@@ -20,14 +20,25 @@ AutohostHandler::~AutohostHandler()
 
 void AutohostHandler::Send(const std::string& cmd)
 {
+	if (m_battle == nullptr) {
+		return;
+	}
 	m_battle->Say(cmd);
 }
 
 void AutohostHandler::SayFounder(const std::string& cmd)
 {
+	if (m_battle == nullptr) {
+		return;
+	}
 	m_battle->GetFounder().Say(cmd);
 }
 
+void AutohostHandler::SetBattle(IBattle* battle)
+{
+	m_battle = battle;
+}
+
 //========================
 //-------- Springie ------
 //========================
@@ -160,10 +171,12 @@ bool AutohostManager::RecognizeAutohost(const std::string& type)
 {
 	if (type == "SPRINGIE") {
 		m_type = AutohostManager::AUTOHOSTTYPE_SPRINGIE;
+		Configure();
 		return true;
 	}
 	if (type == "SPADS") {
 		m_type = AutohostManager::AUTOHOSTTYPE_SPADS;
+		Configure();
 		return true;
 	}
 
@@ -172,6 +185,11 @@ bool AutohostManager::RecognizeAutohost(const std::string& type)
 	return false;
 }
 
+void AutohostManager::Configure()
+{
+	GetAutohostHandler().SetBattle(m_battle);
+}
+
 AutohostManager::AutohostType AutohostManager::GetAutohostType()
 {
 	return m_type;
