@@ -30,7 +30,7 @@
 #include "autohostmanager.h"
 #include "log.h"
 #include "iserver.h"
-#include "gui/ui.h"
+#include "utils/globalevents.h"
 
 
 const unsigned int TIMER_INTERVAL = 1000;
@@ -49,21 +49,17 @@ Battle::Battle(IServer& serv, int id)
     , m_id(id)
     , m_timer(NULL)
 {
-	m_autohost_manager = new AutohostManager(); //FIXME: don't instantiate for each battle, only for the battle we've joined
-	m_autohost_manager->SetBattle(this);
-	ConnectGlobalEvent(this, GlobalEvent::OnUnitsyncReloaded, wxObjectEventFunction(&Battle::OnUnitsyncReloaded));
+	m_autohost_manager = nullptr;
 	m_opts.battleid = m_id;
 }
 
 
 Battle::~Battle()
 {
-	if (m_timer != NULL) {
-		delete m_timer;
-		m_timer = NULL;
-	}
-	delete m_autohost_manager;
-	m_autohost_manager = NULL;
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
+
+	wxDELETE(m_timer);
+	wxDELETE(m_autohost_manager);
 }
 
 
@@ -86,6 +82,11 @@ void Battle::Update(const std::string& Tag)
 
 void Battle::Join(const std::string& password)
 {
+	if (m_autohost_manager == nullptr) {
+		m_autohost_manager = new AutohostManager();
+		m_autohost_manager->SetBattle(this);
+		GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnUnitsyncReloaded, wxObjectEventFunction(&Battle::OnUnitsyncReloaded));
+	}
 	m_serv.JoinBattle(m_opts.battleid, password);
 	m_is_self_in = true;
 }
@@ -93,7 +94,9 @@ void Battle::Join(const std::string& password)
 
 void Battle::Leave()
 {
+	GlobalEventManager::Instance()->UnSubscribe(this, GlobalEventManager::OnUnitsyncReloaded);
 	m_serv.LeaveBattle(m_opts.battleid);
+	m_is_self_in = false;
 }
 
 void Battle::OnPlayerTrueskillChanged(const std::string& NickName, double TrueSkill)
@@ -116,7 +119,7 @@ void Battle::OnRequestBattleStatus()
 	const wxColor col = sett().GetBattleLastColour();
 	bs.colour = LSL::lslColor(col.Red(), col.Green(), col.Blue());
 	//FIXME ? bs.colour = GetFreeColour( GetMe() );
-	bs.side = sett().GetBattleLastSideSel(TowxString(GetHostModName()));
+	bs.side = sett().GetBattleLastSideSel(TowxString(GetHostGameName()));
 	SendMyBattleStatus();
 }
 
@@ -145,7 +148,7 @@ void Battle::SetImReady(bool ready)
 
 /*bool Battle::HasMod()
 {
-  return LSL::usync().ModExists( m_opts.modname );
+  return LSL::usync().GameExists( m_opts.gamename );
 }*/
 
 
@@ -289,7 +292,7 @@ void Battle::OnUserBattleStatusUpdated(User& user, UserBattleStatus status)
 		}
 	}
 	ShouldAutoUnspec();
-	ui().OnUserBattleStatus(*this, user);
+	GlobalEventManager::Instance()->Send(GlobalEventManager::UserBattleStatusChangedEvent, &user);
 }
 
 
@@ -622,7 +625,6 @@ void Battle::StartSpring()
 		m_generating_script = false;
 		GetMe().SendMyUserStatus();
 	}
-	ui().OnBattleStarted(*this);
 }
 
 void Battle::OnTimer(wxTimerEvent&)
@@ -732,7 +734,7 @@ struct Alliance
 	    , allynum(-1)
 	{
 	}
-	Alliance(int i)
+	explicit Alliance(int i)
 	    : ranksum(0)
 	    , allynum(i)
 	{
@@ -765,7 +767,7 @@ struct ControlTeam
 	    , teamnum(-1)
 	{
 	}
-	ControlTeam(int i)
+	explicit ControlTeam(int i)
 	    : ranksum(0)
 	    , teamnum(i)
 	{
@@ -969,7 +971,7 @@ void Battle::FixTeamIDs(BalanceType balance_type, bool support_clans, bool stron
 	if (numcontrolteams == 0 || numcontrolteams == -1)
 		numcontrolteams = GetNumUsers() - GetSpectators(); // 0 or -1 -> use num players, will use comshare only if no available team slots
 	IBattle::StartType position_type = (IBattle::StartType)
-	    LSL::Util::FromString<long>(CustomBattleOptions().getSingleValue("startpostype", LSL::Enum::EngineOption));
+	    LSL::Util::FromIntString(CustomBattleOptions().getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if ((position_type == ST_Fixed) || (position_type == ST_Random)) // if fixed start pos type or random, use max teams = start pos count
 	{
 		try {
