@@ -4,6 +4,7 @@
 // Classes: NetDebugReport CrashReport
 //
 #include "utils/curlhelper.h" // has to be first, else compiler will warn about "please include winsock2.h before windows.h"
+#include <curl/curl.h>
 #include "crashreport.h"
 
 #include <wx/intl.h>
@@ -151,7 +152,7 @@ void CrashReport::GenerateReport()
 	SystemInfos += _T( "SpringLobby version " ) + TowxString(getSpringlobbyVersion()) + _T( "\n" );
 	SystemInfos += _T( "Built from " ) + wxString(wxVERSION_STRING) + _T(" on ") + wxPlatformInfo::Get().GetOperatingSystemIdName() + _T( "\n" );
 
-	report->AddText(_T( "SystemInfos.txt" ), SystemInfos, _("System informations"));
+	report->AddText(_T( "SystemInfos.txt" ), SystemInfos, _("System information"));
 #if wxUSE_STD_IOSTREAM
 	report->AddText(_T( "AppLog.txt" ), TowxString(crashlog.str()), _("Application verbose log"));
 #endif
