@@ -65,7 +65,7 @@ public:
 	//! Fill out map with downloads (Key: Original name)
 	void GetMap(std::map<wxString, ObserverDownloadInfo>& map);
 
-	//! Delete all informations about finished downloads
+	//! Delete all information about finished downloads
 	void ClearFinished();
 
 	bool IsEmpty();
@@ -75,10 +75,10 @@ private:
 	ObserverDownloadInfo GetInfo(IDownload* dl);
 
 	//! List with downloads which are in process
-	std::list<IDownload*> m_dl_list;
+	std::list<IDownload*> m_ActiveDownloadsList;
 
 	//! List with finished downloads
-	std::list<ObserverDownloadInfo> m_finished_list;
+	std::list<ObserverDownloadInfo> m_FinishedDownloadsList;
 
 	//! Mutex fir functions Add, Remove, GetList, GetMap
 	wxMutex mutex;
