@@ -1,6 +1,8 @@
 /* This file is part of pr-downloader (GPL v2 or later), see the LICENSE file */
 
 #include "HttpDownloader.h"
+#include <json/reader.h>
+
 #include "DownloadData.h"
 #include "FileSystem/FileSystem.h"
 #include "FileSystem/File.h"
@@ -10,9 +12,8 @@
 #include "Logger.h"
 #include "Downloader/Mirror.h"
 #include "Downloader/CurlWrapper.h"
-#include "lib/xmlrpc++/src/XmlRpcCurlClient.h"
-#include "lib/xmlrpc++/src/XmlRpc.h"
-#include "lib/xmlrpc++/src/XmlRpcValue.h"
+#include "lib/base64/base64.h"
+
 
 #ifdef WIN32
 #include <winsock2.h>
@@ -25,140 +26,145 @@
 #include <string>
 #include <sstream>
 #include <stdlib.h>
-
-class xmllog: public XmlRpc::XmlRpcLogHandler {
-public:
-	virtual ~xmllog() {}
-	void log(int level, const char* msg)
-	{
-		LOG_INFO("%s",msg);
-	}
-};
-
-static xmllog* logger = NULL;
-static int logcount = 0;
+#include <algorithm> //std::min, std::max
 
 CHttpDownloader::CHttpDownloader()
 {
-	if (logger == NULL) {
-		assert(logcount == 0);
-		logger = new xmllog();
-		XmlRpc::XmlRpcLogHandler::setLogHandler(logger);
-		XmlRpc::XmlRpcLogHandler::setVerbosity(5);
-	}
-	logcount++;
 }
 
 CHttpDownloader::~CHttpDownloader()
 {
-	assert(logcount>=0);
-	logcount--;
-	if (logcount == 0) {
-		delete logger;
-		logger = NULL;
-	}
 }
 
-bool CHttpDownloader::search(std::list<IDownload*>& res, const std::string& name, IDownload::category cat)
+static size_t
+WriteMemoryCallback(void *contents, size_t size, size_t nmemb, void *userp)
 {
-	CURL* curl = CurlWrapper::CurlInit();
-	LOG_DEBUG("%s", name.c_str()  );
+	size_t realsize = size*nmemb;
+	std::string* res = static_cast<std::string*>(userp);
+	res->append((char*)contents, realsize);
+	return realsize;
+}
 
-	const std::string method(XMLRPC_METHOD);
-	//std::string category;
-	XmlRpc::XmlRpcCurlClient client(curl, XMLRPC_HOST,XMLRPC_PORT, XMLRPC_URI);
-	XmlRpc::XmlRpcValue arg;
-	arg["springname"]=name;
-	arg["torrent"]=true;
+//downloads url into res
+bool CHttpDownloader::DownloadUrl(const std::string& url, std::string& res)
+{
+	CurlWrapper* curlw = new CurlWrapper();
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_URL, CurlWrapper::escapeUrl(url).c_str());
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_WRITEFUNCTION, WriteMemoryCallback);
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_WRITEDATA, (void *)&res);
+	CURLcode curlres = curl_easy_perform(curlw->GetHandle());
+	if (!curlres == CURLE_OK) {
+        LOG_ERROR("Error in curl %s", curl_easy_strerror(curlres));
+	}
+	delete curlw;
+	return curlres == CURLE_OK;
+}
+
+static std::string getRequestUrl(const std::string& name, IDownload::category cat)
+{
+	std::string url = HTTP_SEARCH_URL "?category=";
 	switch(cat) {
 	case IDownload::CAT_MAPS:
-		arg["category"]="map";
+		url+="map";
 		break;
 	case IDownload::CAT_GAMES:
-		arg["category"]="game";
+		url+="game";
 		break;
 	case IDownload::CAT_ENGINE_LINUX:
-		arg["category"]="engine_linux";
+		url+="engine_linux";
 		break;
 	case IDownload::CAT_ENGINE_LINUX64:
-		arg["category"]="engine_linux64";
+		url+="engine_linux64";
 		break;
 	case IDownload::CAT_ENGINE_WINDOWS:
-		arg["category"]="engine_windows";
+		url+="engine_windows";
 		break;
 	case IDownload::CAT_ENGINE_MACOSX:
-		arg["category"]="engine_macosx";
+		url+="engine_macosx";
 		break;
 	default:
 		break;
 	}
+	return url + std::string("&torrent=true&springname=") + name;
+}
 
-	XmlRpc::XmlRpcValue result;
-	client.execute(method.c_str(),arg, result);
-
-
-	if (result.getType()!=XmlRpc::XmlRpcValue::TypeArray) {
-		LOG_ERROR("Returned xml isn't an array!");
+bool CHttpDownloader::ParseResult(const std::string& name, const std::string& json, std::list<IDownload*>& res)
+{
+	Json::Value result;   // will contains the root value after parsing.
+	Json::Reader reader;
+	const bool parsingSuccessful = reader.parse( json, result );
+	if ( !parsingSuccessful ) {
+		LOG_ERROR("Couldn't parse result: %s %s", reader.getFormattedErrorMessages().c_str(), json.c_str());
 		return false;
 	}
 
-	for(int i=0; i<result.size(); i++) {
-		XmlRpc::XmlRpcValue resfile = result[i];
+	if (!result.isArray()) {
+		LOG_ERROR("Returned json isn't an array!");
+		return false;
+	}
 
-		if (resfile.getType()!=XmlRpc::XmlRpcValue::TypeStruct) {
+	for(Json::Value::ArrayIndex i=0; i<result.size(); i++) {
+		Json::Value resfile = result[i];
+
+		if (!resfile.isObject()) {
+			LOG_ERROR("Entry isn't object!");
 			return false;
 		}
-		if (resfile["category"].getType()!=XmlRpc::XmlRpcValue::TypeString) {
+		if (!resfile["category"].isString()) {
 			LOG_ERROR("No category in result");
 			return false;
 		}
 		std::string filename=fileSystem->getSpringDir();
-		std::string category=resfile["category"];
+		std::string category=resfile["category"].asString();
 		filename+=PATH_DELIMITER;
-		if (category=="map")
+
+		if (category=="map") {
 			filename+="maps";
-		else if (category=="game")
+		} else if (category=="game") {
 			filename+="games";
-		else if (category.find("engine")==0) // engine_windows, engine_linux, engine_macosx
+		} else if (category.find("engine")==0) { // engine_windows, engine_linux, engine_macosx
 			filename+="engine";
-		else
+		} else
 			LOG_ERROR("Unknown Category %s", category.c_str());
 		filename+=PATH_DELIMITER;
-		if ((resfile["mirrors"].getType()!=XmlRpc::XmlRpcValue::TypeArray) ||
-			(resfile["filename"].getType()!=XmlRpc::XmlRpcValue::TypeString)) {
+
+		if ((!resfile["mirrors"].isArray()) ||
+		    (!resfile["filename"].isString())) {
 			LOG_ERROR("Invalid type in result");
 			return false;
 		}
-		filename.append(resfile["filename"]);
+		filename.append(resfile["filename"].asString());
+
+		const IDownload::category cat = IDownload::getCatFromStr(category);
 		IDownload* dl=new IDownload(filename,name, cat);
-		XmlRpc::XmlRpcValue mirrors = resfile["mirrors"];
-		for(int j=0; j<mirrors.size(); j++) {
-			if (mirrors[j].getType()!=XmlRpc::XmlRpcValue::TypeString) {
+		Json::Value mirrors = resfile["mirrors"];
+		for(Json::Value::ArrayIndex j=0; j<mirrors.size(); j++) {
+			if (!mirrors[j].isString()) {
 				LOG_ERROR("Invalid type in result");
 			} else {
-				dl->addMirror(mirrors[j]);
+				dl->addMirror(mirrors[j].asString());
 			}
 		}
 
-		if(resfile["torrent"].getType()==XmlRpc::XmlRpcValue::TypeBase64) {
-			const std::vector<char> torrent = resfile["torrent"];
+		if(resfile["torrent"].isString()) {
+			const std::string torrent = base64_decode(resfile["torrent"].asString());
 			fileSystem->parseTorrent(&torrent[0], torrent.size(), dl);
 		}
-		if (resfile["version"].getType()==XmlRpc::XmlRpcValue::TypeString) {
-			const std::string& version = resfile["version"];
+		if (resfile["version"].isString()) {
+			const std::string& version = resfile["version"].asString();
 			dl->version = version;
 		}
-		if (resfile["md5"].getType()==XmlRpc::XmlRpcValue::TypeString) {
+		if (resfile["md5"].isString()) {
 			dl->hash=new HashMD5();
-			dl->hash->Set(resfile["md5"]);
+			dl->hash->Set(resfile["md5"].asString());
 		}
-		if (resfile["size"].getType()==XmlRpc::XmlRpcValue::TypeInt) {
-			dl->size=resfile["size"];
+		if (resfile["size"].isInt()) {
+			dl->size=resfile["size"].asInt();
 		}
-		if (resfile["depends"].getType() == XmlRpc::XmlRpcValue::TypeArray) {
-			for(int i=0; i<resfile["depends"].size(); i++) {
-				if (resfile["depends"][i].getType() == XmlRpc::XmlRpcValue::TypeString) {
-					const std::string &dep = resfile["depends"][i];
+		if (resfile["depends"].isArray()) {
+			for(Json::Value::ArrayIndex i=0; i<resfile["depends"].size(); i++) {
+				if (resfile["depends"][i].isString()) {
+					const std::string &dep = resfile["depends"][i].asString();
 					dl->addDepend(dep);
 				}
 			}
@@ -168,6 +174,18 @@ bool CHttpDownloader::search(std::list<IDownload*>& res, const std::string& name
 	return true;
 }
 
+bool CHttpDownloader::search(std::list<IDownload*>& res, const std::string& name, IDownload::category cat)
+{
+	LOG_DEBUG("%s", name.c_str()  );
+	std::string dlres;
+	const std::string url = getRequestUrl(name, cat);
+	if (!DownloadUrl(url, dlres)) {
+		LOG_ERROR("Error downloading %s %s", url.c_str(), dlres.c_str());
+	        return false;
+	}
+	return ParseResult(name, dlres, res);
+}
+
 size_t multi_write_data(void *ptr, size_t size, size_t nmemb, DownloadData* data)
 {
 	//LOG_DEBUG("%d %d",size,  nmemb);
@@ -220,6 +238,9 @@ void CHttpDownloader::showProcess(IDownload* download, bool force)
 {
 	int done = download->getProgress();
 	int size = download->size;
+	if (listener != NULL) {
+		listener(done, size);
+	}
 	LOG_PROGRESS(done, size, force);
 }
 
@@ -236,7 +257,7 @@ std::vector< unsigned int > CHttpDownloader::verifyAndGetNextPieces(CFile& file,
 			showProcess(download, true);
 			return pieces;
 		} else {
-			LOG_ERROR("md5 sum missmatch %s %s", download->hash->toString().c_str(), md5.toString().c_str());
+			LOG_INFO("md5 sum missmatch %s %s", download->hash->toString().c_str(), md5.toString().c_str());
 		}
 	}
 
@@ -281,6 +302,9 @@ std::vector< unsigned int > CHttpDownloader::verifyAndGetNextPieces(CFile& file,
 static int progress_func(DownloadData* data, double total, double done, double, double)
 {
 	data->download->progress = done;
+	if (IDownloader::listener != NULL) {
+		IDownloader::listener(done, total);
+	}
 	if (data->got_ranges) {
 		LOG_PROGRESS(done, total, done >= total);
 	}
@@ -299,27 +323,26 @@ bool CHttpDownloader::setupDownload(DownloadData* piece)
 	piece->start_piece=pieces.size() > 0 ? pieces[0] : -1;
 	assert(piece->download->pieces.size()<=0 || piece->start_piece >=0);
 	piece->pieces = pieces;
-	if (piece->easy_handle==NULL) {
-		piece->easy_handle=CurlWrapper::CurlInit();
+	if (piece->curlw==NULL) {
+		piece->curlw = new CurlWrapper();
 	} else {
-		curl_easy_cleanup(piece->easy_handle);
-		piece->easy_handle=CurlWrapper::CurlInit();
+		delete piece->curlw;
+		piece->curlw = new CurlWrapper();
 	}
 
-	CURL* curle= piece->easy_handle;
+	CURL* curle = piece->curlw->GetHandle();
 	piece->mirror=piece->download->getFastestMirror();
 	if (piece->mirror==NULL) {
 		LOG_ERROR("No mirror found");
 		return false;
 	}
-	std::string escaped;
-	piece->mirror->escapeUrl(escaped);
+
 	curl_easy_setopt(curle, CURLOPT_WRITEFUNCTION, multi_write_data);
 	curl_easy_setopt(curle, CURLOPT_WRITEDATA, piece);
 	curl_easy_setopt(curle, CURLOPT_NOPROGRESS, 0L);
 	curl_easy_setopt(curle, CURLOPT_PROGRESSDATA, piece);
 	curl_easy_setopt(curle, CURLOPT_PROGRESSFUNCTION, progress_func);
-	curl_easy_setopt(curle, CURLOPT_URL, escaped.c_str());
+	curl_easy_setopt(curle, CURLOPT_URL, CurlWrapper::escapeUrl(piece->mirror->url).c_str());
 
 	if ((piece->download->size>0) && (piece->start_piece>=0) && piece->download->pieces.size() > 0) { //don't set range, if size unknown
 		std::string range;
@@ -333,7 +356,7 @@ bool CHttpDownloader::setupDownload(DownloadData* piece)
 		//parse server response	header as well
 		curl_easy_setopt(curle, CURLOPT_HEADERFUNCTION, multiHeader);
 		curl_easy_setopt(curle, CURLOPT_WRITEHEADER, piece);
-		for ( std::vector<unsigned int>::iterator it = piece->pieces.begin(); it != piece->pieces.end(); it++ )
+		for ( std::vector<unsigned int>::iterator it = piece->pieces.begin(); it != piece->pieces.end(); ++it )
 			piece->download->pieces[*it].state=IDownload::STATE_DOWNLOADING;
 	} else { //
 		LOG_DEBUG("single piece transfer");
@@ -350,8 +373,11 @@ bool CHttpDownloader::setupDownload(DownloadData* piece)
 
 DownloadData* CHttpDownloader::getDataByHandle(const std::vector <DownloadData*>& downloads, const CURL* easy_handle) const
 {
-	for(int i=0; i<(int)downloads.size(); i++) { //search corresponding data structure
-		if (downloads[i]->easy_handle == easy_handle) {
+	for(size_t i=0; i<downloads.size(); i++) { //search corresponding data structure
+		if (downloads[i]->curlw == nullptr) { //inactive download
+			continue;
+		}
+		if (downloads[i]->curlw->GetHandle() == easy_handle) {
 			return downloads[i];
 		}
 	}
@@ -390,7 +416,7 @@ bool CHttpDownloader::processMessages(CURLM* curlm, std::vector <DownloadData*>&
 			}
 			assert(data->download->file!=NULL);
 			assert(data->start_piece< (int)data->download->pieces.size());
-			for ( std::vector<unsigned int>::iterator it = data->pieces.begin(); it != data->pieces.end(); it++ ) {
+			for ( std::vector<unsigned int>::iterator it = data->pieces.begin(); it != data->pieces.end(); ++it ) {
 				if (data->download->pieces[*it].sha->isSet()) {
 					data->download->file->Hash(sha1, *it);
 
@@ -411,22 +437,22 @@ bool CHttpDownloader::processMessages(CURLM* curlm, std::vector <DownloadData*>&
 			}
 			//get speed at which this piece was downloaded + update mirror info
 			double dlSpeed;
-			curl_easy_getinfo(data->easy_handle, CURLINFO_SPEED_DOWNLOAD, &dlSpeed);
+			curl_easy_getinfo(data->curlw->GetHandle(), CURLINFO_SPEED_DOWNLOAD, &dlSpeed);
 			data->mirror->UpdateSpeed(dlSpeed);
 			if (data->mirror->status == Mirror::STATUS_UNKNOWN) //set mirror status only when unset
 				data->mirror->status=Mirror::STATUS_OK;
 
 			//remove easy handle, as its finished
-			curl_multi_remove_handle(curlm, data->easy_handle);
-			curl_easy_cleanup(data->easy_handle);
-			data->easy_handle=NULL;
+			curl_multi_remove_handle(curlm, data->curlw->GetHandle());
+			delete data->curlw;
+			data->curlw=NULL;
 			LOG_INFO("piece finished");
 			//piece finished / failed, try a new one
 			if (!setupDownload(data)) {
 				LOG_DEBUG("No piece found, all pieces finished / currently downloading");
 				break;
 			}
-			int ret=curl_multi_add_handle(curlm, data->easy_handle);
+			int ret=curl_multi_add_handle(curlm, data->curlw->GetHandle());
 			if (ret!=CURLM_OK) {
 				LOG_ERROR("curl_multi_perform_error: %d %d", ret, CURLM_BAD_EASY_HANDLE);
 			}
@@ -442,39 +468,38 @@ bool CHttpDownloader::processMessages(CURLM* curlm, std::vector <DownloadData*>&
 bool CHttpDownloader::download(std::list<IDownload*>& download, int max_parallel)
 {
 
-	std::list<IDownload*>::iterator it;
 	std::vector <DownloadData*> downloads;
 	CURLM* curlm=curl_multi_init();
-	for(it=download.begin(); it!=download.end(); ++it) {
-		if ((*it)->dltype != IDownload::TYP_HTTP) {
+	for(IDownload* dl: download) {
+		if (dl->dltype != IDownload::TYP_HTTP) {
 			LOG_DEBUG("skipping non http-dl")
 			continue;
 		}
-		const int count=std::min(max_parallel, std::max(1, std::min((int)(*it)->pieces.size(), (*it)->getMirrorCount()))); //count of parallel downloads
-		if((*it)->getMirrorCount()<=0) {
+		const int count=std::min(max_parallel, std::max(1, std::min((int)dl->pieces.size(), dl->getMirrorCount()))); //count of parallel downloads
+		if(dl->getMirrorCount()<=0) {
 			LOG_ERROR("No mirrors found");
 			return false;
 		}
 		LOG_DEBUG("Using %d parallel downloads", count);
-		(*it)->parallel_downloads = count;
+		dl->parallel_downloads = count;
 		CFile* file=new CFile();
-		if(!file->Open((*it)->name, (*it)->size, (*it)->piecesize)) {
+		if(!file->Open(dl->name, dl->size, dl->piecesize)) {
 			delete file;
 			return false;
 		}
-		(*it)->file = file;
+		dl->file = file;
 		for(int i=0; i<count; i++) {
 			DownloadData* dlData=new DownloadData();
-			dlData->download=*it;
+			dlData->download=dl;
 			if (!setupDownload(dlData)) { //no piece found (all pieces already downloaded), skip
 				delete dlData;
-				if ((*it)->state!=IDownload::STATE_FINISHED) {
+				if (dl->state!=IDownload::STATE_FINISHED) {
 					LOG_ERROR("no piece found");
 					return false;
 				}
 			} else {
 				downloads.push_back(dlData);
-				curl_multi_add_handle(curlm, dlData->easy_handle);
+				curl_multi_add_handle(curlm, dlData->curlw->GetHandle());
 			}
 		}
 	}
@@ -515,8 +540,10 @@ bool CHttpDownloader::download(std::list<IDownload*>& download, int max_parallel
 	if (!aborted) { // if download didn't fail, get file size reported in http-header
 		double size=-1;
 		for (unsigned i=0; i<downloads.size(); i++) {
+			if (downloads[i]->curlw == nullptr)
+				continue;
 			double tmp;
-			curl_easy_getinfo(downloads[i]->easy_handle, CURLINFO_CONTENT_LENGTH_DOWNLOAD, &tmp);
+			curl_easy_getinfo(downloads[i]->curlw->GetHandle(), CURLINFO_CONTENT_LENGTH_DOWNLOAD, &tmp);
 			if (tmp>size) {
 				size=tmp;
 			}
@@ -535,13 +562,13 @@ bool CHttpDownloader::download(std::list<IDownload*>& download, int max_parallel
 	}
 
 	//close all open files
-	for(it=download.begin(); it!=download.end(); ++it) {
-		if ((*it)->file!=NULL)
-			(*it)->file->Close();
+	for(IDownload* dl: download) {
+		if (dl->file!=NULL)
+			dl->file->Close();
 	}
-	for (unsigned i=0; i<downloads.size(); i++) {
+	for (size_t i=0; i<downloads.size(); i++) {
 		long timestamp;
-		if (curl_easy_getinfo(downloads[i]->easy_handle, CURLINFO_FILETIME, &timestamp) == CURLE_OK) {
+		if ((downloads[i]->curlw != nullptr) && curl_easy_getinfo(downloads[i]->curlw->GetHandle(), CURLINFO_FILETIME, &timestamp) == CURLE_OK) {
 			if (downloads[i]->download->state != IDownload::STATE_FINISHED) //decrease local timestamp if download failed to force redownload next time
 				timestamp--;
 			downloads[i]->download->file->SetTimestamp(timestamp);
