@@ -12,9 +12,10 @@
 #include <stdio.h>
 
 
-CRepo::CRepo(const std::string& repourl, CRapidDownloader* rapid):
+CRepo::CRepo(const std::string& repourl,const std::string& _shortname, CRapidDownloader* rapid):
 	repourl(repourl),
-	rapid(rapid)
+	rapid(rapid),
+	shortname(_shortname)
 {
 }
 
@@ -27,12 +28,11 @@ bool CRepo::getDownload(IDownload& dl)
 	std::string tmp;
 	urlToPath(repourl,tmp);
 	LOG_DEBUG("%s",tmp.c_str());
-	this->tmpFile = fileSystem->getSpringDir() + PATH_DELIMITER + "rapid" + PATH_DELIMITER +tmp + PATH_DELIMITER +"versions.gz";
-	fileSystem->createSubdirs(tmpFile);
+	tmpFile = fileSystem->getSpringDir() + PATH_DELIMITER + "rapid" + PATH_DELIMITER +tmp + PATH_DELIMITER +"versions.gz";
+	fileSystem->createSubdirs(CFileSystem::DirName(tmpFile));
 	//first try already downloaded file, as repo master file rarely changes
 	if ((fileSystem->fileExists(tmpFile)) && fileSystem->isOlder(tmpFile,REPO_RECHECK_TIME))
 		return false;
-	fileSystem->createSubdirs(tmpFile);
 	dl = IDownload(tmpFile);
 	dl.addMirror(repourl + "/versions.gz");
 	return true;
@@ -40,12 +40,20 @@ bool CRepo::getDownload(IDownload& dl)
 
 bool CRepo::parse()
 {
+	if (tmpFile.empty()) {
+		LOG_DEBUG("tmpfile empty, repo not initialized?");
+		return false;
+	}
 	LOG_DEBUG("%s",tmpFile.c_str());
 	FILE* f = fileSystem->propen(tmpFile, "rb");
+	if (f == nullptr) {
+		LOG_ERROR("Could not open %s",tmpFile.c_str());
+		return false;
+	}
 	gzFile fp = gzdopen(fileno(f), "rb");
 	if (fp==Z_NULL) {
 		fclose(f);
-		LOG_ERROR("Could not open %s",tmpFile.c_str());
+		LOG_ERROR("Could not gzdopen %s",tmpFile.c_str());
 		return false;
 	}
 
@@ -59,19 +67,16 @@ bool CRepo::parse()
 			}
 		}
 
-		std::string tmp=buf;
-		std::string shortname;
-		getStrByIdx(tmp,shortname, ',',0);
-		std::string md5;
-		getStrByIdx(tmp, md5, ',',1);
-		std::string depends;
-		getStrByIdx(tmp,depends, ',',2);
-		std::string name;
-		getStrByIdx(tmp,name, ',',3);
-		if (shortname.size()>0) { //create new repo from url
-			CSdp sdptmp=CSdp(shortname, md5, name, depends, repourl);
-			rapid->addRemoteDsp(sdptmp);
+		const std::string line=buf;
+		std::vector<std::string> items = tokenizeString(line, ',');
+		if (items.size() < 4) {
+			LOG_ERROR("Invalid line: %s", line.c_str());
+			continue;
 		}
+
+		//create new repo from url
+		CSdp sdptmp=CSdp(items[0], items[1], items[3], items[2], repourl);
+		rapid->addRemoteDsp(sdptmp);
 	}
 	int errnum=Z_OK;
 	const char* errstr = gzerror(fp, &errnum);
