@@ -83,21 +83,19 @@ bool CSdp::download(IDownload * download)
 		fileSystem->parseSdp(filename,files); //parse downloaded file
 	}
 
-	std::list<FileData*>::iterator it;
-
 	HashMD5 md5= HashMD5();
 	FileData tmp=FileData();
 	int i=0;
-	for(it = files.begin(); it!=files.end(); ++it) { //check which file are available on local disk -> create list of files to download
+	for(FileData* filedata: files) { //check which file are available on local disk -> create list of files to download
 		i++;
-		md5.Set((*it)->md5, sizeof((*it)->md5));
+		md5.Set(filedata->md5, sizeof(filedata->md5));
 		std::string file;
 		fileSystem->getPoolFilename(md5.toString(), file);
 		if (!fileSystem->fileExists(file)) { //add non-existing files to download list
 			count++;
-			(*it)->download=true;
+			filedata->download=true;
 		} else {
-			(*it)->download=false;
+			filedata->download=false;
 		}
 		if (i%30==0) {
 			LOG_DEBUG("\r%d/%d checked",i,(int)files.size());
@@ -120,9 +118,8 @@ bool CSdp::download(IDownload * download)
 		LOG_DEBUG("Already downloaded: %s", shortname.c_str());
 		downloaded=true;
 	}
-
-	for(it = files.begin(); it!=files.end(); ++it) { //free memory
-		delete *it;
+	for(FileData* filedata: files) { //free memory
+		delete filedata;
 	}
 	if ((rename) && (!fileSystem->Rename(tmpFile, filename))) {
 		LOG_ERROR("Couldn't rename %s to %s", tmpFile.c_str(), filename.c_str());
@@ -154,7 +151,7 @@ static size_t write_streamed_data(const void* tmp, size_t size, size_t nmemb,CSd
 	while (buf_pos<buf_end) { //all bytes written?
 		if (sdp->file_handle==NULL) { //no open file, create one
 			while ( (!(*sdp->list_it)->download==true) && (sdp->list_it!=sdp->globalFiles->end())) { //get file
-				sdp->list_it++;
+				++sdp->list_it;
 			}
 			HashMD5 md5;
 			md5.Set((*sdp->list_it)->md5, sizeof((*sdp->list_it)->md5));
@@ -203,7 +200,7 @@ static size_t write_streamed_data(const void* tmp, size_t size, size_t nmemb,CSd
 					fileSystem->removeFile(sdp->file_name.c_str());
 					return -1;
 				}
-				sdp->list_it++;
+				++sdp->list_it;
 				sdp->file_pos=0;
 				sdp->skipped=0;
 			}
@@ -226,13 +223,16 @@ static int progress_func(CSdp& csdp, double TotalToDownload, double NowDownloade
 	csdp.m_download->rapid_size[&csdp] = TotalToDownload;
 	csdp.m_download->map_rapid_progress[&csdp] = NowDownloaded;
 	uint64_t total = 0;
-	for ( std::map<CSdp*,uint64_t>::iterator it = csdp.m_download->rapid_size.begin(); it != csdp.m_download->rapid_size.end(); it++ ) {
-		total += (*it).second;
+	for ( auto it : csdp.m_download->rapid_size) {
+		total += it.second;
 	}
 	csdp.m_download->size = total;
+	if (IDownloader::listener != nullptr) {
+		IDownloader::listener(NowDownloaded, TotalToDownload);
+	}
 	total = 0;
-	for ( std::map<CSdp*,uint64_t>::iterator it = csdp.m_download->map_rapid_progress.begin(); it != csdp.m_download->map_rapid_progress.end(); it++ ) {
-		total += (*it).second;
+	for ( auto it : csdp.m_download->map_rapid_progress) {
+		total += it.second;
 	}
 	csdp.m_download->progress = total;
 	if (TotalToDownload == NowDownloaded) //force output when download is finished
@@ -244,52 +244,53 @@ static int progress_func(CSdp& csdp, double TotalToDownload, double NowDownloade
 
 bool CSdp::downloadStream(const std::string& url,std::list<FileData*> files)
 {
-	CURL* curl = CurlWrapper::CurlInit();
-	if (curl) {
-		CURLcode res;
-		LOG_INFO("Using rapid");
-		LOG_INFO(url.c_str());
+	CurlWrapper* curlw = new CurlWrapper();
+	if (!curlw) {
+		return false;
+	}
+	CURLcode res;
+	LOG_INFO("Using rapid");
+	LOG_INFO(url.c_str());
 
-		curl_easy_setopt(curl, CURLOPT_URL, url.c_str());
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_URL, url.c_str());
 
-		int  buflen=files.size()/8;
-		if (files.size()%8!=0)
-			buflen++;
-		char* buf=(char*)malloc(buflen); //FIXME: compress blockwise and not all at once
-		memset(buf,0,buflen);
-		int destlen=files.size()*2;
-		LOG_DEBUG("%d %d %d",(int)files.size(),buflen,destlen);
-		int i=0;
-		std::list<FileData*>::iterator it;
-		for (it=files.begin(); it!=files.end(); ++it) {
-			if ((*it)->download==true) {
-				buf[i/8] |= (1<<(i%8));
-			}
-			i++;
+	int  buflen=files.size()/8;
+	if (files.size()%8!=0)
+		buflen++;
+	char* buf=(char*)malloc(buflen); //FIXME: compress blockwise and not all at once
+	memset(buf,0,buflen);
+	int destlen=files.size()*2;
+	LOG_DEBUG("%d %d %d",(int)files.size(),buflen,destlen);
+	int i=0;
+	for (FileData* it: files) {
+		if (it->download==true) {
+			buf[i/8] |= (1<<(i%8));
 		}
-		char* dest=(char*)malloc(destlen);
+		i++;
+	}
+	char* dest=(char*)malloc(destlen);
 
-		gzip_str(buf,buflen,dest,&destlen);
+	gzip_str(buf,buflen,dest,&destlen);
 
-		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_streamed_data);
-		curl_easy_setopt(curl, CURLOPT_WRITEDATA, this);
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_WRITEFUNCTION, write_streamed_data);
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_WRITEDATA, this);
 
 
-		globalFiles=&files;
-		curl_easy_setopt(curl, CURLOPT_POSTFIELDS, dest);
-		curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE,destlen);
-		curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 0L);
-		curl_easy_setopt(curl, CURLOPT_PROGRESSFUNCTION, progress_func);
-		curl_easy_setopt(curl, CURLOPT_PROGRESSDATA, this);
+	globalFiles=&files;
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_POSTFIELDS, dest);
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_POSTFIELDSIZE,destlen);
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_NOPROGRESS, 0L);
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_PROGRESSFUNCTION, progress_func);
+	curl_easy_setopt(curlw->GetHandle(), CURLOPT_PROGRESSDATA, this);
 
-		res = curl_easy_perform(curl);
-		free(dest);
-		/* always cleanup */
-		curl_easy_cleanup(curl);
-		if (res!=CURLE_OK) {
-			LOG_ERROR("Curl cleanup error: %s",curl_easy_strerror(res));
-			return false;
-		}
+	res = curl_easy_perform(curlw->GetHandle());
+	free(dest);
+	/* always cleanup */
+	delete curlw;
+	curlw = NULL;
+	if (res != CURLE_OK) {
+		LOG_ERROR("Curl cleanup error: %s",curl_easy_strerror(res));
+		return false;
 	}
 	return true;
 }
