@@ -7,12 +7,20 @@
 #include "Util.h"
 
 #include <stdio.h>
+#ifndef _MSC_VER
 #include <unistd.h>
+#else
+#include <io.h> //_chsize
+#endif
 #include <errno.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <stdlib.h>
+#ifndef _MSC_VER
 #include <sys/time.h>
+#endif
+#include <algorithm> //std::min
+
 
 #ifdef WIN32
 #include <windows.h>
@@ -38,7 +46,9 @@ void CFile::Close()
 	if (handle!=0) {
 		fclose(handle);
 		if (IsNewFile()) {
-			fileSystem->removeFile(filename.c_str()); //delete possible existing destination file
+			if (fileSystem->fileExists(filename)) { //delete possible existing destination file
+				fileSystem->removeFile(filename);
+			}
 			fileSystem->Rename(tmpfile, filename);
 			isnewfile = false;
 		}
@@ -51,9 +61,8 @@ bool CFile::Open(const std::string& filename, long size, int piecesize)
 	LOG_DEBUG("%s %d %d", filename.c_str(), size, piecesize);
 	this->filename=filename;
 	this->size=size;
-	fileSystem->createSubdirs(filename);
+	fileSystem->createSubdirs(CFileSystem::DirName(filename));
 	SetPieceSize(piecesize);
-//	fileSystem->createSubdirs(filename);
 	if (handle!=NULL) {
 		LOG_ERROR("file opened before old was closed");
 		return false;
@@ -75,7 +84,12 @@ bool CFile::Open(const std::string& filename, long size, int piecesize)
 	}
 
 	if((!isnewfile) && (size>0) && (size!=sb.st_size)) { //truncate file if real-size != excepted file size
-		int ret=ftruncate(fileno(handle), size);
+#ifdef _MSC_VER
+		int ret  = _chsize(fileno(handle), size);
+#else
+		int ret = ftruncate(fileno(handle), size);
+#endif
+
 		if (ret!=0) {
 			LOG_ERROR("ftruncate failed");
 		}
@@ -94,7 +108,6 @@ bool CFile::Hash(IHash& hash, int piece)
 	SetPos(0, piece);
 	hash.Init();
 //	LOG("piece %d left: %d",piece,  GetPieceSize(piece));
-	int read=0;
 	long unsigned left=GetPieceSize(piece); //total bytes to hash
 	if (left==0) {
 		LOG_ERROR("tried to hash empty piece %d", piece);
@@ -102,11 +115,11 @@ bool CFile::Hash(IHash& hash, int piece)
 	}
 
 	while(left>0) {
-		int toread=std::min(left, (long unsigned)sizeof(buf));
-		read=Read(buf, toread, piece);
+		const int toread=std::min(left, (long unsigned)sizeof(buf));
+		const int read=Read(buf, toread, piece);
 		if(read<=0) {
-			LOG_ERROR("EOF or read error on piece %d, left: %d toread: %d size: %d, GetPiecePos %d GetPieceSize(): %d read: %d", piece, left, toread, GetPieceSize(piece), GetPiecePos(piece), GetPieceSize(piece), read);
-			LOG_ERROR("curpos: %d", curpos);
+			LOG_DEBUG("EOF or read error on piece %d, left: %d toread: %d size: %d, GetPiecePos %d GetPieceSize(): %d read: %d", piece, left, toread, GetPieceSize(piece), GetPiecePos(piece), GetPieceSize(piece), read);
+			LOG_DEBUG("curpos: %d", curpos);
 			return false;
 		}
 		hash.Update(buf, toread);
@@ -126,13 +139,13 @@ int CFile::Read(char *buf, int bufsize, int piece)
 	int items=fread(buf, bufsize, 1, handle);
 	if (items<=0) {
 		if(ferror(handle)) {
-			LOG_ERROR("read error %s bufsize: %d curpos: %d GetPieceSize: %d", strerror(errno), bufsize, curpos, GetPieceSize());
+			LOG_DEBUG("read error %s bufsize: %d curpos: %d GetPieceSize: %d", strerror(errno), bufsize, curpos, GetPieceSize());
 			SetPos(0, piece);
 			return -1;
 		}
 		if(feof(handle)) {
-			LOG_ERROR("EOF while Read: '%s' items: %d!", strerror(errno), items);
-			LOG_ERROR("read error %s bufsize: %d curpos: %d GetPieceSize: %d", strerror(errno), bufsize, curpos, GetPieceSize());
+			LOG_DEBUG("EOF while Read: '%s' items: %d!", strerror(errno), items);
+			LOG_DEBUG("read error %s bufsize: %d curpos: %d GetPieceSize: %d", strerror(errno), bufsize, curpos, GetPieceSize());
 			return -1;
 		}
 	}
@@ -227,7 +240,7 @@ bool CFile::SetPieceSize(int pieceSize)
 int CFile::GetPiecesSize(std::vector< unsigned int > pieces) const
 {
   int size = 0;
-  for ( std::vector< unsigned int >::iterator it = pieces.begin(); it != pieces.end(); it++ )
+  for ( std::vector< unsigned int >::iterator it = pieces.begin(); it != pieces.end(); ++it )
   {
     size += GetPieceSize(*it);
   }
