@@ -10,14 +10,19 @@
 
 static bool fetchDepends = true;
 
+void SetDownloadListener(IDownloaderProcessUpdateListener listener) {
+	IDownloader::setProcessUpdateListener(listener);
+}
+
 bool download_engine(std::list<IDownload*>& dllist)
 {
 	httpDownload->download(dllist);
 	bool res = true;
-	std::list<IDownload*>::iterator it;
-	for (it = dllist.begin(); it!=dllist.end(); ++it) {
-		if (!fileSystem->extractEngine((*it)->name, (*it)->version))
+	for (const IDownload* dl: dllist) {
+		if (!fileSystem->extractEngine(dl->name, dl->version)) {
+			LOG_ERROR("Failed to extract engine %s", dl->version.c_str());
 			res = false;
+		}
 	}
 	return res;
 }
@@ -181,28 +186,36 @@ bool DownloadAdd(unsigned int id)
 	return true;
 }
 
+bool dlListContains(const std::list<IDownload*>&dls, const std::string& name)
+{
+	for(const IDownload* dl: dls) {
+		if (dl->name == name) {
+			return true;
+		}
+	}
+	return false;
+}
+
 bool addDepends(std::list<IDownload*>& dls)
 {
-	std::list<IDownload*>::iterator it;
-	for (it = dls.begin(); it != dls.end(); ++it) {
-		if ((*it)->depend.empty()) {
-			continue;
-		}
-		std::list<std::string>::iterator stit;
-		for (stit = (*it)->depend.begin(); stit != (*it)->depend.end(); ++stit) {
+	for (const IDownload* dl: dls) {
+		for (const std::string& depend: dl->depend) {
 			std::list<IDownload*> depends;
-			const std::string& depend = (*stit);
 			search(DL_ANY, CAT_ANY, depend.c_str(), depends);
 			LOG_INFO("Adding depend %s", depend.c_str());
-			dls.merge(depends);
+			for(IDownload* newdep: depends) {
+				if (!dlListContains(dls, newdep->name)) {
+					dls.push_back(newdep);
+				}
+			}
 		}
 	}
 	return true;
 }
 
-bool DownloadStart()
+int DownloadStart()
 {
-	bool res = true;
+	int res = 0;
 	std::list<IDownload*> dls;
 	std::list<int>::iterator it;
 	for (it = downloads.begin(); it != downloads.end(); ++it) {
@@ -218,6 +231,7 @@ bool DownloadStart()
 
 	if (dls.empty()) {
 		LOG_DEBUG("Nothing to do, did you forget to call DownloadAdd()?");
+		res = 1;
 		return res;
 	}
 
@@ -225,17 +239,17 @@ bool DownloadStart()
 	case DL_RAPID:
 	case DL_HTTP:
 		if(!rapidDownload->download(dls))
-			res = false;
+			res = 2;
 		if (!httpDownload->download(dls,1))
-			res = false;
+			res = 3;
 		break;
 	case DL_ENGINE:
 		if (!download_engine(dls))
-			res = false;
+			res = 4;
 		break;
 	default:
 		LOG_ERROR("%s():%d  Invalid type specified: %d %d", __FUNCTION__, __LINE__, typ, downloads.size());
-		res = false;
+		res = 5;
 	}
 
 	IDownloader::freeResult(searchres);
