@@ -41,79 +41,97 @@ class DownloadItem : public LSL::WorkItem
 {
 public:
 	DownloadItem(std::list<IDownload*> item, IDownloader* loader)
-	    : m_item(item)
-	    , m_loader(loader)
+		: m_item(item)
+		, m_loader(loader)
+		, m_reload(false)
+		, m_lobbydl(false)
 	{
 	}
 
 	void Run()
 	{
-		if (!m_item.empty()) {
-			UiEvents::ScopedStatusMessage msg("Downloading: " + m_item.front()->name, 0);
-			//we create this in avance cause m_item gets freed
-			wxString d(_("Download complete: "));
-			d += TowxString(m_item.front()->name);
-			bool downloadFailed = (m_loader->download(m_item, sett().GetHTTPMaxParallelDownloads()) != true);
-			if (downloadFailed) {
-				wxString errorMessage = wxString::Format(_("Failed to download %s!"), m_item.front()->name);
-				wxLogError(errorMessage);
-			}
-			std::list<IDownload*>::iterator it;
-			bool reload = false;
-			bool lobbydl = false;
-			for (it = m_item.begin(); it != m_item.end(); ++it) {
-				IDownload* dl = *it;
-				switch (dl->cat) {
-					case IDownload::CAT_ENGINE_LINUX:
-					case IDownload::CAT_ENGINE_WINDOWS:
-					case IDownload::CAT_ENGINE_LINUX64:
-					case IDownload::CAT_ENGINE_MACOSX: {
-						fileSystem->extractEngine(dl->name, dl->version);
-						SlPaths::RefreshSpringVersionList(); //FIXME: maybe not thread-save!
-						SlPaths::SetUsedSpringIndex(dl->version);
-						break;
-					}
-					case IDownload::CAT_LOBBYCLIENTS:
-						lobbydl = true;
-						fileSystem->extract(dl->name, SlPaths::GetUpdateDir(), true);
-						break;
-					case IDownload::CAT_MAPS:
-					case IDownload::CAT_GAMES:
-						reload = true;
-						break;
-					default:
-						break;
-						;
-				}
-			}
-			m_loader->freeResult(m_item);
-			UiEvents::ScopedStatusMessage msgcomplete(d, 0);
-			if (reload) {
-				LSL::usync().ReloadUnitSyncLib();
-				// prefetch map data after a download as well
-				for (it = m_item.begin(); it != m_item.end(); ++it) {
-					IDownload* dl = *it;
-					switch (dl->cat) {
-						case IDownload::CAT_MAPS: {
-							LSL::usync().PrefetchMap(dl->name); //FIXME: do the same for games, too
-						}
-						default:
-							continue;
-					}
-				}
-
-				//notify about finished download
-				GlobalEvent::Send(GlobalEvent::OnUnitsyncReloaded);
-			}
-			if (lobbydl) {
-				GlobalEvent::Send(GlobalEvent::OnLobbyDownloaded);
-			}
+		if (m_item.empty()) {
+			return;
 		}
+		UiEvents::ScopedStatusMessage msg("Downloading: " + m_item.front()->name, 0);
+		//we create this in avance cause m_item gets freed
+		wxString d(_("Download complete: "));
+		d += TowxString(m_item.front()->name);
+		bool downloadFailed = (m_loader->download(m_item, sett().GetHTTPMaxParallelDownloads()) != true);
+		if (downloadFailed) {
+			wxString errorMessage = wxString::Format(_("Failed to download %s!"), m_item.front()->name);
+			wxLogError(errorMessage);
+		}
+
+		for (IDownload* dl: m_item) {
+			DownloadFinished(dl);
+		}
+
+		UiEvents::ScopedStatusMessage msgcomplete(d, 0);
+		if (m_reload) {
+			LSL::usync().ReloadUnitSyncLib();
+			// prefetch map data after a download as well
+			for (IDownload* dl: m_item) {
+				switch (dl->cat) {
+					case IDownload::CAT_MAPS: {
+						LSL::usync().PrefetchMap(dl->name); //FIXME: do the same for games, too
+					}
+					break;
+
+					default:
+						continue;
+				}
+			}
+
+			//notify about finished download
+			GlobalEventManager::Instance()->Send(GlobalEventManager::OnUnitsyncReloaded);
+		}
+		if (m_lobbydl) {
+			GlobalEventManager::Instance()->Send(GlobalEventManager::OnLobbyDownloaded);
+		}
+		m_loader->freeResult(m_item);
+	}
+
+private:
+	void DownloadFinished(IDownload* dl)
+	{
+			switch (dl->cat) {
+				case IDownload::CAT_ENGINE_LINUX:
+				case IDownload::CAT_ENGINE_WINDOWS:
+				case IDownload::CAT_ENGINE_LINUX64:
+				case IDownload::CAT_ENGINE_MACOSX:
+					if (fileSystem->extractEngine(dl->name, dl->version) == false) {
+						wxLogError(_("Failed to extract downloaded engine!"));
+						break;
+					}
+					SlPaths::RefreshSpringVersionList(); //FIXME: maybe not thread-save!
+					SlPaths::SetUsedSpringIndex(dl->version);
+					//Inform all application components about new engine been available
+					GlobalEventManager::Instance()->Send(GlobalEventManager::OnUnitsyncReloaded);
+					break;
+
+				case IDownload::CAT_LOBBYCLIENTS:
+					m_lobbydl = true;
+					if (fileSystem->extract(dl->name, SlPaths::GetUpdateDir(), true) == false) {
+						wxLogError(_("Failed to extract downloaded lobby client!"));
+					}
+					break;
+
+				case IDownload::CAT_MAPS:
+				case IDownload::CAT_GAMES:
+					m_reload = true;
+					break;
+
+				default:
+					break;
+			}
 	}
 
 private:
 	std::list<IDownload*> m_item;
 	IDownloader* m_loader;
+	bool m_reload;
+	bool m_lobbydl;
 };
 
 class SearchItem : public LSL::WorkItem
@@ -141,11 +159,10 @@ void SearchItem::Run()
 {
 	rapidDownload->setOption("forceupdate", "");
 	std::list<IDownload*> results;
-	std::list<IDownloader*>::const_iterator it = m_loaders.begin();
-	for (; it != m_loaders.end(); ++it) {
-		(*it)->search(results, m_name, m_cat);
+	for (IDownloader* loader: m_loaders) {
+		loader->search(results, m_name, m_cat);
 		if (!results.empty()) {
-			DownloadItem* dl_item = new DownloadItem(results, *it);
+			DownloadItem* dl_item = new DownloadItem(results, loader);
 			prDownloader().m_dl_thread->DoWork(dl_item);
 			m_result_size = results.size();
 			return;
@@ -164,15 +181,16 @@ PrDownloader::PrDownloader()
 	UpdateSettings();
 	m_game_loaders.push_back(rapidDownload);
 	m_game_loaders.push_back(httpDownload);
-	//	m_game_loaders.push_back(plasmaDownload);
 	m_map_loaders.push_back(httpDownload);
-	//	m_map_loaders.push_back(plasmaDownload);
-	ConnectGlobalEvent(this, GlobalEvent::OnSpringStarted, wxObjectEventFunction(&PrDownloader::OnSpringStarted));
-	ConnectGlobalEvent(this, GlobalEvent::OnSpringTerminated, wxObjectEventFunction(&PrDownloader::OnSpringTerminated));
+	m_engine_loaders.push_back(httpDownload);
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnSpringStarted, wxObjectEventFunction(&PrDownloader::OnSpringStarted));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnSpringTerminated, wxObjectEventFunction(&PrDownloader::OnSpringTerminated));
 }
 
 PrDownloader::~PrDownloader()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
+
 	delete m_dl_thread;
 	m_dl_thread = nullptr;
 	IDownloader::Shutdown();
@@ -199,22 +217,22 @@ int PrDownloader::GetDownload(const std::string& category, const std::string& na
 	if (category == "engine") { //automaticly select engine from current platform
 		cat = PrDownloader::GetEngineCat();
 	}
-
-	if (cat == "map") {
-		return Get(m_map_loaders, name, IDownload::CAT_MAPS);
-	} else if (cat == "game") {
-		return Get(m_game_loaders, name, IDownload::CAT_GAMES);
-	} else if (cat == "engine_linux") {
-		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_LINUX);
-	} else if (cat == "engine_linux64") {
-		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_LINUX64);
-	} else if (cat == "engine_windows") {
-		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_WINDOWS);
-	} else if (cat == "engine_macosx") {
-		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_MACOSX);
+	const IDownload::category prcat = IDownload::getCatFromStr(cat);
+	switch(prcat) {
+		case IDownload::CAT_GAMES:
+			return Get(m_game_loaders, name, prcat);
+		case IDownload::CAT_MAPS:
+			return Get(m_map_loaders, name, prcat);
+		case IDownload::CAT_ENGINE_LINUX:
+		case IDownload::CAT_ENGINE_WINDOWS:
+		case IDownload::CAT_ENGINE_LINUX64:
+		case IDownload::CAT_ENGINE_MACOSX:
+			return Get(m_engine_loaders, name, prcat);
+		default:
+			break;
 	}
-	wxLogError(_T("Category %s not found"), category.c_str());
-	return -1;
+	wxLogWarning("Unhandled category: %s", category.c_str());
+	return false;
 }
 
 bool PrDownloader::Download(const std::string& filename, const std::string& url)
