@@ -17,42 +17,46 @@
 
 #include "aui/auimanager.h"
 #include "battlelisttab.h"
-#include "battlelistctrl.h"
+#include "battledataviewcttrl.h"
 #include "gui/ui.h"
 #include "gui/chatpanel.h"
 #include "utils/conversion.h"
 #include "gui/controls.h"
 #include "gui/uiutils.h"
-#include "gui/hosting/hostbattledialog_public.h"
+#include "gui/hosting/hostbattledialog.h"
 #include "gui/hosting/mainjoinbattletab.h"
 #include "iserver.h"
 #include "serverselector.h"
 #include "gui/mapctrl.h"
-#include "gui/nicklistctrl.h"
+#include "gui/nickdataviewctrl.h"
 #include "gui/mainwindow.h"
 #include "battlelistfilter.h"
 #include "iconimagelist.h"
 #include "useractions.h"
 #include "gui/customdialogs.h"
 #include "utils/slconfig.h"
+#include "utils/globalevents.h"
 #include "log.h"
+#include "servermanager.h"
+#include "contentmanager.h"
+#include "contentdownloadrequest.h"
+#include "exception.h"
 
 //const unsigned int BATTLELIST_COLUMNCOUNT = 10;
 
 BEGIN_EVENT_TABLE(BattleListTab, wxPanel)
-
-EVT_BUTTON(BattleListTab::BATTLE_JOIN, BattleListTab::OnJoin)
-EVT_BUTTON(BattleListTab::BATTLE_HOST, BattleListTab::OnHost)
-EVT_LIST_ITEM_ACTIVATED(BattleListCtrl::BLIST_LIST, BattleListTab::OnListJoin)
-EVT_LIST_ITEM_SELECTED(BattleListCtrl::BLIST_LIST, BattleListTab::OnSelect)
-EVT_CHECKBOX(BattleListTab::BATTLE_LIST_FILTER_ACTIV, BattleListTab::OnFilterActiv)
-#if wxUSE_TOGGLEBTN
-EVT_TOGGLEBUTTON(BattleListTab::BATTLE_LIST_FILTER_BUTTON, BattleListTab::OnFilter)
-EVT_TOGGLEBUTTON(BattleListTab::BATTLE_LIST_INFO_BUTTON, BattleListTab::OnInfoShow)
-#else
-EVT_CHECKBOX(BattleListTab::BATTLE_LIST_FILTER_BUTTON, BattleListTab::OnFilter)
-EVT_CHECKBOX(BattleListTab::BATTLE_LIST_INFO_BUTTON, BattleListTab::OnOnInfoShow)
-#endif
+	EVT_BUTTON(BattleListTab::BATTLE_JOIN, BattleListTab::OnJoin)
+	EVT_BUTTON(BattleListTab::BATTLE_HOST, BattleListTab::OnHost)
+	EVT_DATAVIEW_ITEM_ACTIVATED(BattleDataViewCtrl::BATTLELIST_DATAVIEW_ID, BattleListTab::OnListJoin)
+	EVT_DATAVIEW_SELECTION_CHANGED(BattleDataViewCtrl::BATTLELIST_DATAVIEW_ID, BattleListTab::OnSelect)
+	EVT_CHECKBOX(BattleListTab::BATTLE_LIST_FILTER_ACTIV, BattleListTab::OnFilterActiv)
+	#if wxUSE_TOGGLEBTN
+	EVT_TOGGLEBUTTON(BattleListTab::BATTLE_LIST_FILTER_BUTTON, BattleListTab::OnFilter)
+	EVT_TOGGLEBUTTON(BattleListTab::BATTLE_LIST_INFO_BUTTON, BattleListTab::OnInfoShow)
+	#else
+	EVT_CHECKBOX(BattleListTab::BATTLE_LIST_FILTER_BUTTON, BattleListTab::OnFilter)
+	EVT_CHECKBOX(BattleListTab::BATTLE_LIST_INFO_BUTTON, BattleListTab::OnOnInfoShow)
+	#endif
 END_EVENT_TABLE()
 
 SLCONFIG("/BattleFilter/Active", false, "determines if battle list filter is active");
@@ -73,8 +77,8 @@ BattleListTab::BattleListTab(wxWindow* parent)
 
 	m_battlelist_sizer = new wxBoxSizer(wxVERTICAL);
 
-	m_battle_list = new BattleListCtrl(this);
-	m_battle_list->SetHighLightAction(UserActions::ActHighlight);
+	m_battle_list = new BattleDataViewCtrl(_T("BattleDataViewCtrl_BattleList"), this);
+//	m_battle_list->SetHighLightAction(UserActions::ActHighlight);
 	m_battlelist_sizer->Add(m_battle_list, 1, wxEXPAND);
 
 	m_main_sizer->Add(m_battlelist_sizer, 1, wxEXPAND);
@@ -112,7 +116,7 @@ BattleListTab::BattleListTab(wxWindow* parent)
 
 	m_info_sizer->Add(m_data_sizer, 1, wxEXPAND, 5);
 
-	m_players = new NickListCtrl(this, false, 0, true, _T("battlelist_nicklist"));
+	m_players = new NickDataViewCtrl(_T("NickDataViewCtrl_BattleListTab"), this, false, 0, true);
 	m_info_sizer->Add(m_players, 1, wxALL | wxEXPAND, 5);
 
 	m_main_sizer->Add(m_info_sizer, 0, wxEXPAND, 5);
@@ -167,12 +171,14 @@ BattleListTab::BattleListTab(wxWindow* parent)
 
 	SelectBattle(0);
 	ShowExtendedInfos(cfg().ReadBool(_T("/BattleListTab/ShowExtendedInfos")));
-	ConnectGlobalEvent(this, GlobalEvent::OnUnitsyncReloaded, wxObjectEventFunction(&BattleListTab::OnUnitsyncReloaded));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnUnitsyncReloaded, wxObjectEventFunction(&BattleListTab::OnUnitsyncReloaded));
 }
 
 
 BattleListTab::~BattleListTab()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
+
 	if (m_filter != 0)
 		m_filter->SaveFilterValues();
 }
@@ -185,7 +191,7 @@ void BattleListTab::OnConnected()
 
 void BattleListTab::SetNumDisplayed()
 {
-	int num = m_battle_list->GetItemCount();
+	int num = m_battle_list->GetItemsCount();
 	m_battle_num->SetLabel(wxString::Format(_("%d battles displayed"), num));
 }
 
@@ -196,15 +202,10 @@ void BattleListTab::SelectBattle(IBattle* battle)
 	m_players->ClearUsers();
 	if (m_sel_battle != 0) {
 		m_map_text->SetLabel(TowxString(m_sel_battle->GetHostMapName()));
-		m_mod_text->SetLabel(TowxString(m_sel_battle->GetHostModName()));
+		m_mod_text->SetLabel(TowxString(m_sel_battle->GetHostGameName()));
 		m_players_text->SetLabel(wxString::Format(_T( "%d / %d" ), int(m_sel_battle->GetNumUsers()) - int(m_sel_battle->GetSpectators()), int(m_sel_battle->GetMaxPlayers())));
 		m_spec_text->SetLabel(wxString::Format(_T( "%d" ), m_sel_battle->GetSpectators()));
-		for (unsigned int i = 0; i < m_sel_battle->GetNumUsers(); i++) {
-			User& usr = m_sel_battle->GetUser(i);
-			if (usr.BattleStatus().IsBot())
-				continue;
-			m_players->AddUser(usr);
-		}
+		m_players->SetUsers(m_sel_battle->GetUsers());
 	} else {
 		m_map_text->SetLabel(wxEmptyString);
 		m_mod_text->SetLabel(wxEmptyString);
@@ -253,7 +254,6 @@ void BattleListTab::UpdateBattle(IBattle& battle)
 		if (&battle == m_sel_battle) {
 			m_sel_battle = NULL;
 			SelectBattle(NULL);
-			m_battle_list->SetSelectedIndex(-1);
 		}
 		return;
 	}
@@ -262,7 +262,9 @@ void BattleListTab::UpdateBattle(IBattle& battle)
 		SelectBattle(m_sel_battle);
 }
 
-
+/**
+ * Process "Disconnected From Server" global event
+ */
 void BattleListTab::OnDisconnected()
 {
 	SelectBattle(0);
@@ -273,19 +275,14 @@ void BattleListTab::OnDisconnected()
 
 void BattleListTab::UpdateList()
 {
-	m_battle_list->SetSelectedIndex(-1);
-
 	serverSelector().GetServer().battles_iter->IteratorBegin();
 	while (!serverSelector().GetServer().battles_iter->EOL()) {
 		IBattle* b = serverSelector().GetServer().battles_iter->GetBattle();
 		if (b != 0)
 			UpdateBattle(*b);
 	}
-	m_battle_list->SortList(true);
-	m_battle_list->RefreshVisibleItems();
-
-	if (m_sel_battle != NULL)
-		m_battle_list->SetSelectedIndex(m_battle_list->GetIndexFromData(m_sel_battle));
+	m_battle_list->Resort();
+	m_battle_list->Refresh();
 }
 
 
@@ -294,12 +291,11 @@ void BattleListTab::SetFilterActiv(bool activ)
 	m_filter->SetActiv(activ);
 	m_filter_activ->SetValue(activ);
 	cfg().Write(_T( "/BattleFilter/Active" ), activ);
-	m_battle_list->MarkDirtySort();
 }
 
 void BattleListTab::OnHost(wxCommandEvent& /*unused*/)
 {
-	if (!ui().IsConnected()) {
+	if (!ServerManager::Instance()->IsConnected()) {
 		wxLogWarning(_T( "Trying to host while offline" ));
 		customMessageBoxNoModal(SL_MAIN_ICON, _("You cannot host a game while being offline. Please connect to a lobby server."), _("Not Online."), wxOK);
 		ui().ShowConnectWindow();
@@ -316,10 +312,13 @@ void BattleListTab::OnHost(wxCommandEvent& /*unused*/)
 		}
 	}
 
-	SL::RunHostBattleDialog(this);
+	HostBattleDialog::RunHostBattleDialog(this);
 }
 
-
+/**
+ * Procees "Show Filtes" toggle buttton clicked. Show/hides filters options panel
+ * @param
+ */
 void BattleListTab::OnFilter(wxCommandEvent& /*unused*/)
 {
 	if (m_filter_show->GetValue()) {
@@ -331,11 +330,14 @@ void BattleListTab::OnFilter(wxCommandEvent& /*unused*/)
 	}
 }
 
-
+/**
+ * Process "Turn On Filters" button event. Activates/deactivates battlelist filtering
+ * @param
+ */
 void BattleListTab::OnFilterActiv(wxCommandEvent& /*unused*/)
 {
 	bool active = m_filter_activ->GetValue();
-	if (!ui().IsConnected()) {
+	if (!ServerManager::Instance()->IsConnected()) {
 		m_filter_activ->SetValue(!active);
 		return;
 	}
@@ -344,47 +346,47 @@ void BattleListTab::OnFilterActiv(wxCommandEvent& /*unused*/)
 	SetNumDisplayed();
 }
 
+/**
+ * Process "JOIN" button clicked. Join selected battle, if any
+ * @param
+ */
 void BattleListTab::OnJoin(wxCommandEvent& /*unused*/)
 {
-	try {
-		ASSERT_LOGIC(m_battle_list != 0, "m_battle_list = 0");
-	} catch (...) {
-		return;
-	}
+	wxASSERT(m_battle_list != nullptr);
 
 	//Is there any battle selected?
-	if (m_battle_list->GetSelectedIndex() < 0) {
+	const IBattle* battle = m_battle_list->GetSelectedItem();
+	if (battle == nullptr) {
 		return;
 	}
 
-	const IBattle* battle = m_battle_list->GetSelectedData();
-	try {
-		ASSERT_LOGIC(battle != NULL, "battle == null");
-	} catch (...) {
-		return;
-	}
 	const int id = battle->GetBattleId();
 	DoJoin(serverSelector().GetServer().battles_iter->GetBattle(id));
 }
 
-
-void BattleListTab::OnListJoin(wxListEvent& event)
+/**
+ * Process double clicking on battle in battlelist. Join selected battle
+ * @param event Selected battle
+ */
+void BattleListTab::OnListJoin(wxDataViewEvent& /*event*/)
 {
-	try {
-		ASSERT_LOGIC(m_battle_list != 0, "m_battle_list = 0");
-	} catch (...) {
+	wxASSERT(m_battle_list != nullptr);
+
+	IBattle* battle = m_battle_list->GetSelectedItem();
+	if (battle == nullptr) {
 		return;
 	}
 
-	//TODO: This "crunch" selects item that is being double clicked
-	//Should solve some problems with wxListCtrl under Windows
-	m_battle_list->OnSelected(event);
+	SelectBattle(battle);
 
-	int id = m_battle_list->GetSelectedData()->GetBattleId();
+	int id = battle->GetBattleId();
 	DoJoin(serverSelector().GetServer().battles_iter->GetBattle(id));
 }
 
-
+/**
+ * Check conditions for joining battle and try to join
+ * @param battle Battle been joined
+ */
 void BattleListTab::DoJoin(IBattle& battle)
 {
 	wxString password = wxEmptyString;
@@ -420,28 +422,47 @@ void BattleListTab::DoJoin(IBattle& battle)
 	}
 
 	//Check if some content needs to be downloaded
-	if (!ui().DownloadArchives(battle)) {
-		//There is content needed but user reject it tobe downloaded
-		//or some error happend
-		return;
+	ContentDownloadRequest req = ContentManager::Instance()->WhatContentForBattleIsRequired(battle);
+	if (req.IsSomethingNeeded()) {
+		if (wxYES == customMessageBox(SL_MAIN_ICON,
+				TowxString(req.GetRequiredContentAsString()) + _("Shall I download it for you?"),
+				_("Content is needed"),
+				wxYES_NO | wxICON_QUESTION)) {
+			try {
+				ContentManager::Instance()->DownloadContent(req);
+			} catch (Exception& e) {
+				wxLogError(e.Reason());
+				return;
+			}
+		} else {
+			return;
+		}
 	}
 
 	battle.Join(STD_STRING(password));
+	//Change Tab to show user joining to battle is in progress
+	ui().mw().ShowTab(MainWindow::PAGE_JOIN);
 }
 
-
-void BattleListTab::OnSelect(wxListEvent& event)
+/**
+ * Process "select" for battlelist. Selects currentbattle for info panel.
+ * @param event Battle been selected
+ */
+void BattleListTab::OnSelect(wxDataViewEvent& /*event*/)
 {
-	if (event.GetIndex() == -1) {
-		SelectBattle(0);
+	IBattle* battle = m_battle_list->GetSelectedItem();
+	if (battle == nullptr) {
+		SelectBattle(nullptr);
 		return;
+	} else {
+		SelectBattle(battle);
 	}
-	IBattle* b = (m_battle_list->GetSelectedData());
-	if (b != 0)
-		SelectBattle(b);
 }
 
-
+/**
+ * Global event handler. Fires when unitsync library is reloaded
+ * @param
+ */
 void BattleListTab::OnUnitsyncReloaded(wxCommandEvent& /*data*/)
 {
 	ASSERT_LOGIC(wxThread::IsMain(), "wxThread::IsMain() == false");
@@ -454,13 +475,13 @@ void BattleListTab::OnUnitsyncReloaded(wxCommandEvent& /*data*/)
 
 void BattleListTab::UpdateHighlights()
 {
-	m_battle_list->RefreshVisibleItems();
+	m_battle_list->Refresh();
 }
 
 
 void BattleListTab::SortBattleList()
 {
-	m_battle_list->SortList();
+	m_battle_list->Resort();
 }
 
 void BattleListTab::ShowExtendedInfos(bool show)
