@@ -19,6 +19,7 @@
 #include <wx/dataobj.h>
 #include <wx/bmpbuttn.h>
 #include <wx/stattext.h>
+#include <wx/wupdlock.h>
 
 #include "aui/auimanager.h"
 #include "gui/slbook.h"
@@ -28,7 +29,7 @@
 #include "iserver.h"
 #include "serverselector.h"
 #include "ibattle.h"
-#include "nicklistctrl.h"
+#include "nickdataviewctrl.h"
 #include "mainwindow.h"
 #include "chatpanelmenu.h"
 #include "gui/pastedialog.h"
@@ -36,23 +37,24 @@
 #include "log.h"
 #include "utils/slconfig.h"
 #include "gui/hosting/votepanel.h"
+#include "utils/globalevents.h"
+#include "iconimagelist.h"
+#include "gui/controls.h"
 
 BEGIN_EVENT_TABLE(ChatPanel, wxPanel)
-
-EVT_TEXT_ENTER(CHAT_TEXT, ChatPanel::OnSay)
-EVT_TEXT_PASTE(CHAT_TEXT, ChatPanel::OnPaste)
-EVT_BUTTON(CHAT_CHAN_OPTS, ChatPanel::OnChanOpts)
-EVT_BUTTON(CHAT_SEND, ChatPanel::OnSay)
-EVT_TEXT_URL(CHAT_LOG, ChatPanel::OnLinkEvent)
-EVT_MENU(wxID_ANY, ChatPanel::OnMenuItem)
-EVT_TEXT(FILTER_USERS, ChatPanel::OnFilterUsers)
-
+	EVT_TEXT_ENTER(CHAT_TEXT, ChatPanel::OnSay)
+	EVT_TEXT_PASTE(CHAT_TEXT, ChatPanel::OnPaste)
+	EVT_BUTTON(CHAT_CHAN_OPTS, ChatPanel::OnChanOpts)
+	EVT_BUTTON(CHAT_SEND, ChatPanel::OnSay)
+	EVT_TEXT_URL(CHAT_LOG, ChatPanel::OnLinkEvent)
+	EVT_MENU(wxID_ANY, ChatPanel::OnMenuItem)
+	EVT_TEXT(FILTER_USERS, ChatPanel::OnFilterUsers)
+	EVT_CHECKBOX(SHOW_PLAYERS_ONLY_CHECK, ChatPanel::OnShowPlayerOnlyCheck)
 END_EVENT_TABLE()
 
-static const wxString chan_prefix = _("channel_");
 
 SLCONFIG("/Channel/bridgebot", (const wxString&) _T("TIZBOT"), "Name of the Bridgebot (which forwards traffic between #sy and irc channels)");
-
+SLCONFIG("/GUI/ShowPromotions", true, "Show promotion messages as popup");
 
 /// table for irc colors
 static wxColor m_irc_colors[16] = {
@@ -76,12 +78,21 @@ static wxColor m_irc_colors[16] = {
 void ChatPanel::Init(const wxString& panelname)
 {
 	m_chatpanelname = panelname;
+
+	//Clear some controls pointer that can be used in ReadSettings
+	m_say_text = nullptr;
+	m_chatlog_text = nullptr;
+
+	//Read settings
+	ReadSettings();
 	CreateControls();
 	SetLogFile(panelname);
-	m_display_joinitem = cfg().Read(_T( "/Channels/DisplayJoinLeave/" ) + m_chatpanelname, m_display_joinitem);
+
 	GetAui().manager->AddPane(this, wxLEFT, _T("chatpanel-channel-") + panelname);
 	m_chatlog_text->Connect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(ChatPanel::OnMouseDown), 0, this);
-	ConnectGlobalEvent(this, GlobalEvent::OnLogin, wxObjectEventFunction(&ChatPanel::OnLogin));
+
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnLogin, wxObjectEventFunction(&ChatPanel::OnLogin));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::ApplicationSettingsChangedEvent, wxObjectEventFunction(&ChatPanel::OnSettingsChanged));
 }
 
 ChatPanel::ChatPanel(wxWindow* parent, Channel& chan, wxImageList* imaglist)
@@ -101,13 +112,14 @@ ChatPanel::ChatPanel(wxWindow* parent, Channel& chan, wxImageList* imaglist)
     , m_disable_append(false)
     , m_display_joinitem(false)
     , m_topic_set(false)
+    , m_reactOnPromoteEvents(true)
 {
 	Init(TowxString(chan.GetName()));
 	SetChannel(&chan);
 }
 
 
-ChatPanel::ChatPanel(wxWindow* parent, const User& user, wxImageList* imaglist)
+ChatPanel::ChatPanel(wxWindow* parent, User& user, wxImageList* imaglist)
     : wxPanel(parent, -1)
     , m_show_nick_list(false)
     , m_votePanel(0)
@@ -124,6 +136,7 @@ ChatPanel::ChatPanel(wxWindow* parent, const User& user, wxImageList* imaglist)
     , m_disable_append(false)
     , m_display_joinitem(true)
     , m_topic_set(false)
+    , m_reactOnPromoteEvents(false)
 {
 	Init(_T("chatpanel-pm-") + TowxString(user.GetNick()));
 	SetUser(&user);
@@ -147,6 +160,7 @@ ChatPanel::ChatPanel(wxWindow* parent, IServer& serv, wxImageList* imaglist)
     , m_disable_append(false)
     , m_display_joinitem(false)
     , m_topic_set(false)
+    , m_reactOnPromoteEvents(false)
 {
 	Init(_T("chatpanel-server"));
 	SetServer(&serv);
@@ -168,6 +182,7 @@ ChatPanel::ChatPanel(wxWindow* parent, IBattle* battle)
     , m_disable_append(false)
     , m_display_joinitem(true)
     , m_topic_set(false)
+    , m_reactOnPromoteEvents(false)
 {
 	Init(_T("BATTLE"));
 	SetBattle(battle);
@@ -188,6 +203,7 @@ ChatPanel::ChatPanel(wxWindow* parent)
     , m_disable_append(false)
     , m_display_joinitem(true)
     , m_topic_set(false)
+    , m_reactOnPromoteEvents(false)
 {
 	Init(_T("debug"));
 }
@@ -195,21 +211,24 @@ ChatPanel::ChatPanel(wxWindow* parent)
 //! @brief ChatPanel destructor.
 ChatPanel::~ChatPanel()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
+
 	if (m_server != 0) {
-		if (m_server->uidata.panel == this)
-			m_server->uidata.panel = 0;
+		if (m_server->panel == this)
+			m_server->panel = 0;
 	}
 	if (m_user != 0) {
-		if (m_user->uidata.panel == this)
-			m_user->uidata.panel = 0;
+		if (m_user->panel == this)
+			m_user->panel = nullptr;
 	}
 	if (m_channel != 0) {
-		if (m_channel->uidata.panel == this)
-			m_channel->uidata.panel = 0;
+		if (m_channel->panel == this)
+			m_channel->panel = nullptr;
 	}
 	cfg().Write(_T( "/Channels/DisplayJoinLeave/" ) + m_chatpanelname, m_display_joinitem);
 
 	m_chatlog_text->Disconnect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(ChatPanel::OnMouseDown), 0, 0);
+	wxDELETE(m_chatlog_text);
 
 	if (GetAui().manager) {
 		GetAui().manager->DetachPane(this);
@@ -219,8 +238,6 @@ ChatPanel::~ChatPanel()
 
 void ChatPanel::CreateControls()
 {
-	slLogDebugFunc("");
-
 	// Creating sizers
 	m_main_sizer = new wxBoxSizer(wxHORIZONTAL);
 	m_chat_sizer = new wxBoxSizer(wxVERTICAL);
@@ -235,22 +252,29 @@ void ChatPanel::CreateControls()
 
 		m_nick_sizer = new wxBoxSizer(wxVERTICAL);
 		m_usercount_label = new wxStaticText(m_nick_panel, wxID_ANY, wxEmptyString);
+		m_showPlayerOnlyCheck = new wxCheckBox(m_nick_panel, SHOW_PLAYERS_ONLY_CHECK, _("Hide bots"));
+
+		wxBoxSizer* nickListHeaderSizer = new wxBoxSizer(wxHORIZONTAL);
+		nickListHeaderSizer->Add(m_usercount_label, 1, wxEXPAND);
+		nickListHeaderSizer->Add(m_showPlayerOnlyCheck, 0, wxEXPAND);
+
 		UpdateUserCountLabel();
 		CreatePopup(); //ensures m_popup_menu is constructed
 		//SL_GENERIC::UserMenu<ChatPanelMenu>* usermenu  = m_popup_menu->GetUserMenu();
-		m_nicklist = new NickListCtrl(m_nick_panel, true, m_popup_menu);
+		m_nicklist = new NickDataViewCtrl(_T("NickDataViewCtrl_ChatPanel"), m_nick_panel, true, m_popup_menu);
 
 		// m_nick_filter = new wxComboBox( m_nick_panel, -1, _("Show all"), wxDefaultPosition, wxSize(80,CONTROL_HEIGHT), 0, 0, wxCB_READONLY );
 		// m_nick_filter->Disable();
 
 		m_nick_filter = new wxTextCtrl(m_nick_panel, FILTER_USERS);
-		m_nick_sizer->Add(m_usercount_label, 0);
 		m_nick_sizer->Add(m_nicklist, 1, wxEXPAND);
+		m_nick_sizer->Add(nickListHeaderSizer, 0, wxEXPAND);
 		m_nick_sizer->Add(m_nick_filter, 0, wxEXPAND);
 		// m_nick_sizer->Add( m_nick_filter, 0, wxEXPAND | wxTOP, 2 );
 
 		m_nick_panel->SetSizer(m_nick_sizer);
-
+		m_nicklist->UserFilterShowPlayersOnly(m_ShowPlayersOnlyFlag);
+		m_showPlayerOnlyCheck->SetValue(m_ShowPlayersOnlyFlag);
 	} else {
 
 		m_chat_panel = this;
@@ -312,9 +336,8 @@ void ChatPanel::CreateControls()
 		m_splitter->SetSashPosition(s.GetWidth() - 238, true);
 	}
 
-	m_chatlog_text->SetBackgroundColour(sett().GetChatColorBackground());
 	m_chatlog_text->ShowPosition(m_chatlog_text->GetLastPosition());
-
+	m_chatlog_text->SetBackgroundColour(sett().GetChatColorBackground());
 	m_say_text->SetBackgroundColour(sett().GetChatColorBackground());
 	m_say_text->SetForegroundColour(sett().GetChatColorNormal());
 
@@ -336,7 +359,7 @@ void ChatPanel::CreatePopup()
 	m_popup_menu = new ChatPanelMenu(this);
 }
 
-const User* ChatPanel::GetSelectedUser() const
+User* ChatPanel::GetSelectedUser() const
 {
 	if (m_type == CPT_User) {
 		return m_user;
@@ -344,10 +367,7 @@ const User* ChatPanel::GetSelectedUser() const
 	if (!m_show_nick_list || (m_nicklist == 0))
 		return 0;
 
-	if (m_nicklist->GetSelectedItemCount() > 0)
-		return m_nicklist->GetSelectedData();
-	else
-		return 0;
+	return m_nicklist->GetSelectedItem();
 }
 
 
@@ -387,17 +407,8 @@ void ChatPanel::OutputLine(const wxString& message, const wxColour& col, bool sh
 
 void ChatPanel::OutputLine(const ChatLine& line)
 {
-	const int pos = m_chatlog_text->GetScrollPos(wxVERTICAL);   // vertical scrolled window position
-	const int end = m_chatlog_text->GetScrollRange(wxVERTICAL); // hight of complete scolled window
-	const int height = m_chatlog_text->GetSize().GetHeight();
 	const int numOfLines = m_chatlog_text->GetNumberOfLines();
 	const int maxlength = sett().GetChatHistoryLenght();
-	float original_pos = (float)(pos + height) / (float)end;
-
-	if (original_pos < 0.0f)
-		original_pos = 0.0f;
-	if (original_pos > 1.0f)
-		original_pos = 1.0f;
 
 	// crop lines from history that exceeds limit
 	if ((maxlength > 0) && (numOfLines > maxlength)) {
@@ -504,6 +515,7 @@ void ChatPanel::OnSay(wxCommandEvent& /*unused*/)
 void ChatPanel::OnFilterUsers(wxCommandEvent& /*unused*/)
 {
 	m_nicklist->SetUsersFilterString(m_nick_filter->GetValue());
+	UpdateUserCountLabel();
 }
 
 void ChatPanel::OnPaste(wxClipboardTextEvent& event)
@@ -585,6 +597,32 @@ bool ChatPanel::ContainsWordToHighlight(const wxString& message) const
 	return false;
 }
 
+/**
+ *	Check if there is "promote" event and notify user if needed
+ */
+void ChatPanel::CheckForPromotion(const wxString& /*who*/, const wxString& action)
+{
+	if (m_reactOnPromoteEvents == false) { //If this feature disabled in options do nothing
+		return;
+	}
+
+	//TODO: Make promote templates be user-configurable and uses regexp
+	const wxString promoteMessageTemplate = _T(" player(s) needed for battle \"");
+	const wxString promoteMessageTemplate2 = _T("). Come play and enjoy !");
+
+	//Detect event and notify user
+	//TODO: Rework for using array of regexps, not shit crap
+	if (action.Contains(promoteMessageTemplate) || action.Contains(promoteMessageTemplate2)) {
+		wxCommandEvent promoteEvent = wxCommandEvent(GlobalEventManager::GamePromotedEvent);
+		promoteEvent.SetString(action); //Send action string with that should be shown
+		GlobalEventManager::Instance()->Send(promoteEvent);
+	}
+}
+
+/**
+ * Process text sent by the server, not users
+ * Check for vote events, promote events and something else
+ */
 void ChatPanel::DidAction(const wxString& who, const wxString& action)
 {
 	//Handle vote events in chat by VotePanel
@@ -592,6 +630,9 @@ void ChatPanel::DidAction(const wxString& who, const wxString& action)
 		m_votePanel->OnChatAction(who, action);
 	}
 
+	//Look for "promote" notifications from server
+	CheckForPromotion(who, action);
+
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_say);
 	OutputLine(_T( " * " ) + who + _T( " " ) + action, sett().GetChatColorAction());
@@ -663,7 +704,7 @@ void ChatPanel::Joined(User& who)
 		OutputLine(_T( " ** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
 	}
 
-	if (m_show_nick_list && (m_nicklist != 0)) {
+	if (m_show_nick_list && (m_nicklist != nullptr)) {
 		m_nicklist->AddUser(who);
 		UpdateUserCountLabel();
 	}
@@ -674,7 +715,7 @@ void ChatPanel::Joined(User& who)
 void ChatPanel::OnChannelJoin(User& who)
 {
 	//    assert( m_type == CPT_Channel || m_type == CPT_Server || m_type == CPT_Battle || m_type == CPT_User );
-	if (m_show_nick_list && (m_nicklist != 0)) {
+	if (m_show_nick_list && (m_nicklist != nullptr)) {
 		m_nicklist->AddUser(who);
 		UpdateUserCountLabel();
 	}
@@ -691,14 +732,14 @@ void ChatPanel::Parted(User& who, const wxString& message)
 	const bool me_parted = m_channel && &who == &m_channel->GetMe();
 	const wxString nick = TowxString(who.GetNick());
 	const bool wasactive = m_active_users.erase(nick) > 0;
-	if (m_display_joinitem || wasactive) {
+	if (m_display_joinitem || (wasactive && !who.IsBot())) {
 		OutputLine(_T( " ** " ) + wxString::Format(_("%s left %s (%s)."), nick.c_str(), GetChatTypeStr().c_str(), message.c_str()), sett().GetChatColorJoinPart());
 	}
 	if (m_type == CPT_Channel) {
 		if (m_channel == 0)
 			return;
 		if (me_parted) {
-			m_channel->uidata.panel = 0;
+			m_channel->panel = nullptr;
 			SetChannel(0);
 			return;
 		}
@@ -708,7 +749,7 @@ void ChatPanel::Parted(User& who, const wxString& message)
 		}
 	} else if (m_type == CPT_Server && me_parted)
 		return;
-	if (m_show_nick_list && (m_nicklist != 0)) {
+	if (m_show_nick_list && (m_nicklist != nullptr)) {
 		m_nicklist->RemoveUser(who);
 		UpdateUserCountLabel();
 	}
@@ -746,7 +787,7 @@ void ChatPanel::UserStatusUpdated(User& who)
 	if ((m_type == CPT_User) && (m_user == &who) && (m_chan_opts_button != NULL)) {
 		m_chan_opts_button->SetBitmapLabel(icons().GetBitmap(icons().GetUserListStateIcon(who.GetStatus(), false, who.GetBattle() != 0)));
 	}
-	if (!m_show_nick_list || (m_nicklist == 0))
+	if (!m_show_nick_list || (m_nicklist == nullptr))
 		return;
 	try {
 		m_nicklist->UserUpdated(who);
@@ -766,15 +807,15 @@ void ChatPanel::SetChannel(Channel* chan)
 	ASSERT_LOGIC(m_type == CPT_Channel, "Not of type channel");
 
 	if ((chan == 0) && (m_channel != 0)) {
-		m_channel->uidata.panel = 0;
+		m_channel->panel = nullptr;
 	}
-	if (m_nicklist != 0) {
+	if (m_nicklist != nullptr) {
 		m_nicklist->ClearUsers();
 		UpdateUserCountLabel();
 	}
 
 	if (chan != 0) {
-		chan->uidata.panel = this;
+		chan->panel = this;
 		if (chan != m_channel) {
 			SetLogFile(TowxString(chan->GetName()));
 		}
@@ -794,18 +835,17 @@ const IServer* ChatPanel::GetServer() const
 void ChatPanel::SetServer(IServer* serv)
 {
 	ASSERT_LOGIC(m_type == CPT_Server, "Not of type server");
-	if (m_nicklist != NULL) {
-		m_nicklist->StopTimer();
+	if (m_nicklist != nullptr) {
 		m_nicklist->ClearUsers();
 		UpdateUserCountLabel();
 	}
-	if (serv != 0) {
+
+	if (serv != nullptr) {
 		SetLogFile(_T("server"));
-		serv->uidata.panel = this;
-		if (m_nicklist != NULL)
-			m_nicklist->StartTimer();
-	} else if (m_server != 0) {
-		m_server->uidata.panel = 0;
+		serv->panel = this;
+	}
+	if (m_server != nullptr) {
+		m_server->panel = 0;
 	}
 	m_server = serv;
 }
@@ -815,19 +855,19 @@ const User* ChatPanel::GetUser() const
 	return m_user;
 }
 
-void ChatPanel::SetUser(const User* usr)
+void ChatPanel::SetUser(User* usr)
 {
 	ASSERT_LOGIC(m_type == CPT_User, "Not of type user");
 
 	if (usr == NULL) {
 		if (m_user != NULL) {
-			m_user->uidata.panel = 0;
+			m_user->panel = nullptr;
 			if (m_chan_opts_button != NULL) {
 				m_chan_opts_button->SetBitmapLabel(icons().GetBitmap(icons().ICON_EMPTY));
 			}
 		}
 	} else {
-		usr->uidata.panel = this;
+		usr->panel = this;
 		if (m_chan_opts_button != NULL) {
 			const wxBitmap icon = icons().GetBitmap(icons().GetUserListStateIcon(usr->GetStatus(), false, usr->GetBattle() != 0));
 			m_chan_opts_button->SetBitmapLabel(icon);
@@ -953,7 +993,7 @@ bool ChatPanel::Say(const wxString& message)
 				try {
 					Channel& chan = m_server->GetChannel(STD_STRING(channame));
 					chan.Leave();
-					chan.uidata.panel = 0;
+					chan.panel = 0;
 				} catch (assert_exception) {
 				}
 			}
@@ -972,7 +1012,7 @@ void ChatPanel::Part()
 		if (m_channel == 0)
 			return;
 		m_channel->Leave();
-		m_channel->uidata.panel = 0;
+		m_channel->panel = 0;
 	}
 }
 
@@ -1058,15 +1098,15 @@ void ChatPanel::OnMouseDown(wxMouseEvent& event)
 
 void ChatPanel::UpdateNicklistHighlights()
 {
-	if (m_show_nick_list && (m_nicklist != 0)) {
-		m_nicklist->RefreshVisibleItems();
+	if (m_show_nick_list && (m_nicklist != nullptr)) {
+		m_nicklist->Refresh();
 	}
 }
 
 void ChatPanel::SortNickList()
 {
 	if (m_show_nick_list && (m_nicklist != 0))
-		m_nicklist->SortList();
+		m_nicklist->Resort();
 }
 
 void ChatPanel::SetIconHighlight(HighlightType highlight)
@@ -1147,8 +1187,19 @@ void ChatPanel::SetBattle(IBattle* battle)
 
 void ChatPanel::OnLogin(wxCommandEvent& /*data*/)
 {
-	if (m_type == CPT_Channel && m_channel) {
-		m_channel->Rejoin();
+	switch (m_type) {
+		case CPT_Channel:
+			if (m_channel) {
+				m_channel->Rejoin();
+			}
+			break;
+		case CPT_Server:
+			m_nicklist->SetUsers(m_server->GetUserList().GetUsers());
+			UpdateUserCountLabel();
+		case CPT_Battle:
+		case CPT_User:
+		case CPT_Debug:
+			break;
 	}
 }
 
@@ -1173,16 +1224,62 @@ void ChatPanel::SetVotePanel(VotePanel* votePanel)
 	m_votePanel->SetChatPanel(this);
 }
 
+/**
+ * Update User Count label on top of users list
+ * If available shows filtered number of users
+ */
 void ChatPanel::UpdateUserCountLabel()
 {
 	if (m_usercount_label == NULL)
 		return;
 
 	unsigned int numusers = 0;
+
+	//Regular channel
 	if ((m_type == CPT_Channel) && (GetChannel() != nullptr)) {
-		numusers = GetChannel()->GetNumUsers();
+		if (m_nicklist != nullptr) {
+			numusers = m_nicklist->GetUsersCount();
+		} else {
+			numusers = GetChannel()->GetNumUsers();
+		}
+		//Server channel
 	} else if ((m_type == CPT_Server) && (m_server != NULL)) {
-		numusers = m_server->GetNumUsers();
+		if (m_nicklist != nullptr) {
+			numusers = m_nicklist->GetUsersCount();
+		} else {
+			numusers = m_server->GetNumUsers();
+		}
 	}
+	//Update label
 	m_usercount_label->SetLabel(wxString::Format(_("%d users"), numusers));
 }
+
+
+void ChatPanel::OnShowPlayerOnlyCheck(wxCommandEvent& event)
+{
+	m_nicklist->UserFilterShowPlayersOnly(event.IsChecked());
+	UpdateUserCountLabel();
+}
+
+void ChatPanel::OnSettingsChanged(wxCommandEvent&)
+{
+	ReadSettings();
+}
+
+void ChatPanel::ReadSettings()
+{
+
+	m_reactOnPromoteEvents = cfg().ReadBool("/GUI/ShowPromotions");
+	m_display_joinitem = cfg().Read(_T( "/Channels/DisplayJoinLeave/" ) + m_chatpanelname, m_display_joinitem);
+
+	//Hide bots by default
+	m_ShowPlayersOnlyFlag = true;
+
+	if (m_chatlog_text != nullptr) {
+		m_chatlog_text->SetBackgroundColour(sett().GetChatColorBackground());
+	}
+	if (m_say_text != nullptr) {
+		m_say_text->SetBackgroundColour(sett().GetChatColorBackground());
+		m_say_text->SetForegroundColour(sett().GetChatColorNormal());
+	}
+}
