@@ -5,13 +5,13 @@
 
 #include <wx/panel.h>
 #include <wx/textctrl.h>
+#include <wx/checkbox.h>
 #include <vector>
 #include <set>
 
 #include "chatlog.h"
 #include "utils/TextCompletionDatabase.h"
 #include "utils/mixins.h"
-#include "utils/globalevents.h"
 
 class wxCommandEvent;
 class wxSizeEvent;
@@ -23,7 +23,7 @@ class wxTextUrlEvent;
 class wxComboBox;
 class wxButton;
 class wxBitmapButton;
-class NickListCtrl;
+class NickDataViewCtrl;
 class Channel;
 class User;
 class ChatLog;
@@ -63,14 +63,14 @@ struct ChatLine
  * The nick list is optional and can be removed by setting show_nick_list in the
  * constructor to false.
  */
-class ChatPanel : public wxPanel, public GlobalEvent, public SL::NonCopyable
+class ChatPanel : public wxPanel, public SL::NonCopyable
 {
 public:
 	ChatPanel(wxWindow* parent, Channel& chan, wxImageList* imaglist);
-	ChatPanel(wxWindow* parent, const User& user, wxImageList* imaglist);
+	ChatPanel(wxWindow* parent, User& user, wxImageList* imaglist);
 	ChatPanel(wxWindow* parent, IServer& serv, wxImageList* imaglist);
 	ChatPanel(wxWindow* parent, IBattle* battle);
-	ChatPanel(wxWindow* parent); //debug chatpanel
+	explicit ChatPanel(wxWindow* parent); //debug chatpanel
 	~ChatPanel();
 
 	void Said(const wxString& who, const wxString& message);
@@ -94,7 +94,7 @@ public:
 	void SetServer(IServer* serv);
 
 	const User* GetUser() const;
-	void SetUser(const User* usr);
+	void SetUser(User* usr);
 
 	ChatPanelType GetPanelType() const;
 
@@ -123,16 +123,23 @@ public:
 	bool Say(const wxString& message);
 
 private:
+	enum HighlightType {
+		highlight_say,
+		highlight_join_leave,
+		highlight_important
+	};
+
 	void Init(const wxString& panelname);
 	//! @returns true on success ( blank line ), false otherwise
 
 	wxString GetChatTypeStr() const;
 
 	const User& GetMe() const;
-	const User* GetSelectedUser() const;
+	User* GetSelectedUser() const;
 
 	void SortNickList();
 	void OnFilterUsers(wxCommandEvent&);
+	void OnShowPlayerOnlyCheck(wxCommandEvent&);
 
 	void OnChanOpts(wxCommandEvent& event);
 	void OnSay(wxCommandEvent& event);
@@ -156,17 +163,22 @@ private:
 	void SetLogFile(const wxString& name);
 	void UpdateUserCountLabel();
 
-	enum HighlightType {
-		highlight_say,
-		highlight_join_leave,
-		highlight_important
-	};
-
 	void SetIconHighlight(HighlightType highlight);
 	wxString FindUrl(const long pos) const;
 
 	bool ContainsWordToHighlight(const wxString& message) const;
+
+	void LogTime();
+	void CreateControls();
+	void CreatePopup();
+	void CheckForPromotion(const wxString& who, const wxString& action);
+
+	void OnSettingsChanged(wxCommandEvent&);
+
+private:
+	void ReadSettings();
 	bool m_show_nick_list; //!< If the nicklist should be shown or not.
+	bool m_ShowPlayersOnlyFlag;
 
 	VotePanel* m_votePanel;
 
@@ -175,16 +187,16 @@ private:
 	wxBoxSizer* m_say_sizer;  //!< Sizer containing send input and button.
 	wxBoxSizer* m_nick_sizer; //!< Sizer containing the nicklist.
 
-	wxSplitterWindow* m_splitter; //!< The splitter.
-	wxPanel* m_chat_panel;	//!< Panel containing the chat. Only used when nicklist is visible.
-	wxPanel* m_nick_panel;	//!< Panel containing the nicklist.
-	wxTextCtrl* m_nick_filter;    //!< Textcontrol for filtering nicklist
-
+	wxSplitterWindow* m_splitter;       //!< The splitter.
+	wxPanel* m_chat_panel;		    //!< Panel containing the chat. Only used when nicklist is visible.
+	wxPanel* m_nick_panel;		    //!< Panel containing the nicklist.
+	wxTextCtrl* m_nick_filter;	  //!< Textcontrol for filtering nicklist
+	wxCheckBox* m_showPlayerOnlyCheck;  //!< CheckBox for showing only live players (not bots)
 	wxTextCtrl* m_chatlog_text;	 //!< The chat log textcontrol.
 	wxTextCtrlHist* m_say_text;	 //!< The say textcontrol.
 	wxBitmapButton* m_chan_opts_button; //!< The channel options button.
 
-	NickListCtrl* m_nicklist; //!< The nicklist.
+	NickDataViewCtrl* m_nicklist; //!< The nicklist.
 	//wxComboBox* m_nick_filter;  //!< The filter combo.
 
 	wxButton* m_say_button; //!< The say button.
@@ -192,7 +204,7 @@ private:
 
 	Channel* m_channel; //!< Channel object.
 	IServer* m_server;  //!< Server object.
-	const User* m_user; //!< User object.
+	User* m_user;       //!< User object.
 	IBattle* m_battle;  //!< User object.
 
 	wxStaticText* m_usercount_label;
@@ -205,9 +217,6 @@ private:
 
 	ChatLog m_chat_log;
 
-	void LogTime();
-	void CreateControls();
-	void CreatePopup();
 	size_t m_icon_index;
 
 	wxImageList* m_imagelist;
@@ -227,6 +236,7 @@ private:
 
 	//used to avoid marking channel as changed when it's just been created.
 	bool m_topic_set;
+	bool m_reactOnPromoteEvents;
 
 	DECLARE_EVENT_TABLE()
 };
@@ -236,6 +246,7 @@ enum {
 	CHAT_TEXT,
 	CHAT_LOG,
 	CHAT_CHAN_OPTS,
-	FILTER_USERS
+	FILTER_USERS,
+	SHOW_PLAYERS_ONLY_CHECK
 };
 #endif // SPRINGLOBBY_HEADERGUARD_CHATPANEL_H
