@@ -9,7 +9,6 @@
 #include "iserver.h"
 #include "serverselector.h"
 #include "user.h"
-#include "nicklistctrl.h"
 #include "mainwindow.h"
 #include "settings.h"
 #include "battlelist/battlelisttab.h"
@@ -405,13 +404,13 @@ void ChatPanelMenu::OnChannelMenuSpamIsOn(wxCommandEvent& /*unused*/)
 
 void ChatPanelMenu::OnServerMenuDisconnect(wxCommandEvent& /*unused*/)
 {
-	ui().Disconnect();
+	ServerManager::Instance()->DisconnectFromServer();
 }
 
 
 void ChatPanelMenu::OnServerMenuReconnect(wxCommandEvent& /*unused*/)
 {
-	ui().Reconnect();
+	ServerManager::Instance()->ReconnectToServer();
 }
 
 
@@ -454,8 +453,8 @@ void ChatPanelMenu::OnServerMenuBroadcast(wxCommandEvent& /*unused*/)
 
 void ChatPanelMenu::OnUserMenuOpenChat(wxCommandEvent& /*unused*/)
 {
-	const User* user = m_chatpanel->GetSelectedUser();
-	if (user == 0)
+	User* user = m_chatpanel->GetSelectedUser();
+	if (user == nullptr)
 		return;
 
 	ui().mw().OpenPrivateChat(*user);
