@@ -187,7 +187,7 @@ wxString AddBotDialog::GetAiRawName()
 void AddBotDialog::ReloadAIList()
 {
 	try {
-		m_ais = lslTowxArrayString(LSL::usync().GetAIList(m_battle.GetHostModName()));
+		m_ais = lslTowxArrayString(LSL::usync().GetAIList(m_battle.GetHostGameName()));
 	} catch (...) {
 	}
 
@@ -248,7 +248,7 @@ void AddBotDialog::ShowAIOptions()
 {
 	m_opts_list->DeleteAllItems();
 	m_opt_list_map.clear();
-	m_battle.CustomBattleOptions().loadAIOptions(m_battle.GetHostModName(), GetAIType(), STD_STRING(GetNick()));
+	m_battle.CustomBattleOptions().loadAIOptions(m_battle.GetHostGameName(), GetAIType(), STD_STRING(GetNick()));
 	AddMMOptionsToList(0, m_battle.CustomBattleOptions().GetAIOptionIndex(STD_STRING(GetNick())));
 	m_opts_list->SetColumnWidth(0, wxLIST_AUTOSIZE);
 	m_opts_list->SetColumnWidth(1, wxLIST_AUTOSIZE);
@@ -283,7 +283,7 @@ void AddBotDialog::UpdateOption(const wxString& Tag)
 	else
 		m_opts_list->SetItemFont(index, wxFont(8, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD));
 	if (DataType == LSL::Enum::opt_bool) {
-		value = STD_STRING(bool2yn(LSL::Util::FromString<long>(value))); // convert from 0/1 to literal Yes/No
+		value = STD_STRING(bool2yn(LSL::Util::FromIntString(value))); // convert from 0/1 to literal Yes/No
 	} else if (DataType == LSL::Enum::opt_list) {
 		value = m_battle.CustomBattleOptions().GetNameListOptValue(key, type); // get the key full name not short key
 	}
