@@ -32,6 +32,7 @@
 #include "settings.h"
 #include "aui/auimanager.h"
 #include "utils/conversion.h"
+#include "utils/globalevents.h"
 #include "log.h"
 #include "gui/mapctrl.h"
 
@@ -121,12 +122,14 @@ BattleMapTab::BattleMapTab(wxWindow* parent, IBattle* battle)
 	SetBattle(battle);
 
 	Layout();
-	ConnectGlobalEvent(this, GlobalEvent::OnUnitsyncReloaded, wxObjectEventFunction(&BattleMapTab::OnUnitsyncReloaded));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnUnitsyncReloaded, wxObjectEventFunction(&BattleMapTab::OnUnitsyncReloaded));
 }
 
 
 BattleMapTab::~BattleMapTab()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
+
 	if (GetAui().manager)
 		GetAui().manager->DetachPane(this);
 }
@@ -135,7 +138,7 @@ void BattleMapTab::Update()
 {
 	if (!m_battle)
 		return;
-	const long longval = LSL::Util::FromString<long>(
+	const long longval = LSL::Util::FromIntString(
 	    m_battle->CustomBattleOptions().getSingleValue("startpostype", LSL::Enum::EngineOption));
 	m_start_radios->SetSelection(longval);
 
@@ -170,10 +173,9 @@ void BattleMapTab::Update(const wxString& Tag)
 	long type;
 	Tag.BeforeFirst('_').ToLong(&type);
 	const std::string key = STD_STRING(Tag.AfterFirst('_'));
-	const long longval = LSL::Util::FromString<long>(
-	    m_battle->CustomBattleOptions().getSingleValue(key, (LSL::Enum::GameOption)type));
 	if (type == LSL::Enum::EngineOption) {
 		if (key == "startpostype") {
+			const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions().getSingleValue(key, (LSL::Enum::GameOption)type));
 			m_start_radios->SetSelection(longval);
 			m_minimap->UpdateMinimap();
 		}
