@@ -4,7 +4,6 @@
 #define SPRINGLOBBY_HEADERGUARD_BATTLEMAPTAB_H
 
 #include <wx/scrolwin.h>
-#include "utils/globalevents.h"
 
 class Ui;
 class IBattle;
@@ -26,7 +25,7 @@ class wxMouseEvent;
 
 /** \brief select map, draw startboxes (in sp define startpos)
  * \todo DOCMEMORE */
-class BattleMapTab : public wxPanel, public GlobalEvent
+class BattleMapTab : public wxPanel
 {
 public:
 	BattleMapTab(wxWindow* parent, IBattle* battle);
