@@ -376,13 +376,13 @@ void BattleroomMMOptionsTab::UpdateOptControls(const wxString& controlName)
 	if (gameoption == LSL::Enum::PrivateOptions) {
 		if (optKey == "mapname")
 			OnReloadControls(LSL::Enum::MapOption);
-		if (optKey == "modname")
+		if (optKey == "gamename")
 			OnReloadControls(LSL::Enum::ModOption);
 		return;
 	}
 
 	if (m_chkbox_map.find(controlName) != m_chkbox_map.end()) {
-		const long value = LSL::Util::FromString<long>(
+		const long value = LSL::Util::FromIntString(
 		    m_battle->CustomBattleOptions().getSingleValue(optKey, (LSL::Enum::GameOption)gameoption));
 		wxCheckBox* cur = m_chkbox_map[controlName];
 		cur->SetValue(value);
@@ -402,7 +402,7 @@ void BattleroomMMOptionsTab::UpdateOptControls(const wxString& controlName)
 	}
 
 	if (m_spinctrl_map.find(controlName) != m_spinctrl_map.end()) {
-		const long value = LSL::Util::FromString<long>(
+		const long value = LSL::Util::FromIntString(
 		    m_battle->CustomBattleOptions().getSingleValue(optKey, (LSL::Enum::GameOption)gameoption));
 		wxSpinCtrlDouble* cur = m_spinctrl_map[controlName];
 		cur->SetValue(value);
@@ -522,7 +522,7 @@ void BattleroomMMOptionsTab::OnSetModDefaultPreset(wxCommandEvent& /*unused*/)
 	int result = wxGetSingleChoiceIndex(_("Pick an existing option set from the list"), _("Set game default preset"), choices);
 	if (result < 0)
 		return;
-	sett().SetModDefaultPresetName(TowxString(m_battle->GetHostModName()), choices[result]);
+	sett().SetModDefaultPresetName(TowxString(m_battle->GetHostGameName()), choices[result]);
 }
 
 void BattleroomMMOptionsTab::UpdatePresetList()
@@ -596,7 +596,7 @@ void BattleroomMMOptionsTab::SetBattle(IBattle* battle)
 		itor->second->Enable(isBattleEnabled);
 
 	if (isBattleEnabled) {
-		m_options_preset_sel->SetStringSelection(sett().GetModDefaultPresetName(TowxString(m_battle->GetHostModName())));
+		m_options_preset_sel->SetStringSelection(sett().GetModDefaultPresetName(TowxString(m_battle->GetHostGameName())));
 		if (!m_battle->IsFounderMe()) {
 			m_options_preset_sel->Disable();
 			m_load_btn->Disable();
