@@ -4,14 +4,13 @@
 #define SPRINGLOBBY_HEADERGUARD_BATTLEROOMTAB_H
 
 #include <lslunitsync/optionswrapper.h>
-#include "utils/globalevents.h"
 #include "utils/uievents.h"
 #include <map>
 
 class Ui;
 class IBattle;
 struct BattleBot;
-class BattleroomListCtrl;
+class BattleroomDataViewCtrl;
 class User;
 class ChatPanel;
 class wxCommandEvent;
@@ -36,15 +35,13 @@ typedef std::map<wxString, long> OptionListMap;
 
 /** \brief container for BattleroomListCtrl, battle specific ChatPanel. Also displaying battle info summary
  * \todo DOCMEMORE */
-class BattleRoomTab : public wxPanel, public GlobalEvent
+class BattleRoomTab : public wxPanel
 {
 public:
 	BattleRoomTab(wxWindow* parent, IBattle* battle);
 	~BattleRoomTab();
 
-	BattleroomListCtrl& GetPlayersListCtrl();
-
-	void UpdateUser(User& user);
+	void UpdateUser(User& user, bool userJustAdded = false);
 
 	IBattle* GetBattle();
 	ChatPanel& GetChatPanel();
@@ -171,7 +168,7 @@ private:
 
 	wxComboBox* m_map_combo;
 
-	BattleroomListCtrl* m_players;
+	BattleroomDataViewCtrl* m_players;
 	ChatPanel* m_chat;
 	wxSplitterWindow* m_splitter;
 
