@@ -6,6 +6,7 @@
 
 #include <wx/dialog.h>
 #include "gui/windowattributespickle.h"
+
 class wxStaticText;
 class wxTextCtrl;
 class wxChoice;
@@ -23,8 +24,8 @@ class wxPanel;
 class HostBattleDialog : public wxDialog, public WindowHintsPickle
 {
 public:
-	HostBattleDialog(wxWindow* parent);
-
+	explicit HostBattleDialog(wxWindow* parent);
+	static void RunHostBattleDialog(wxWindow* parent);
 
 private:
 	int GetSelectedRank();
@@ -105,5 +106,11 @@ private:
 	DECLARE_EVENT_TABLE()
 };
 
+namespace SL
+{
+//! this shows an instance and handles everything wrt data feeding and input handling
+
+}
+
 
 #endif // SPRINGLOBBY_HEADERGUARD_HOSTBATTLEDIALOG_H
