@@ -9,9 +9,9 @@
 
 class wxStaticText;
 class wxButton;
-class DownloadListCtrl;
+class DownloadDataViewCtrl;
 class Ui;
-struct DownloadInfo;
+class DownloadInfo;
 class wxBoxSizer;
 class ColorButton;
 class WidgetDownloadDialog;
@@ -44,7 +44,7 @@ private:
 
 	wxButton* m_but_cancel;
 	wxButton* m_but_clear;
-	DownloadListCtrl* m_dl_listctrl;
+	DownloadDataViewCtrl* m_DownloadDataView;
 	WidgetDownloadDialog* m_widgets_dialog;
 
 	void OnCancelButton(wxCommandEvent& event);
@@ -52,6 +52,9 @@ private:
 	void OnDLWidgets(wxCommandEvent& event);
 	void OnClearFinished(wxCommandEvent& event);
 
+	void OnNewDownloadStarted(wxCommandEvent& event);
+	void OnDownloadComplete(wxCommandEvent& event);
+
 	wxBoxSizer* m_main_sizer;
 
 private:
