@@ -32,6 +32,7 @@
 #include "serverselector.h"
 #include "utils/platform.h"
 #include "utils/version.h"
+#include "utils/globalevents.h"
 #include "battlelist/battlelisttab.h"
 #include "mainchattab.h"
 #include "hosting/mainjoinbattletab.h"
@@ -56,6 +57,7 @@
 #include "gui/controls.h"
 #include "gui/ui.h"
 #include "log.h"
+#include "servermanager.h"
 #include <lslunitsync/unitsync.h>
 
 #include "iconimagelist.h"
@@ -233,6 +235,8 @@ MainWindow::MainWindow()
 	mapSelectDialog(true, this);
 	Logger::ShowDebugWindow(true);
 	//	Logger::ShowDebugWindow(cfg().ReadBool(_T("/debug")));
+
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::GamePromotedEvent, wxObjectEventFunction(&MainWindow::OnGamePromoted));
 }
 
 wxBitmap MainWindow::GetTabIcon(const unsigned char* data, size_t size) const
@@ -279,7 +283,7 @@ MainWindow::~MainWindow()
 void MainWindow::OnClose(wxCloseEvent& /*unused*/)
 {
 	Logger::ShowDebugWindow(false);
-	GlobalEvent::Send(GlobalEvent::OnQuit);
+	GlobalEventManager::Instance()->Send(GlobalEventManager::OnQuit);
 	//	GlobalEvent::Disconnect(MainWindow::OnClose, GlobalEvent::)
 	//	SetEvtHandlerEnabled(false);
 	{
@@ -435,7 +439,7 @@ void MainWindow::OpenChannelChat(Channel& channel, bool doFocus)
 //! @brief Open a new chat tab with a private chat
 //!
 //! @param nick The user to whom the chatwindow should be opened to
-void MainWindow::OpenPrivateChat(const User& user, bool doFocus)
+void MainWindow::OpenPrivateChat(User& user, bool doFocus)
 {
 	ASSERT_LOGIC(m_chat_tab != 0, "m_chat_tab");
 	m_func_tabs->SetSelection(PAGE_CHAT);
@@ -478,7 +482,7 @@ void MainWindow::ShowChannelChooser()
 	if ((m_channel_chooser == NULL) || (m_channel_chooser && m_channel_chooser->IsShown()))
 		return;
 
-	if (!ui().IsConnected()) {
+	if (!ServerManager::Instance()->IsConnected()) {
 		customMessageBox(SL_MAIN_ICON, _("You need to be connected to a server to view the channel list"), _("Not connected"));
 	} else {
 		m_channel_chooser->ClearChannels();
@@ -491,11 +495,11 @@ void MainWindow::ShowChannelChooser()
 void MainWindow::OnMenuJoin(wxCommandEvent& /*unused*/)
 {
 
-	if (!ui().IsConnected())
+	if (!ServerManager::Instance()->IsConnected())
 		return;
 	wxString answer;
 	if (ui().AskText(_("Join channel..."), _("Name of channel to join"), answer)) {
-		ui().JoinChannel(answer, wxEmptyString);
+		ServerManager::Instance()->JoinChannel(answer, wxEmptyString);
 	}
 }
 
@@ -503,7 +507,7 @@ void MainWindow::OnMenuJoin(wxCommandEvent& /*unused*/)
 void MainWindow::OnMenuChat(wxCommandEvent& /*unused*/)
 {
 
-	if (!ui().IsConnected())
+	if (!ServerManager::Instance()->IsConnected())
 		return;
 	wxString answer;
 	if (ui().AskText(_("Open Private Chat..."), _("Name of user"), answer)) {
@@ -527,7 +531,7 @@ void MainWindow::OnMenuConnect(wxCommandEvent& /*unused*/)
 
 void MainWindow::OnMenuDisconnect(wxCommandEvent& /*unused*/)
 {
-	ui().Disconnect();
+	ServerManager::Instance()->DisconnectFromServer();
 }
 
 void MainWindow::OnMenuServerTab(wxCommandEvent& /*unused*/)
@@ -554,7 +558,7 @@ void MainWindow::OnUnitSyncReload(wxCommandEvent& /*unused*/)
 {
 	LSL::usync().ReloadUnitSyncLib();
 	m_menuEdit->Enable(MENU_SETTINGSPP, LSL::usync().IsLoaded());
-	GlobalEvent::Send(GlobalEvent::OnUnitsyncReloaded);
+	GlobalEventManager::Instance()->Send(GlobalEventManager::OnUnitsyncReloaded);
 }
 
 void MainWindow::MainWindow::OnShowWriteableDir(wxCommandEvent& /*unused*/)
@@ -579,8 +583,9 @@ void MainWindow::OnTabsChanged(wxAuiNotebookEvent& event)
 	int newsel = event.GetSelection();
 
 	if (newsel == 0 || newsel == 1) {
-		if (!ui().IsConnected() && ui().IsMainWindowCreated())
-			ui().Connect();
+		if (!ServerManager::Instance()->IsConnected() && ui().IsMainWindowCreated()) {
+			ServerManager::Instance()->ConnectToServer();
+		}
 	}
 
 	ChatPanel* panel = ui().GetActiveChatPanel(); //set input focus to edit field on tab change
@@ -722,3 +727,12 @@ void MainWindow::OnMenuDownload(wxCommandEvent& /*event*/)
 		start = pos + 1;
 	} while (pos != wxNOT_FOUND);
 }
+
+void MainWindow::OnGamePromoted(wxCommandEvent& promoteEvent)
+{
+	//Promote user without checking his status
+	//TODO: Maybe need to separate users by status to groups which one should be notified
+	//and which one should not be.
+	wxString msg = promoteEvent.GetString();
+	UiEvents::GetNotificationEventSender().SendEvent(UiEvents::NotficationData(UiEvents::GamePromoted, msg));
+}
