@@ -41,7 +41,7 @@ class OptionsDialog;
 class ReplayTraits;
 class wxFocusEvent;
 
-const wxEventType MainwindowMessageEvent = wxNewEventType();
+static const wxEventType MainwindowMessageEvent = wxNewEventType();
 
 //! @brief wxFrame that contains the main window of the client.
 class MainWindow : public wxFrame, public WindowAttributesPickle
@@ -52,7 +52,7 @@ public:
 
 	// MainWindow interface
 	void OpenChannelChat(Channel& channel, bool doFocus = true);
-	void OpenPrivateChat(const User& user, bool doFocus = false);
+	void OpenPrivateChat(User& user, bool doFocus = false);
 
 	void ShowConfigure(const unsigned int page = OPT_PAGE_SPRING);
 	void ShowTab(const unsigned int idx);
@@ -113,6 +113,9 @@ public:
 	void LoadPerspectives(const wxString& perspective_name = wxEmptyString);
 	void SavePerspectives(const wxString& perspective_name = wxEmptyString);
 
+private:
+	void OnGamePromoted(wxCommandEvent&);
+
 private:
 	wxMenuItem* m_settings_menu;
 	wxMenuBar* m_menubar;
