@@ -28,6 +28,9 @@
 #include "iconimagelist.h"
 #include "hosting/addbotdialog.h"
 #include "log.h"
+#include "contentmanager.h"
+#include "contentdownloadrequest.h"
+#include "exception.h"
 
 #include "images/close.xpm"
 #include "images/close_hi.xpm"
@@ -358,7 +361,7 @@ void MapCtrl::_SetCursor()
 	}
 
 	if (m_battle != 0) {
-		const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
+		const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
 								     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 		if (longval != IBattle::ST_Choose) {
 			SetCursor(wxCursor(wxCURSOR_ARROW));
@@ -494,26 +497,23 @@ void MapCtrl::UpdateMinimap()
 {
 	assert(wxThread::IsMain());
 	_SetCursor();
-	if (m_battle == 0)
+	if (m_battle == nullptr)
 		return;
 	int w, h;
 	GetClientSize(&w, &h);
 
 	m_mutex.Lock();
-	if (m_battle) //needs to be looked into, crahses with replaytab (koshi)
-	{
-		bool just_resize = (m_lastsize != wxSize(-1, -1) && m_lastsize != wxSize(w, h));
-		if ((m_mapname != m_battle->GetHostMapName()) || just_resize) {
-			FreeMinimap();
-			int loaded_ok = LoadMinimap();
+	const bool just_resize = (m_lastsize != wxSize(-1, -1) && m_lastsize != wxSize(w, h));
+	if ((m_mapname != m_battle->GetHostMapName()) || just_resize) {
+		FreeMinimap();
+		int loaded_ok = LoadMinimap();
 
-			if (!just_resize && loaded_ok == 0) // if a new map is loaded, reset start positions
-			{
-				const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
-										     .getSingleValue("startpostype", LSL::Enum::EngineOption));
-				if (longval == IBattle::ST_Pick)
-					RelocateUsers();
-			}
+		if (!just_resize && loaded_ok == 0) // if a new map is loaded, reset start positions
+		{
+			const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
+										 .getSingleValue("startpostype", LSL::Enum::EngineOption));
+			if (longval == IBattle::ST_Pick)
+				RelocateUsers();
 		}
 	}
 	m_mutex.Unlock();
@@ -773,7 +773,7 @@ void MapCtrl::DrawStartPositions(wxDC& dc)
 	wxRect mr = GetMinimapRect();
 	m_map = m_battle->LoadMap();
 	RequireImages();
-	const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
+	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
 							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if (longval == IBattle::ST_Fixed) {
 
@@ -932,7 +932,7 @@ void MapCtrl::DrawUser(wxDC& dc, User& user, bool selected, bool /*unused*/)
 			DrawStartRect(dc, -1, tmp, col, false);
 		}
 
-		wxBitmap bmp = icons().GetBitmap(icons().GetSideIcon(m_battle->GetHostModName(), user.BattleStatus().side));
+		wxBitmap bmp = icons().GetBitmap(icons().GetSideIcon(m_battle->GetHostGameName(), user.BattleStatus().side));
 		dc.DrawBitmap(bmp, r.x + siderect.x, r.y + siderect.y, true);
 
 		/* Draw the Ally Number numeric select */
@@ -1057,7 +1057,7 @@ void MapCtrl::OnPaint(wxPaintEvent& WXUNUSED(event))
 
 	if (!m_minimap)
 		return;
-	const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
+	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
 							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 
 
@@ -1098,7 +1098,7 @@ void MapCtrl::OnMouseMove(wxMouseEvent& event)
 		return;
 	if (p == wxDefaultPosition)
 		return;
-	const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
+	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
 							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 
 	if (longval == IBattle::ST_Pick) {
@@ -1300,7 +1300,7 @@ void MapCtrl::OnLeftDown(wxMouseEvent& event)
 	if (m_battle == 0)
 		return;
 
-	const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
+	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
 							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 
 	if (!m_ro) {
@@ -1383,7 +1383,7 @@ void MapCtrl::OnLeftUp(wxMouseEvent& event)
 	if (m_battle == 0)
 		return;
 
-	const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
+	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
 							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if (longval == IBattle::ST_Pick) {
 		if (!m_user_expanded)
@@ -1419,7 +1419,7 @@ void MapCtrl::OnLeftUp(wxMouseEvent& event)
 
 		} else if (m_mdown_area == Side) {
 			try {
-				const auto sides = LSL::usync().GetSides(m_battle->GetHostModName());
+				const auto sides = LSL::usync().GetSides(m_battle->GetHostGameName());
 				const unsigned int sidecount = sides.size();
 				if (sidecount > 0)
 					user.BattleStatus().side = (user.BattleStatus().side + 1) % sidecount;
@@ -1447,7 +1447,13 @@ void MapCtrl::OnLeftUp(wxMouseEvent& event)
 				m_battle->Update(stdprintf("%d_mapname", LSL::Enum::PrivateOptions));
 				UpdateMinimap();
 			} else if (m_mdown_area == Download) {
-				ui().Download("map", m_battle->GetHostMapName(), m_battle->GetHostMapHash());
+				ContentDownloadRequest req;
+				req.MapRequired(m_battle->GetHostMapName(), m_battle->GetHostMapHash());
+				try{
+					ContentManager::Instance()->DownloadContent(req);
+				}catch(Exception& e) {
+					wxLogError(_("Failed to download map: ") + e.Reason());
+				}
 			}
 		}
 		m_mdown_area = Main;
@@ -1496,7 +1502,7 @@ void MapCtrl::OnRightUp(wxMouseEvent& event)
 	if (p == wxDefaultPosition)
 		return;
 
-	const long longval = LSL::Util::FromString<long>(m_battle->CustomBattleOptions()
+	const long longval = LSL::Util::FromIntString(m_battle->CustomBattleOptions()
 							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if (longval == IBattle::ST_Pick) {
 
