@@ -6,6 +6,7 @@
 #include "gui/uiutils.h"
 #include "gui/ui.h"
 #include "utils/slconfig.h"
+#include "utils/globalevents.h"
 #include "settings.h"
 #include "spring.h"
 #include "gui/mainwindow.h"
@@ -46,11 +47,13 @@ NotificationManager::NotificationManager()
     , m_rate_limit_ms(2000)
     , m_showNotificationSink(this, &UiEvents::GetNotificationEventSender())
 {
-	ConnectGlobalEvent(this, GlobalEvent::OnQuit, wxObjectEventFunction(&NotificationManager::OnQuit));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnQuit, wxObjectEventFunction(&NotificationManager::OnQuit));
 }
 
 NotificationManager::~NotificationManager()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
+
 	m_rate_limit_timer.Stop();
 	delete m_notification_wrapper;
 	m_notification_wrapper = NULL;
