@@ -19,7 +19,6 @@
 #include "replaylist.h"
 //#include "PlaybackListFiltervalues.h"
 #include "playbackfiltervalues.h"
-#include "gui/battlelist/battlelistctrl.h"
 #include "battle.h"
 #include "gui/uiutils.h"
 #include "utils/tasutil.h"
@@ -90,7 +89,7 @@ PlaybackListFilter::PlaybackListFilter(wxWindow* parent, wxWindowID id, Playback
 
 	m_filter_player_choice->SetMinSize(wxSize(140, -1));
 
-	m_filter_body_row2_sizer->Add(m_filter_player_choice, 0, wxALIGN_RIGHT | wxALL | wxALIGN_CENTER_VERTICAL, 5);
+	m_filter_body_row2_sizer->Add(m_filter_player_choice, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
 
 	m_filter_player_button = new wxButton(this, PLAYBACK_FILTER_PLAYER_BUTTON, f_values.player_mode, wxDefaultPosition, wxSize(25, 25), 0);
 	m_filter_body_row2_sizer->Add(m_filter_player_button, 0, wxALIGN_LEFT | wxALL | wxALIGN_CENTER_VERTICAL, 5);
@@ -124,7 +123,7 @@ PlaybackListFilter::PlaybackListFilter(wxWindow* parent, wxWindowID id, Playback
 	m_filter_map_show->SetValue(f_values.map_show);
 	m_filter_map_show->SetMinSize(wxSize(140, -1));
 
-	m_filter_only_map_sizer->Add(m_filter_map_show, 0, wxEXPAND | wxALIGN_LEFT | wxALL | wxALIGN_CENTER_VERTICAL, 5);
+	m_filter_only_map_sizer->Add(m_filter_map_show, 0, wxEXPAND | wxALIGN_LEFT | wxALL, 5);
 
 	m_filter_body_row3_sizer->Add(m_filter_only_map_sizer, 0, wxEXPAND, 5);
 
@@ -157,7 +156,7 @@ PlaybackListFilter::PlaybackListFilter(wxWindow* parent, wxWindowID id, Playback
 	m_filter_mod_show->SetValue(f_values.mod_show);
 	m_filter_mod_show->SetMinSize(wxSize(140, -1));
 
-	m_filter_only_mod_sizer->Add(m_filter_mod_show, 0, wxALIGN_LEFT | wxALL | wxALIGN_CENTER_VERTICAL | wxEXPAND, 5);
+	m_filter_only_mod_sizer->Add(m_filter_mod_show, 0, wxALIGN_LEFT | wxALL | wxEXPAND, 5);
 
 	m_filter_body_row4_sizer->Add(m_filter_only_mod_sizer, 0, wxALIGN_LEFT | wxEXPAND, 5);
 
@@ -227,8 +226,8 @@ PlaybackListFilter::PlaybackListFilter(wxWindow* parent, wxWindowID id, Playback
 	m_col2_sizer->Add(m_filter_body_row6_sizer, 1, wxEXPAND, 5);
 
 
-	m_filter_sizer->Add(m_col1_sizer, 1, wxEXPAND | wxALIGN_CENTER_HORIZONTAL, 5);
-	m_filter_sizer->Add(m_col2_sizer, 1, wxEXPAND | wxALIGN_CENTER_HORIZONTAL, 5);
+	m_filter_sizer->Add(m_col1_sizer, 1, wxEXPAND, 5);
+	m_filter_sizer->Add(m_col2_sizer, 1, wxEXPAND, 5);
 
 	m_activ = false;
 	m_filter_player_mode = _GetButtonMode(f_values.player_mode);
@@ -330,7 +329,7 @@ bool PlaybackListFilter::FilterPlayback(const StoredGame& playback)
 		return false;
 
 	//Only Mods i have Check
-	if (m_filter_mod_show->GetValue() && !battle.ModExists())
+	if (m_filter_mod_show->GetValue() && !battle.GameExists())
 		return false;
 
 	//Strings Plain Text & RegEx Check (Case insensitiv)
@@ -340,7 +339,7 @@ bool PlaybackListFilter::FilterPlayback(const StoredGame& playback)
 		return false;
 
 	//Mod:
-	if (!TowxString(battle.GetHostModName()).Upper().Contains(m_filter_mod_edit->GetValue().Upper()) && !TowxString(battle.GetHostModName()).Upper().Contains(m_filter_mod_edit->GetValue().Upper()) && !m_filter_mod_expression->Matches(TowxString(battle.GetHostModName())))
+	if (!TowxString(battle.GetHostGameName()).Upper().Contains(m_filter_mod_edit->GetValue().Upper()) && !TowxString(battle.GetHostGameName()).Upper().Contains(m_filter_mod_edit->GetValue().Upper()) && !m_filter_mod_expression->Matches(TowxString(battle.GetHostGameName())))
 		return false;
 
 	if ((!m_filter_filesize_edit->GetValue().IsEmpty()) && !_IntCompare(playback.size, 1024 * FromwxString(m_filter_filesize_edit->GetValue()), m_filter_filesize_mode))
