@@ -33,6 +33,7 @@
 #include "utils/globalevents.h"
 #include "log.h"
 #include "utils/lslconversion.h"
+#include "utils/slconfig.h"
 
 BEGIN_EVENT_TABLE(SinglePlayerTab, wxPanel)
 
@@ -63,6 +64,18 @@ SinglePlayerTab::SinglePlayerTab(wxWindow* parent, MainSinglePlayerTab& msptab)
 	wxBoxSizer* m_map_sizer = new wxBoxSizer(wxHORIZONTAL);
 	// m_map_sizer->SetMinSize( wxSize( 352, -1 ) );
 
+
+	// empty panel to replace minimap
+	m_nominimap = new wxWindow(this, -1, wxDefaultPosition, wxSize(100, 100), wxSIMPLE_BORDER | wxFULL_REPAINT_ON_RESIZE);
+
+	m_nominimap->SetToolTip(_("No Unitsync configured."));
+	m_nominimap->SetBackgroundStyle(wxBG_STYLE_CUSTOM);
+	m_nominimap->SetBackgroundColour(*wxLIGHT_GREY);
+	m_nominimap->Hide();
+	m_map_sizer->Add(m_nominimap, 1, wxALL | wxEXPAND, 2);
+
+//	Regular minimap
+
 	m_minimap = new MapCtrl(this, 100, &m_battle, false, true, true);
 	m_minimap->SetToolTip(_("You can drag the sun/bot icon around to define start position.\n "
 				"Hover over the icon for a popup that lets you change side, ally and bonus."));
@@ -121,12 +134,9 @@ SinglePlayerTab::SinglePlayerTab(wxWindow* parent, MainSinglePlayerTab& msptab)
 	m_mod_lbl = new wxStaticText(this, -1, _("Engine:"));
 	m_ctrl_sizer->Add(m_mod_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALL, 5);
 
-	wxArrayString m_engine_picChoices;
-	wxBoxSizer* mod_choice_button_sizer2 = new wxBoxSizer(wxHORIZONTAL);
-	m_engine_pic = new wxChoice(this, SP_ENGINE_PICK, wxDefaultPosition, wxDefaultSize, m_engine_picChoices, 0);
-	m_engine_pic->SetToolTip(_("Select the engine version to play."));
-	mod_choice_button_sizer2->Add(m_engine_pic, 0, wxALL, 5);
-	m_ctrl_sizer->Add(mod_choice_button_sizer2, 0, wxEXPAND | wxALL, 1);
+	m_engine_pick = new wxChoice(this, SP_ENGINE_PICK);
+	m_engine_pick->SetToolTip(_("Select the engine version to play."));
+	m_ctrl_sizer->Add(m_engine_pick, 1, wxALL, 5);
 
 	//  m_ctrl_sizer->Add( 0, 0, 1, wxEXPAND, 0 );
 
@@ -160,18 +170,18 @@ SinglePlayerTab::SinglePlayerTab(wxWindow* parent, MainSinglePlayerTab& msptab)
 	m_battle.SetEngineVersion(SlPaths::GetCurrentUsedSpringIndex());
 
 	ReloadMaplist();
-	ReloadModlist();
+//	ReloadModlist(); //Called from ReloadEngineList() too
 	ReloadEngineList();
-	ConnectGlobalEvent(this, GlobalEvent::OnUnitsyncReloaded, wxObjectEventFunction(&SinglePlayerTab::OnUnitsyncReloaded));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnUnitsyncReloaded, wxObjectEventFunction(&SinglePlayerTab::OnUnitsyncReloaded));
 
 	this->SetSizer(m_main_sizer);
 	this->Layout();
-
 }
 
 
 SinglePlayerTab::~SinglePlayerTab()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
 }
 
 
@@ -201,34 +211,51 @@ void SinglePlayerTab::ReloadMaplist()
 void SinglePlayerTab::ReloadModlist()
 {
 	m_mod_pick->Clear();
-	m_mod_pick->Append(lslTowxArrayString(LSL::usync().GetModList()));
+	m_mod_pick->Append(lslTowxArrayString(LSL::usync().GetGameList()));
 	m_mod_pick->Insert(_("-- Select one --"), m_mod_pick->GetCount());
-	if (m_battle.GetHostModName().empty()) {
+	if (m_battle.GetHostGameName().empty()) {
 		m_mod_pick->SetSelection(m_mod_pick->GetCount() - 1);
 	} else {
-		m_mod_pick->SetStringSelection(TowxString(m_battle.GetHostModName()));
+		m_mod_pick->SetStringSelection(TowxString(m_battle.GetHostGameName()));
 		if (m_mod_pick->GetStringSelection().empty()) {
 			SetMod(m_mod_pick->GetCount() - 1);
 		}
 	}
 }
 
+
+
 void SinglePlayerTab::ReloadEngineList()
 {
-	m_engine_pic->Clear();
+	SlPaths::ValidatePaths();
+
+	m_engine_pick->Clear();
+
 	std::map<std::string, LSL::SpringBundle> versions = SlPaths::GetSpringVersionList();
 	const std::string last = SlPaths::GetCurrentUsedSpringIndex();
 	int i = 0;
+
 	for (auto pair : versions) {
-		m_engine_pic->Insert(TowxString(pair.first), i);
+		m_engine_pick->Insert(TowxString(pair.first), i);
 		if (last == pair.first) {
-			m_engine_pic->SetSelection(i);
+			m_engine_pick->SetSelection(i);
 		}
 		i++;
 	}
 
-	if (m_engine_pic->GetSelection() == wxNOT_FOUND) {
-		m_engine_pic->SetSelection(0);
+	if (m_engine_pick->GetSelection() == wxNOT_FOUND) {
+		m_engine_pick->SetSelection(0);
+	}
+
+	if(i == 0) {
+		m_minimap->Hide();
+		m_nominimap->Show();
+		m_start_btn->Enable(false);
+	}
+	else {
+		m_nominimap->Hide();
+		m_minimap->Show();
+		m_start_btn->Enable(true);
 	}
 	//unitsync change needs a refresh of games as well
 	ReloadModlist();
@@ -267,25 +294,25 @@ void SinglePlayerTab::SetMap(unsigned int index)
 
 void SinglePlayerTab::ResetUsername()
 {
-	m_battle.GetMe().SetNick(STD_STRING(sett().GetDefaultNick()));
+	m_battle.GetMe().SetNick(STD_STRING(cfg().ReadString("/Spring/DefaultName")));
 }
 
 void SinglePlayerTab::SetMod(unsigned int index)
 {
 	//ui().ReloadUnitSync();
 	if (index >= m_mod_pick->GetCount() - 1) {
-		m_battle.SetHostMod("", "");
+		m_battle.SetHostGame("", "");
 	} else {
 		try {
-			LSL::UnitsyncMod mod = LSL::usync().GetMod(index);
-			m_battle.SetLocalMod(mod);
-			m_battle.SetHostMod(mod.name, mod.hash);
+			LSL::UnitsyncGame mod = LSL::usync().GetGame(index);
+			m_battle.SetLocalGame(mod);
+			m_battle.SetHostGame(mod.name, mod.hash);
 		} catch (...) {
 		}
 	}
 	m_minimap->UpdateMinimap();
 	m_battle.SendHostInfo(IBattle::HI_Restrictions); // Update restrictions in options.
-	m_battle.SendHostInfo(IBattle::HI_Mod_Changed);  // reload mod options
+	m_battle.SendHostInfo(IBattle::HI_Game_Changed);  // reload mod options
 	m_mod_pick->SetSelection(index);
 }
 
@@ -332,10 +359,9 @@ void SinglePlayerTab::OnModSelect(wxCommandEvent& /*unused*/)
 
 void SinglePlayerTab::OnEngineSelect(wxCommandEvent& /*event*/)
 {
-	SlPaths::SetUsedSpringIndex(STD_STRING(m_engine_pic->GetString(m_engine_pic->GetSelection())));
+	SlPaths::SetUsedSpringIndex(STD_STRING(m_engine_pick->GetString(m_engine_pick->GetSelection())));
 	LSL::usync().ReloadUnitSyncLib();
-	m_battle.SetEngineVersion(STD_STRING(m_engine_pic->GetString(m_engine_pic->GetSelection())));
-	ReloadEngineList();
+	m_battle.SetEngineVersion(STD_STRING(m_engine_pick->GetString(m_engine_pick->GetSelection())));
 }
 
 void SinglePlayerTab::OnMapBrowse(wxCommandEvent& /*unused*/)
@@ -375,6 +401,7 @@ void SinglePlayerTab::OnUnitsyncReloaded(wxCommandEvent& /*data*/)
 	try {
 		ReloadMaplist();
 		ReloadModlist();
+		ReloadEngineList();
 		UpdateMinimap();
 	} catch (...) {
 		slLogDebugFunc("");
@@ -402,10 +429,10 @@ void SinglePlayerTab::OnRandomCheck(wxCommandEvent& /*unused*/)
 {
 	if (m_random_check->IsChecked())
 		m_battle.CustomBattleOptions().setSingleOption("startpostype",
-							       LSL::Util::ToString(IBattle::ST_Random), LSL::Enum::EngineOption);
+							       LSL::Util::ToIntString(IBattle::ST_Random), LSL::Enum::EngineOption);
 	else
 		m_battle.CustomBattleOptions().setSingleOption("startpostype",
-							       LSL::Util::ToString(IBattle::ST_Pick), LSL::Enum::EngineOption);
+							       LSL::Util::ToIntString(IBattle::ST_Pick), LSL::Enum::EngineOption);
 	m_battle.SendHostInfo(IBattle::HI_StartType);
 }
 
