@@ -34,6 +34,7 @@
 #include "utils/uievents.h"
 #include "utils/slpaths.h"
 #include "utils/version.h"
+#include "utils/globalevents.h"
 #include "gui/uiutils.h"
 #include "gui/chatpanel.h"
 #include "gui/battlelist/battlelisttab.h"
@@ -51,6 +52,10 @@
 #include "gui/textentrydialog.h"
 #include "log.h"
 #include "settings.h"
+#include "servermanager.h"
+#include "contentmanager.h"
+#include "exception.h"
+#include "contentdownloadrequest.h"
 
 #ifndef DISABLE_SOUND
 #include "sound/alsound.h"
@@ -62,11 +67,9 @@ SLCONFIG("/General/LastUpdateCheck", 0L, "Last time springlobby checked for an u
 SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_SINGLE, "which tab to show on startup");
 SLCONFIG("/Chat/BroadcastEverywhere", true, "setting to spam the server messages in all channels");
 SLCONFIG("/Server/Autoconnect", false, "Connect to server on startup");
-SLCONFIG("/General/UpdateUrl", "http://version.springlobby.info/current.txt", "Url to check for updates");
 
 
 static unsigned int s_reconnect_delay_ms = 6 * 1000;	  //initial reconnect delay
-static const unsigned int s_max_reconnect_delay = 240 * 1000; //max delay for reconnecting
 
 Ui& ui()
 {
@@ -90,13 +93,16 @@ Ui::Ui()
 	m_serv = new TASServer();
 //	m_serv = new OfflineServer();
 	serverSelector().SetCurrentServer(m_serv);
-	ConnectGlobalEvent(this, GlobalEvent::OnSpringTerminated, wxObjectEventFunction(&Ui::OnSpringTerminated));
-	ConnectGlobalEvent(this, GlobalEvent::OnQuit, wxObjectEventFunction(&Ui::OnQuit));
-	ConnectGlobalEvent(this, GlobalEvent::OnLobbyDownloaded, wxObjectEventFunction(&Ui::OnDownloadComplete));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnSpringTerminated, wxObjectEventFunction(&Ui::OnSpringTerminated));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnQuit, wxObjectEventFunction(&Ui::OnQuit));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnLobbyDownloaded, wxObjectEventFunction(&Ui::OnDownloadComplete));
+	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::UserBattleStatusChangedEvent, wxObjectEventFunction(&Ui::OnUserBattleStatus));
+
 }
 
 Ui::~Ui()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
 	delete m_serv;
 	m_serv = NULL;
 }
@@ -135,6 +141,8 @@ void Ui::ShowMainWindow()
 {
 	ASSERT_LOGIC(m_main_win != 0, "m_main_win = 0");
 	mw().Show(true);
+
+	SlPaths::ValidatePaths();
 }
 
 
@@ -143,8 +151,9 @@ void Ui::ShowMainWindow()
 //! @note It will create the ConnectWindow if not allready created
 void Ui::ShowConnectWindow()
 {
-	if (IsConnected())
+	if (ServerManager::Instance()->IsConnected()) {
 		return;
+	}
 	if (m_con_win == 0) {
 		ASSERT_LOGIC(m_main_win != 0, "m_main_win = 0");
 		m_con_win = new ConnectWindow(m_main_win, *this);
@@ -154,86 +163,6 @@ void Ui::ShowConnectWindow()
 	m_con_win->Raise();
 }
 
-
-//! @brief Connects to default server or opens the ConnectWindow
-//!
-//! @see DoConnect
-void Ui::Connect()
-{
-	if (m_connecting)
-		return;
-	const wxString server_name = sett().GetDefaultServer();
-	const wxString nick = sett().GetServerAccountNick(server_name);
-	const wxString pass = sett().GetServerAccountPass(server_name);
-	bool autoconnect = cfg().ReadBool(_T( "/Server/Autoconnect" ));
-	if (!autoconnect || server_name.IsEmpty() || nick.IsEmpty() || pass.IsEmpty()) {
-		ShowConnectWindow();
-		return;
-	}
-	m_con_win = 0;
-	m_connecting = true;
-	DoConnect(server_name, nick, pass);
-}
-
-
-void Ui::Reconnect()
-{
-	if (s_reconnect_delay_ms <= s_max_reconnect_delay) { //increase reconnect delay each time we try to reconnect
-		s_reconnect_delay_ms += std::max<unsigned int>(s_reconnect_delay_ms * 0.50, 1000);
-		wxLogDebug("changed reconnect delay to %d", s_reconnect_delay_ms / 1000);
-	}
-	const wxString servname = sett().GetDefaultServer();
-	const wxString pass = sett().GetServerAccountPass(servname);
-	if (!sett().GetServerAccountSavePass(servname)) {
-		ShowConnectWindow();
-		return;
-	}
-	DoConnect(servname, sett().GetServerAccountNick(servname), pass);
-}
-
-
-void Ui::Disconnect()
-{
-	if (m_serv != 0) {
-		if (IsConnected()) {
-			m_serv->Disconnect();
-		}
-	}
-}
-
-
-//! @brief Opens the accutial connection to a server.
-void Ui::DoConnect(const wxString& servername, const wxString& username, const wxString& password)
-{
-	if ((m_serv != NULL) && (m_serv->GetServerName() == STD_STRING(servername)) && IsConnected() &&
-	    (m_serv->GetUserName() == STD_STRING(username)) && (m_serv->GetPassword() == STD_STRING(password))) {
-		//nothing changed & already connected, do nothing
-		return;
-	}
-
-	Disconnect();
-
-	m_serv->SetUsername(STD_STRING(username));
-	m_serv->SetPassword(STD_STRING(password));
-
-	const wxString host = sett().GetServerHost(servername);
-	const int port = sett().GetServerPort(servername);
-
-	AddServerWindow(servername);
-	m_serv->uidata.panel->StatusMessage(_T("Connecting to server ") + servername + _T("..."));
-
-	// Connect
-	m_serv->Connect(STD_STRING(servername), STD_STRING(host), port);
-}
-
-void Ui::AddServerWindow(const wxString& servername)
-{
-	if (!m_serv->uidata.panel) {
-		m_serv->uidata.panel = m_main_win->GetChatTab().AddChatPanel(*m_serv, servername);
-	}
-}
-
-
 void Ui::ReopenServerTab()
 {
 	if (m_serv->IsOnline()) {
@@ -241,34 +170,18 @@ void Ui::ReopenServerTab()
 		// re-add all users to the user list
 		const UserList& list = m_serv->GetUserList();
 		for (unsigned int i = 0; i < list.GetNumUsers(); i++) {
-			m_serv->uidata.panel->OnChannelJoin(list.GetUser(i));
+			m_serv->panel->OnChannelJoin(list.GetUser(i));
 		}
 	}
 }
 
-void Ui::DoRegister(const wxString& servername, const wxString& username, const wxString& password)
+void Ui::AddServerWindow(const wxString& servername)
 {
-	if (!sett().ServerExists(servername)) {
-		OnRegistrationDenied(_T("Server does not exist in settings"));
-		return;
+	if (m_serv->panel == nullptr) {
+		m_serv->panel = ui().mw().GetChatTab().AddChatPanel(*m_serv, servername);
 	}
-	m_serv->Register(STD_STRING(servername), STD_STRING(sett().GetServerHost(servername)), sett().GetServerPort(servername), STD_STRING(username), STD_STRING(password));
 }
 
-bool Ui::IsConnected() const
-{
-	if (m_serv == 0)
-		return false;
-	return m_serv->IsConnected();
-}
-
-void Ui::JoinChannel(const wxString& name, const wxString& password)
-{
-	if (m_serv != 0)
-		m_serv->JoinChannel(STD_STRING(name), STD_STRING(password));
-}
-
-
 bool Ui::IsSpringRunning() const
 {
 	return spring().IsRunning();
@@ -278,7 +191,7 @@ bool Ui::IsSpringRunning() const
 //! @brief Quits the entire application
 void Ui::Quit()
 {
-	Disconnect();
+	ServerManager::Instance()->DisconnectFromServer();
 	if (m_con_win != 0) {
 		m_con_win->Close();
 		delete m_con_win;
@@ -286,14 +199,6 @@ void Ui::Quit()
 	}
 }
 
-void Ui::Download(const std::string& category, const std::string& name, const std::string& /*hash */)
-{
-	int count = prDownloader().GetDownload(category, name);
-	if (count < 1) {
-		wxLogError(_("prDownloader failed to create thread!"));
-	}
-}
-
 //! @brief Display a dialog asking a question with OK and Canel buttons
 //!
 //! @return true if OK button was pressed
@@ -329,11 +234,12 @@ void Ui::ShowMessage(const wxString& heading, const wxString& message) const
 	serverMessageBox(SL_MAIN_ICON, message, heading, wxOK);
 }
 
-
+//TODO: Move this to anywhere else
 bool Ui::ExecuteSayCommand(const wxString& cmd)
 {
-	if (!IsConnected())
+	if (ServerManager::Instance()->IsConnected() == false) {
 		return false;
+	}
 
 	if ((cmd.BeforeFirst(' ').Lower() == _T("/join")) || (cmd.BeforeFirst(' ').Lower() == _T("/j"))) {
 		wxString channel = cmd.AfterFirst(' ');
@@ -350,7 +256,7 @@ bool Ui::ExecuteSayCommand(const wxString& cmd)
 		mw().GetJoinTab().GetBattleRoomTab().UpdateMyInfo();
 		return true;
 	} else if (cmd.BeforeFirst(' ').Lower() == _T("/back")) {
-		if (IsConnected()) {
+		if (ServerManager::Instance()->IsConnected()) {
 			m_serv->GetMe().Status().away = false;
 			m_serv->GetMe().SendMyUserStatus();
 			mw().GetJoinTab().GetBattleRoomTab().UpdateMyInfo();
@@ -390,7 +296,7 @@ void Ui::ConsoleHelp(const wxString& topic)
 		panel->ClientMessage(_("Global commands:"));
 		panel->ClientMessage(_("  \"/away\" - Sets your status to away."));
 		panel->ClientMessage(_("  \"/back\" - Resets your away status."));
-		panel->ClientMessage(_("  \"/changepassword2 newpassword\" - Changes the current active account's password, needs the old password saved in login box"));
+		panel->ClientMessage(_("  \"/changepassword newpassword\" - Changes the current active account's password, needs the old password saved in login box"));
 		panel->ClientMessage(_("  \"/changepassword oldpassword newpassword\" - Changes the current active account's password, password cannot contain spaces"));
 		panel->ClientMessage(_("  \"/channels\" - Lists currently active channels."));
 		panel->ClientMessage(_("  \"/help [topic]\" - Put topic if you want to know more specific information about a command."));
@@ -437,8 +343,8 @@ void Ui::OnConnected(IServer& server, const wxString& server_name, const wxStrin
 	slLogDebugFunc("");
 	m_connect_retries = 10;
 
-	if (server.uidata.panel)
-		server.uidata.panel->StatusMessage(_T("Connected to ") + server_name + _T("."));
+	if (server.panel != nullptr)
+		server.panel->StatusMessage(_T("Connected to ") + server_name + _T("."));
 	mw().GetBattleListTab().OnConnected();
 
 	delete m_con_win;
@@ -451,78 +357,17 @@ void Ui::OnConnected(IServer& server, const wxString& server_name, const wxStrin
 	std::map<std::string, LSL::SpringBundle> enginebundles = SlPaths::GetSpringVersionList();
 	if (enginebundles.size() == 0) {
 		if (Ask(_("Spring can't be found"), wxString::Format(_T("No useable spring engine can be found, download it? (spring %s)"), version.c_str()))) {
-			Download(PrDownloader::GetEngineCat(), "spring " + STD_STRING(version), "");
+			ContentDownloadRequest req;
+			req.EngineRequired("spring " + STD_STRING(version));
+			try {
+				ContentManager::Instance()->DownloadContent(req);
+			} catch (Exception& e) {
+				wxLogError(_("Failed to download engine: ") + e.Reason());
+			}
 		}
 	}
 }
 
-
-bool Ui::IsSpringCompatible(const std::string& engine, const std::string& version)
-{
-	assert(engine == "spring");
-	if (sett().GetDisableSpringVersionCheck())
-		return true;
-	const std::string ver = SlPaths::GetCompatibleVersion(version);
-	if (!ver.empty()) {
-		if (SlPaths::GetCurrentUsedSpringIndex() != ver) {
-			wxLogMessage(_T("server enforce usage of version: %s, switching to profile: %s"), TowxString(ver).c_str(), TowxString(ver).c_str());
-			SlPaths::SetUsedSpringIndex(ver);
-			LSL::usync().ReloadUnitSyncLib();
-		}
-		return true;
-	}
-	return false; // no compatible version found
-}
-
-bool Ui::DownloadArchives(const IBattle& battle)
-{
-	const std::string engineVersion = battle.GetBattleOptions().engineVersion;
-	const std::string engineName = battle.GetBattleOptions().engineName;
-
-	if (!IsSpringCompatible(engineName, engineVersion)) {
-		wxLogWarning(_T( "trying to join battles with incompatible spring version" ));
-
-		if (wxYES == customMessageBox(SL_MAIN_ICON,
-					      wxString::Format(_("The selected preset requires the engine '%s' version '%s'. Should it be downloaded?"), TowxString(engineName).c_str(), TowxString(engineVersion).c_str()),
-					      _("Engine missing"),
-					      wxYES_NO | wxICON_QUESTION)) {
-			ui().Download(PrDownloader::GetEngineCat(), engineVersion, "");
-		}
-		return false;
-	}
-
-	if (battle.MapExists() && battle.ModExists()) {
-		return true;
-	}
-
-	wxString prompt;
-	if (!battle.ModExists()) {
-		prompt += wxString::Format(_("the game '%s'"), TowxString(battle.GetHostModName()).c_str());
-	}
-
-	if (!battle.MapExists()) {
-		if (!prompt.empty()) {
-			prompt += _(" and ");
-		}
-		prompt += wxString::Format(_("the map '%s'"), TowxString(battle.GetHostMapName()).c_str());
-	}
-	if (prDownloader().IsRunning()) {
-		return true;
-	}
-	if (customMessageBox(SL_MAIN_ICON, wxString::Format(_("You need to download %s to be able to play.\n\n Shall I download it?"), prompt.c_str()),
-			     _("Content needed to be downloaded"), wxYES_NO | wxICON_QUESTION) == wxYES) {
-		if (!battle.MapExists()) {
-			ui().Download("map", battle.GetHostMapName(), battle.GetHostMapHash());
-		}
-		if (!battle.ModExists()) {
-			ui().Download("game", battle.GetHostModName(), battle.GetHostModHash());
-		}
-		return true;
-	}
-	return false;
-}
-
-
 void Ui::OnLoggedIn()
 {
 	if (m_main_win == 0)
@@ -531,7 +376,6 @@ void Ui::OnLoggedIn()
 	mw().GetBattleListTab().SortBattleList();
 }
 
-
 void Ui::OnDisconnected(IServer& server, bool wasonline)
 {
 	Start(s_reconnect_delay_ms, true);
@@ -554,9 +398,9 @@ void Ui::OnDisconnected(IServer& server, bool wasonline)
 	if (!wxTheApp->IsActive()) {
 		UiEvents::GetNotificationEventSender().SendEvent(UiEvents::NotficationData(UiEvents::ServerConnection, disconnect_msg));
 	}
-	if (server.uidata.panel) {
-		server.uidata.panel->StatusMessage(disconnect_msg);
-		server.uidata.panel->SetServer(0);
+	if (server.panel != nullptr) {
+		server.panel->StatusMessage(disconnect_msg);
+		server.panel->SetServer(0);
 	}
 	if ((!wasonline) && (m_connect_retries <= 0)) { // couldn't even estabilish a socket, prompt the user to switch to another server
 		ShowConnectWindow();
@@ -576,7 +420,6 @@ void Ui::OnJoinedChannelSuccessful(Channel& chan, bool doFocus)
 	mw().OpenChannelChat(chan, doFocus);
 }
 
-
 void Ui::OnChannelMessage(Channel& chan, const std::string& msg)
 {
 	ChatPanel* panel = GetChannelChatPanel(TowxString(chan.GetName()));
@@ -609,9 +452,9 @@ void Ui::OnUserOffline(User& user)
 	if (m_main_win == 0)
 		return;
 	mw().GetChatTab().OnUserDisconnected(user);
-	if (user.uidata.panel) {
-		user.uidata.panel->SetUser(0);
-		user.uidata.panel = 0;
+	if (user.panel != nullptr) {
+		user.panel->SetUser(0);
+		user.panel = nullptr;
 	}
 }
 
@@ -622,12 +465,12 @@ void Ui::OnUserStatusChanged(User& user)
 		return;
 	for (int i = 0; i < m_serv->GetNumChannels(); i++) {
 		Channel& chan = m_serv->GetChannel(i);
-		if ((chan.UserExists(user.GetNick())) && (chan.uidata.panel != 0)) {
-			chan.uidata.panel->UserStatusUpdated(user);
+		if ((chan.UserExists(user.GetNick())) && (chan.panel != nullptr)) {
+			chan.panel->UserStatusUpdated(user);
 		}
 	}
-	if (user.uidata.panel) {
-		user.uidata.panel->UserStatusUpdated(user);
+	if (user.panel != nullptr) {
+		user.panel->UserStatusUpdated(user);
 	}
 	if (user.GetStatus().in_game)
 		mw().GetBattleListTab().UserUpdate(user);
@@ -641,15 +484,15 @@ void Ui::OnUserStatusChanged(User& user)
 
 void Ui::OnUnknownCommand(IServer& server, const wxString& command, const wxString& params)
 {
-	if (server.uidata.panel != 0)
-		server.uidata.panel->UnknownCommand(command, params);
+	if (server.panel != nullptr)
+		server.panel->UnknownCommand(command, params);
 }
 
 
 void Ui::OnMotd(IServer& server, const wxString& message)
 {
-	if (server.uidata.panel != 0)
-		server.uidata.panel->Motd(message);
+	if (server.panel != nullptr)
+		server.panel->Motd(message);
 }
 
 void Ui::OnServerBroadcast(IServer& /*server*/, const wxString& message)
@@ -667,16 +510,16 @@ void Ui::OnServerBroadcast(IServer& /*server*/, const wxString& message)
 void Ui::OnServerMessage(IServer& server, const wxString& message)
 {
 	if (!cfg().ReadBool(_T("/Chat/BroadcastEverywhere"))) {
-		if (server.uidata.panel != 0)
-			server.uidata.panel->StatusMessage(message);
+		if (server.panel != nullptr)
+			server.panel->StatusMessage(message);
 	} else {
-		if (server.uidata.panel != 0)
-			server.uidata.panel->StatusMessage(message);
-		if (m_main_win == 0)
+		if (server.panel != nullptr)
+			server.panel->StatusMessage(message);
+		if (m_main_win == nullptr)
 			return;
 		ChatPanel* activepanel = mw().GetChatTab().GetActiveChatPanel();
-		if (activepanel != 0) {
-			if (activepanel != server.uidata.panel)
+		if (activepanel != nullptr) {
+			if (activepanel != server.panel)
 				activepanel->StatusMessage(message); // don't send it twice to the server tab
 		}
 		try { // send it to battleroom too
@@ -691,26 +534,26 @@ void Ui::OnUserSaid(User& user, const wxString& message, bool fromme)
 {
 	if (m_main_win == 0)
 		return;
-	if (user.uidata.panel == 0) {
+	if (user.panel == nullptr) {
 		mw().OpenPrivateChat(user);
 	}
 	if (fromme)
-		user.uidata.panel->Said(TowxString(m_serv->GetMe().GetNick()), message);
+		user.panel->Said(TowxString(m_serv->GetMe().GetNick()), message);
 	else
-		user.uidata.panel->Said(TowxString(user.GetNick()), message);
+		user.panel->Said(TowxString(user.GetNick()), message);
 }
 
 void Ui::OnUserSaidEx(User& user, const wxString& action, bool fromme)
 {
 	if (m_main_win == 0)
 		return;
-	if (user.uidata.panel == 0) {
+	if (user.panel == 0) {
 		mw().OpenPrivateChat(user);
 	}
 	if (fromme)
-		user.uidata.panel->DidAction(TowxString(m_serv->GetMe().GetNick()), action);
+		user.panel->DidAction(TowxString(m_serv->GetMe().GetNick()), action);
 	else
-		user.uidata.panel->DidAction(TowxString(user.GetNick()), action);
+		user.panel->DidAction(TowxString(user.GetNick()), action);
 }
 
 void Ui::OnBattleOpened(IBattle& battle)
@@ -722,8 +565,8 @@ void Ui::OnBattleOpened(IBattle& battle)
 		User& user = battle.GetFounder();
 		for (int i = 0; i < m_serv->GetNumChannels(); i++) {
 			Channel& chan = m_serv->GetChannel(i);
-			if ((chan.UserExists(user.GetNick())) && (chan.uidata.panel != 0)) {
-				chan.uidata.panel->UserStatusUpdated(user);
+			if ((chan.UserExists(user.GetNick())) && (chan.panel != nullptr)) {
+				chan.panel->UserStatusUpdated(user);
 			}
 		}
 	} catch (...) {
@@ -749,8 +592,8 @@ void Ui::OnBattleClosed(IBattle& battle)
 		user.SetBattle(0);
 		for (int i = 0; i < m_serv->GetNumChannels(); i++) {
 			Channel& chan = m_serv->GetChannel(i);
-			if ((chan.UserExists(user.GetNick())) && (chan.uidata.panel != 0)) {
-				chan.uidata.panel->UserStatusUpdated(user);
+			if ((chan.UserExists(user.GetNick())) && (chan.panel != nullptr)) {
+				chan.panel->UserStatusUpdated(user);
 			}
 		}
 	}
@@ -773,8 +616,8 @@ void Ui::OnUserJoinedBattle(IBattle& battle, User& user)
 
 	for (int i = 0; i < m_serv->GetNumChannels(); i++) {
 		Channel& chan = m_serv->GetChannel(i);
-		if ((chan.UserExists(user.GetNick())) && (chan.uidata.panel != 0)) {
-			chan.uidata.panel->UserStatusUpdated(user);
+		if ((chan.UserExists(user.GetNick())) && (chan.panel != nullptr)) {
+			chan.panel->UserStatusUpdated(user);
 		}
 	}
 }
@@ -803,8 +646,8 @@ void Ui::OnUserLeftBattle(IBattle& battle, User& user, bool isbot)
 		return;
 	for (int i = 0; i < m_serv->GetNumChannels(); i++) {
 		Channel& chan = m_serv->GetChannel(i);
-		if ((chan.UserExists(user.GetNick())) && (chan.uidata.panel != 0)) {
-			chan.uidata.panel->UserStatusUpdated(user);
+		if ((chan.UserExists(user.GetNick())) && (chan.panel != nullptr)) {
+			chan.panel->UserStatusUpdated(user);
 		}
 	}
 }
@@ -845,12 +688,20 @@ void Ui::OnHostedBattle(IBattle& battle)
 }
 
 
-void Ui::OnUserBattleStatus(IBattle& battle, User& user)
+void Ui::OnUserBattleStatus(wxCommandEvent& event)
 {
-	if (m_main_win == 0)
+	if (m_main_win == 0) {
 		return;
-	mw().GetJoinTab().BattleUserUpdated(user);
-	OnBattleInfoUpdated(std::make_pair(&battle, ""));
+	}
+
+	User* user = static_cast<User*>(event.GetClientData());
+	mw().GetJoinTab().BattleUserUpdated(*user);
+	IBattle* battle = user->GetBattle();
+	if (battle == nullptr) {
+		wxLogWarning("trying to update non-existing battle");
+		return;
+	}
+	OnBattleInfoUpdated(std::make_pair(battle, ""));
 }
 
 
@@ -867,15 +718,6 @@ void Ui::OnRequestBattleStatus(IBattle& battle)
 }
 
 
-void Ui::OnBattleStarted(IBattle& battle)
-{
-	if (m_main_win == 0)
-		return;
-	slLogDebugFunc("");
-	mw().GetBattleListTab().UpdateBattle(battle);
-}
-
-
 void Ui::OnSaidBattle(IBattle& /*battle*/, const wxString& nick, const wxString& msg)
 {
 	if (m_main_win == 0)
@@ -948,25 +790,20 @@ bool Ui::IsThisMe(User& other) const
 	return IsThisMe(TowxString(other.GetNick()));
 }
 
-bool Ui::IsThisMe(User* other) const
+bool Ui::IsThisMe(const User* other) const
 {
-	return ((other != 0) && IsThisMe(TowxString(other->GetNick())));
+	return ((other != nullptr) && IsThisMe(TowxString(other->GetNick())));
 }
 
 bool Ui::IsThisMe(const wxString& other) const
 {
 	//if i'm not connected i have no identity
-	if (!IsConnected() || m_serv == 0)
+	if (!ServerManager::Instance()->IsConnected() || m_serv == 0)
 		return false;
 	else
 		return (STD_STRING(other) == m_serv->GetMe().GetNick());
 }
 
-int Ui::TestHostPort(unsigned int port) const
-{
-	return m_serv->TestOpenPort(port);
-}
-
 void Ui::ReloadPresetList()
 {
 	try {
@@ -987,7 +824,14 @@ bool Ui::OnPresetRequiringMap(const wxString& mapname)
                                     Please reselect the preset after download finished"),
 				      _("Map missing"),
 				      wxYES_NO)) {
-		Download("map", STD_STRING(mapname), "");
+		ContentDownloadRequest req;
+		req.MapRequired(STD_STRING(mapname), "");
+		try {
+			ContentManager::Instance()->DownloadContent(req);
+		} catch (Exception& e) {
+			wxLogError(_("Failed to download map: ") + e.Reason());
+			return false;
+		}
 		return true;
 	}
 	return false;
@@ -1014,7 +858,7 @@ void Ui::OnInit()
 		FirstRunWelcome();
 	} else {
 		if (cfg().ReadBool(_T( "/Server/Autoconnect" ))) {
-			Connect(); // OnConnect changes tab
+			ServerManager::Instance()->ConnectToServer(); // OnConnect changes tab
 		}
 		mw().ShowTab(cfg().ReadLong(_T( "/GUI/StartTab" )));
 		//don't ask for updates on first run, that's a bit much for a newbie
@@ -1039,38 +883,6 @@ void Ui::FirstRunWelcome()
 	ShowConnectWindow();
 }
 
-
-bool Ui::StartUpdate(const std::string& latestVersion)
-{
-	const wxString updatedir = TowxString(SlPaths::GetUpdateDir());
-	const size_t mindirlen = 9; // safety, minimal is/should be: C:\update
-	if ((updatedir.size() <= mindirlen)) {
-		wxLogError(_T("Invalid update dir: ") + updatedir);
-		return false;
-	}
-	if (wxDirExists(updatedir)) {
-		if (!SlPaths::RmDir(STD_STRING(updatedir))) {
-			wxLogWarning(_T("Couldn't cleanup ") + updatedir);
-		}
-	}
-	if (!SafeMkdir(updatedir)) {
-		wxLogWarning(_T("couldn't create update directory") + updatedir);
-	}
-
-	if (!wxFileName::IsDirWritable(updatedir)) {
-		wxLogError(_T("dir not writable: ") + updatedir);
-		return false;
-	}
-
-	const std::string dlfilepath = SlPaths::GetLobbyWriteDir() + "springlobby-latest.zip";
-	if (wxFileExists(TowxString(dlfilepath)) && !(wxRemoveFile(TowxString(dlfilepath)))) {
-		wxLogError(_T("couldn't delete: ") + TowxString(dlfilepath));
-		return false;
-	}
-	const std::string dlurl = GetDownloadUrl(latestVersion);
-	return prDownloader().Download(dlfilepath, dlurl);
-}
-
 void Ui::OnDownloadComplete(wxCommandEvent& data)
 {
 	if (data.GetInt() != 0) {
@@ -1100,22 +912,26 @@ void Ui::OnDownloadComplete(wxCommandEvent& data)
 
 void Ui::CheckForUpdates(bool show)
 {
-	wxString latestVersion = GetHttpFile(cfg().ReadString("/General/UpdateUrl"));
-	// Need to replace crap chars or versions will always be inequal
-	latestVersion.Replace(_T(" "), wxEmptyString, true);
-	latestVersion.Replace(_T("\n"), wxEmptyString, true);
-	latestVersion.Replace(_T("\t"), wxEmptyString, true);
+	ContentManager* contMan = ContentManager::Instance();
 
+	const wxString latestVersion = contMan->GetLatestApplicationVersionAvailable();
 
 	if (latestVersion.empty()) {
-		customMessageBoxNoModal(SL_MAIN_ICON, _("There was an error checking for the latest version.\nPlease try again later.\nIf the problem persists, please use Help->Report Bug to report this bug."), _("Error"));
+		if (show) {
+			customMessageBoxNoModal(SL_MAIN_ICON, _("There was an error checking for the latest version.\nPlease try again later.\nIf the problem persists, please use Help->Report Bug to report this bug."), _("Error"));
+		}
 		return;
 	}
 	//get current rev w/o AUX_VERSION added
 	const wxString myVersion = TowxString(getSpringlobbyVersion());
 
 	const wxString msg = _("Your Version: ") + myVersion + _T("\n") + _("Latest Version: ") + latestVersion;
-	if (!latestVersion.IsSameAs(myVersion, false)) {
+	if (latestVersion.IsSameAs(myVersion, false)) {
+		if (show) {
+				customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is up to date.\n\n") + msg, _("Up to Date"));
+		}
+		return;
+	}
 #ifdef __WXMSW__
 		int answer = customMessageBox(SL_MAIN_ICON,
 					      wxString::Format(_("Your %s version is not up to date.\n\n%s\n\nWould you like to update to the new version?"),
@@ -1123,25 +939,33 @@ void Ui::CheckForUpdates(bool show)
 							       msg.c_str()),
 					      _("Not up to date"), wxOK | wxCANCEL);
 		if (answer == wxOK) {
-			if (!StartUpdate(STD_STRING(latestVersion))) {
+			try{
+				if (!contMan->UpdateApplication()) {
+					//this will also happen if updater exe is not present so we don't really ne special check for existance of it
+					customMessageBox(SL_MAIN_ICON, _("Automatic update failed\n\nyou will be redirected to a web page with instructions and the download link will be opened in your browser.") + msg, _("Updater error."));
+					OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
+					OpenWebBrowser(TowxString(GetDownloadUrl(STD_STRING(latestVersion))));
+				}
+			} catch(Exception& ex) {
 				//this will also happen if updater exe is not present so we don't really ne special check for existance of it
-				customMessageBox(SL_MAIN_ICON, _("Automatic update failed\n\nyou will be redirected to a web page with instructions and the download link will be opened in your browser.") + msg, _("Updater error."));
+				const wxString errormsg = wxString::Format(_("Automatic update failed\n\
+						%s\n\
+						you will be redirected to a web page with instructions and the download link will be opened in your browser. %s"), ex.Reason(), msg);
+				customMessageBox(SL_MAIN_ICON, errormsg, _("Updater error."));
 				OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
 				OpenWebBrowser(TowxString(GetDownloadUrl(STD_STRING(latestVersion))));
+				return;
 			}
 		}
 #else
 		customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is not up to date.\n\n") + msg, _("Not up to Date"));
 #endif
-	} else if (show) {
-		customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is up to date.\n\n") + msg, _("Up to Date"));
-	}
 }
 
 
 void Ui::OnQuit(wxCommandEvent& /*data*/)
 {
-	Disconnect();
+	ServerManager::Instance()->DisconnectFromServer();
 	delete m_serv;
 	m_serv = NULL;
 }
@@ -1152,7 +976,7 @@ void Ui::Notify()
 	if (m_serv->IsConnected() || (m_con_win != NULL && m_con_win->IsVisible())) {
 		Stop();
 	} else {
-		Reconnect();
+		ServerManager::Instance()->ReconnectToServer();
 	}
 }
 
@@ -1170,7 +994,7 @@ void Ui::OnRegistrationDenied(const wxString& reason)
 		m_con_win = new ConnectWindow(m_main_win, *this);
 	}
 	m_con_win->OnRegistrationDenied(reason);
-	Disconnect();
+	ServerManager::Instance()->DisconnectFromServer();
 }
 
 void Ui::OnLoginDenied(const std::string& reason)
@@ -1179,5 +1003,5 @@ void Ui::OnLoginDenied(const std::string& reason)
 		m_con_win = new ConnectWindow(m_main_win, *this);
 	}
 	m_con_win->OnLoginDenied(TowxString(reason));
-	Disconnect();
+	ServerManager::Instance()->DisconnectFromServer();
 }
