@@ -4,9 +4,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/battle/ibattle.cpp
 
@@ -34,6 +32,8 @@ lsl/battle/ibattle.cpp
 #include "serverselector.h"
 #include "log.h"
 
+#define MAX_TEAMS 255
+
 
 IBattle::IBattle()
     : m_autohost_manager(NULL)
@@ -41,7 +41,7 @@ IBattle::IBattle()
     , m_is_self_in(false)
     , m_ingame(false)
     , m_map_loaded(false)
-    , m_mod_loaded(false)
+    , m_game_loaded(false)
     , m_players_ready(0)
     , m_players_sync(0)
     , m_players_ok(0)
@@ -54,7 +54,7 @@ IBattle::~IBattle()
 {
 	try {
 		if (m_is_self_in)
-			LSL::usync().UnSetCurrentMod();
+			LSL::usync().UnSetCurrentArchive();
 	} catch (const LSL::Util::GlobalDestroyedError& err) {
 		/* If this is called during TAServer::~TAServer, then unitsync might be unavailable. */
 	}
@@ -63,26 +63,26 @@ IBattle::~IBattle()
 
 bool IBattle::IsSynced()
 {
-	LoadMod();
+	LoadGame();
 	LoadMap();
-	if (!m_host_mod.name.empty() && m_local_mod.name != m_host_mod.name) {
-		wxLogWarning("Not synced: game name doesn't match: %s %s", m_host_mod.name.c_str(), m_local_mod.name.c_str());
+	if (!m_host_game.name.empty() && m_local_game.name != m_host_game.name) {
+		wxLogWarning("Not synced: game name doesn't match: '%s' '%s'", m_host_game.name.c_str(), m_local_game.name.c_str());
 		return false;
 	}
 	if (!m_host_map.name.empty() && m_local_map.name != m_host_map.name) {
-		wxLogWarning("Not synced: map name doesn't match: %s %s", m_host_map.name.c_str(), m_local_map.name.c_str());
+		wxLogWarning("Not synced: map name doesn't match: '%s' '%s'", m_host_map.name.c_str(), m_local_map.name.c_str());
 		return false;
 	}
-	if (!m_host_mod.hash.empty() && m_host_mod.hash != "0" && m_host_mod.hash != m_local_mod.hash) {
-		wxLogWarning("Not synced: game hash doesn't match: %s %s", m_host_mod.hash.c_str(), m_host_mod.hash.c_str());
+	if (!m_host_game.hash.empty() && m_host_game.hash != "0" && m_host_game.hash != m_local_game.hash) {
+		wxLogWarning("Not synced: game hash doesn't match: '%s' '%s'", m_host_game.hash.c_str(), m_local_game.hash.c_str());
 		return false;
 	}
 	if (!m_host_map.hash.empty() && m_host_map.hash != "0" && m_host_map.hash != m_local_map.hash) {
-		wxLogWarning("Not synced: map hash doesn't match: %s %s", m_host_map.hash.c_str(), m_local_map.hash.c_str());
+		wxLogWarning("Not synced: map hash doesn't match: '%s' '%s'", m_host_map.hash.c_str(), m_local_map.hash.c_str());
 		return false;
 	}
-	if (!ModExists()) {
-		wxLogWarning("Not synced: game doesn't exist: %s %s", m_host_mod.name.c_str());
+	if (!GameExists()) {
+		wxLogWarning("Not synced: game doesn't exist: %s %s", m_host_game.name.c_str());
 		return false;
 	}
 	if (!MapExists()) {
@@ -405,6 +405,8 @@ bool IBattle::IsEveryoneReady() const
 
 void IBattle::AddStartRect(unsigned int allyno, unsigned int left, unsigned int top, unsigned int right, unsigned int bottom)
 {
+	assert(allyno<MAX_TEAMS);
+
 	BattleStartRect sr;
 
 	sr.ally = allyno;
@@ -423,6 +425,7 @@ void IBattle::AddStartRect(unsigned int allyno, unsigned int left, unsigned int
 
 void IBattle::RemoveStartRect(unsigned int allyno)
 {
+	assert(allyno<MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
@@ -436,6 +439,7 @@ void IBattle::RemoveStartRect(unsigned int allyno)
 
 void IBattle::ResizeStartRect(unsigned int allyno)
 {
+	assert(allyno<MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
@@ -449,6 +453,7 @@ void IBattle::ResizeStartRect(unsigned int allyno)
 
 void IBattle::StartRectRemoved(unsigned int allyno)
 {
+	assert(allyno<MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::const_iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
@@ -460,6 +465,7 @@ void IBattle::StartRectRemoved(unsigned int allyno)
 
 void IBattle::StartRectResized(unsigned int allyno)
 {
+	assert(allyno<MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
@@ -473,6 +479,7 @@ void IBattle::StartRectResized(unsigned int allyno)
 
 void IBattle::StartRectAdded(unsigned int allyno)
 {
+	assert(allyno<MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
@@ -486,6 +493,7 @@ void IBattle::StartRectAdded(unsigned int allyno)
 
 BattleStartRect IBattle::GetStartRect(unsigned int allyno) const
 {
+	assert(allyno<MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::const_iterator rect_it = m_rects.find(allyno);
 	if (rect_it != m_rects.end())
 		return (*rect_it).second;
@@ -501,8 +509,11 @@ unsigned int IBattle::GetNumRects() const
 //key of last start rect in the map
 unsigned int IBattle::GetLastRectIdx() const
 {
-	if (GetNumRects() > 0)
-		return m_rects.rbegin()->first;
+	if (GetNumRects() > 0) {
+		const unsigned int res = m_rects.rbegin()->first;
+		assert(res < MAX_TEAMS);
+		return res;
+	}
 
 	return 0;
 }
@@ -510,12 +521,17 @@ unsigned int IBattle::GetLastRectIdx() const
 //return  the lowest currently unused key in the map of rects.
 unsigned int IBattle::GetNextFreeRectIdx() const
 {
+	const size_t num = GetNumRects();
+	if (num == 0) //rects start at 1
+		return 1;
 	//check for unused allyno keys
-	for (unsigned int i = 0; i <= GetLastRectIdx(); i++) {
-		if (!GetStartRect(i).IsOk())
+	for (unsigned int i = 1; i <= GetLastRectIdx(); i++) {
+		if (!GetStartRect(i).IsOk()) {
+			assert(i<MAX_TEAMS);
 			return i;
+		}
 	}
-	return GetNumRects(); //if all rects are in use, or no elements exist, return first possible available allyno.
+	return num;//if all rects are in use, or no elements exist, return first possible available allyno.
 }
 
 void IBattle::ClearStartRects()
@@ -699,11 +715,10 @@ UserPosition IBattle::GetFreePosition()
 }
 
 
-void IBattle::SetHostMap(const std::string& _mapname, const std::string& _hash)
+void IBattle::SetHostMap(const std::string& mapname, const std::string& hash)
 {
-	ASSERT_LOGIC(!_mapname.empty(), "Battle with empty map name!");
-	const std::string mapname(_mapname);
-	const std::string hash(_hash);
+	assert(hash.empty() || LSL::Util::MakeHashUnsigned(hash) == hash);
+	ASSERT_LOGIC(!mapname.empty(), "Battle with empty map name!");
 	if (mapname != m_host_map.name || hash != m_host_map.hash) {
 		m_map_loaded = false;
 		m_host_map.name = mapname;
@@ -729,9 +744,10 @@ void IBattle::SetLocalMap(const std::string& mapname)
 const LSL::UnitsyncMap& IBattle::LoadMap()
 {
 	if ((!m_map_loaded) && (!m_host_map.name.empty())) {
-		if (MapExists(false)) { //Check if selected map available for engine?
+		if (MapExists(true)) { //Check if selected map available for engine?
 			try {
 				m_local_map = LSL::usync().GetMap(m_host_map.name);
+				assert(LSL::Util::MakeHashUnsigned(m_local_map.hash) == m_local_map.hash);
 				bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::MapOption, m_host_map.name);
 				//TODO: maybe replace this with "silent" IF operator?
 				ASSERT_EXCEPTION(options_loaded, _T("couldn't load the map options"));
@@ -756,54 +772,58 @@ std::string IBattle::GetHostMapHash() const
 }
 
 
-void IBattle::SetHostMod(const std::string& _modname, const std::string& _hash)
+void IBattle::SetHostGame(const std::string& gamename, const std::string& hash)
 {
-	const std::string modname(_modname);
-	const std::string hash(_hash);
-	if (m_host_mod.name != modname || m_host_mod.hash != hash) {
-		m_mod_loaded = false;
-		m_host_mod.name = modname;
-		m_host_mod.hash = hash;
+	assert(hash.empty() || LSL::Util::MakeHashUnsigned(hash) == hash);
+	if (m_host_game.name != gamename || m_host_game.hash != hash) {
+		m_game_loaded = false;
+		m_host_game.name = gamename;
+		m_host_game.hash = hash;
 	}
 }
 
 
-void IBattle::SetLocalMod(const LSL::UnitsyncMod& mod)
+void IBattle::SetLocalGame(const LSL::UnitsyncGame& mod)
 {
-	if (mod.name != m_local_mod.name || mod.hash != m_local_mod.hash) {
-		m_previous_local_mod_name = m_local_mod.name;
-		m_local_mod = mod;
-		m_mod_loaded = true;
+	assert(mod.hash.empty() || LSL::Util::MakeHashUnsigned(mod.hash) == mod.hash); // hash has to be in unsigned format
+	if (mod.hash.empty()) {
+		wxLogWarning("empty hash: %s", mod.name);
+	}
+	if (mod.name != m_local_game.name || mod.hash != m_local_game.hash) {
+		m_previous_local_game_name = m_local_game.name;
+		m_local_game = mod;
+		m_game_loaded = true;
 	}
 }
 
 
-const LSL::UnitsyncMod& IBattle::LoadMod()
+const LSL::UnitsyncGame& IBattle::LoadGame()
 {
-	ASSERT_LOGIC(!m_host_mod.name.empty(), "m_host_mod.name.empty() is FALSE");
-	if (!m_mod_loaded) {
-		try {
-			ASSERT_EXCEPTION(ModExists(), wxString::Format("Game does not exist: %s hash:%s", m_host_mod.name.c_str(), m_host_mod.hash.c_str()));
-			m_local_mod = LSL::usync().GetMod(m_host_mod.name);
-			bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::ModOption, m_host_mod.name);
-			ASSERT_EXCEPTION(options_loaded, _T("couldn't load the game options"));
-			m_mod_loaded = true;
-		} catch (...) {
+	ASSERT_LOGIC(!m_host_game.name.empty(), "m_host_game.name.empty() is FALSE");
+	if (!m_game_loaded) {
+		if (GameExists(true)) {
+			try {
+				SetLocalGame(LSL::usync().GetGame(m_host_game.name));
+				bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::ModOption, m_host_game.name);
+				ASSERT_EXCEPTION(options_loaded, _T("couldn't load the game options"));
+				m_game_loaded = true;
+			} catch (...) {
+			}
 		}
 	}
-	return m_local_mod;
+	return m_local_game;
 }
 
 
-std::string IBattle::GetHostModName() const
+std::string IBattle::GetHostGameName() const
 {
-	return m_host_mod.name;
+	return m_host_game.name;
 }
 
 
-std::string IBattle::GetHostModHash() const
+std::string IBattle::GetHostGameHash() const
 {
-	return m_host_mod.hash;
+	return m_host_game.hash;
 }
 
 
@@ -816,11 +836,11 @@ bool IBattle::MapExists(bool comparehash) const
 }
 
 
-bool IBattle::ModExists(bool comparehash) const
+bool IBattle::GameExists(bool comparehash) const
 {
 	if (comparehash)
-		return LSL::usync().ModExists(m_host_mod.name, m_host_mod.hash);
-	return LSL::usync().ModExists(m_host_mod.name, "");
+		return LSL::usync().GameExists(m_host_game.name, m_host_game.hash);
+	return LSL::usync().GameExists(m_host_game.name, "");
 }
 
 void IBattle::RestrictUnit(const std::string& unitname, int count)
@@ -867,7 +887,7 @@ void IBattle::OnSelfLeftBattle()
 	m_players_ready = 0;
 	m_players_sync = 0;
 	m_players_ok = 0;
-	LSL::usync().UnSetCurrentMod(); //left battle
+	LSL::usync().UnSetCurrentArchive(); //left battle
 }
 
 static std::string FixPresetName(const std::string& name)
@@ -959,7 +979,7 @@ void IBattle::SaveOptionsPreset(const std::string& name)
 			std::map<wxString, wxString> opts;
 			opts[_T("mapname")] = TowxString(GetHostMapName());
 			unsigned int validrectcount = 0;
-			if (LSL::Util::FromString<long>(
+			if (LSL::Util::FromIntString(
 				CustomBattleOptions().getSingleValue("startpostype", LSL::Enum::EngineOption)) == ST_Choose) {
 				unsigned int boxcount = GetLastRectIdx();
 				for (unsigned int boxnum = 0; boxnum <= boxcount; boxnum++) {
@@ -1096,18 +1116,18 @@ void IBattle::GetBattleFromScript(bool loadmapmod)
 	LSL::TDF::PDataList replayNode(script->Find("GAME"));
 	if (replayNode.ok()) {
 
-		std::string modname = replayNode->GetString("GameType");
-		std::string modhash = replayNode->GetString("ModHash");
-		if (!modhash.empty())
-			modhash = LSL::Util::MakeHashUnsigned(modhash);
-		SetHostMod(modname, modhash);
+		std::string gamename = replayNode->GetString("GameType");
+		std::string gamehash = replayNode->GetString("ModHash");
+		if (!gamehash.empty())
+			gamehash = LSL::Util::MakeHashUnsigned(gamehash);
+		SetHostGame(gamename, gamehash);
 
 		//don't have the maphash, what to do?
 		//ui download function works with mapname if hash is empty, so works for now
 		std::string mapname = replayNode->GetString("MapName");
 		std::string maphash = replayNode->GetString("MapHash");
-		if (!modhash.empty())
-			modhash = LSL::Util::MakeHashUnsigned(maphash);
+		if (!gamehash.empty())
+			gamehash = LSL::Util::MakeHashUnsigned(maphash);
 		SetHostMap(mapname, maphash);
 
 		//        opts.ip         = replayNode->GetString( _T("HostIP") );
@@ -1124,7 +1144,7 @@ void IBattle::GetBattleFromScript(bool loadmapmod)
 
 		LSL::StringVector sides;
 		if (loadmapmod) {
-			sides = LSL::usync().GetSides(modname);
+			sides = LSL::usync().GetSides(gamename);
 		}
 
 		IBattle::TeamVec parsed_teams = GetParsedTeamsVec();
@@ -1263,3 +1283,18 @@ User& IBattle::GetFounder() const
 {
 	return GetUser(m_opts.founder);
 }
+
+void IBattle::RemoveUnfittingBots()
+{
+	const auto old_ais = LSL::usync().GetAIList(m_previous_local_game_name);
+	const auto new_ais = LSL::usync().GetAIList(m_local_game.name);
+	LSL::StringVector diff(old_ais.size());
+	LSL::StringVector::iterator end = std::set_difference(old_ais.begin(), old_ais.end(), new_ais.begin(), new_ais.end(), diff.begin());
+	for (auto it = diff.begin(); it != end; ++it) {
+		for (size_t j = 0; j < GetNumUsers(); ++j) {
+			User& u = GetUser(j);
+			if (u.GetBattleStatus().airawname == *it)
+				KickPlayer(u);
+		}
+	}
+}
