@@ -23,15 +23,16 @@ private:
 };
 
 #define slLogDebugFunc(format, ...) \
-	wxLogDebug("%s:%d %s(): " format, __FILE__, __LINE__, __FUNCTION__, ##__VA_ARGS__);
+	wxLogDebug(format, ##__VA_ARGS__);
 
 #include <stdexcept>
 class assert_exception : public std::runtime_error
 {
 public:
-	assert_exception(std::string msg)
+	explicit assert_exception(std::string msg)
 	    : std::runtime_error(msg)
 	{
+		wxLogWarning("%s", msg.c_str());
 	}
 };
 
