@@ -1,4 +1,4 @@
-/* Copyright (C) 2007 The SpringLobby Team. All rights reserved. */
+/* This file is part of the Springlobby (GPL v2 or later), see COPYING */
 
 #include "unitsync.h"
 
@@ -26,7 +26,7 @@
 
 #define LOCK_UNITSYNC boost::mutex::scoped_lock lock_criticalsection(m_lock)
 
-#define ASYNC_LOAD 0
+#define ASYNC_LOAD 0 //FIXME: repair/set to 1!
 #if ASYNC_LOAD
 #define TRY_LOCK(ret)                                               \
 	boost::mutex::scoped_try_lock lock_criticalsection(m_lock); \
@@ -124,15 +124,15 @@ void Unitsync::FetchUnitsyncErrors(const std::string& prefix)
 	if (!prefix.empty()) {
 		pre += " ";
 	}
-	for(const std::string error: errors ) {
-		LslWarning("Unitsync: %s%s",pre.c_str(), error.c_str() );
+	for (const std::string error : errors) {
+		LslWarning("Unitsync: %s%s", pre.c_str(), error.c_str());
 	}
 }
 
 static std::string GetGameInfo(int index, const std::string keyname)
 {
 	const int count = susynclib().GetPrimaryModInfoCount(index);
-	for (int i=0; i < count; i++) {
+	for (int i = 0; i < count; i++) {
 		const std::string key = Util::SafeString(susynclib().GetInfoKey(i));
 		if (key == keyname) {
 			return Util::SafeString(susynclib().GetInfoValueString(i));
@@ -161,7 +161,7 @@ void Unitsync::PopulateArchiveList()
 		}
 		try {
 			assert(!name.empty());
-			m_maps_list[name] = LSL::Util::ToString(hash);
+			m_maps_list[name] = LSL::Util::ToUIntString(hash);
 			if (!archivename.empty())
 				m_maps_archive_name[name] = archivename;
 			m_map_array.push_back(name);
@@ -186,7 +186,7 @@ void Unitsync::PopulateArchiveList()
 		}
 		try {
 			assert(!name.empty());
-			m_mods_list[name] = LSL::Util::ToString(hash);
+			m_mods_list[name] = LSL::Util::ToUIntString(hash);
 			if (!archivename.empty())
 				m_mods_archive_name[name] = archivename;
 			m_mod_array.push_back(name);
@@ -238,16 +238,16 @@ std::string Unitsync::GetSpringVersion() const
 }
 
 
-StringVector Unitsync::GetModList() const
+StringVector Unitsync::GetGameList() const
 {
 	TRY_LOCK(StringVector())
 	return m_mod_array;
 }
 
-bool Unitsync::ModExists(const std::string& modname, const std::string& hash) const
+bool Unitsync::GameExists(const std::string& gamename, const std::string& hash) const
 {
 	TRY_LOCK(false)
-	LocalArchivesVector::const_iterator itor = m_mods_list.find(modname);
+	LocalArchivesVector::const_iterator itor = m_mods_list.find(gamename);
 	if (itor == m_mods_list.end())
 		return false;
 	if (hash.empty() || hash == "0")
@@ -255,19 +255,19 @@ bool Unitsync::ModExists(const std::string& modname, const std::string& hash) co
 	return itor->second == hash;
 }
 
-UnitsyncMod Unitsync::GetMod(const std::string& modname)
+UnitsyncGame Unitsync::GetGame(const std::string& gamename)
 {
-	UnitsyncMod m;
+	UnitsyncGame m;
 	TRY_LOCK(m);
-	m.name = modname;
-	m.hash = m_mods_list[modname];
+	m.name = gamename;
+	m.hash = m_mods_list[gamename];
 	return m;
 }
 
 
-UnitsyncMod Unitsync::GetMod(int index)
+UnitsyncGame Unitsync::GetGame(int index)
 {
-	UnitsyncMod m;
+	UnitsyncGame m;
 	TRY_LOCK(m);
 	m.name = m_mod_array[index];
 	m.hash = m_mods_list[m.name];
@@ -280,12 +280,12 @@ StringVector Unitsync::GetMapList() const
 	return m_map_array;
 }
 
-StringVector Unitsync::GetModValidMapList(const std::string& modname) const
+StringVector Unitsync::GetGameValidMapList(const std::string& gamename) const
 {
 	StringVector ret;
 	TRY_LOCK(ret)
 	try {
-		unsigned int mapcount = susynclib().GetValidMapCount(modname);
+		unsigned int mapcount = susynclib().GetValidMapCount(gamename);
 		for (unsigned int i = 0; i < mapcount; i++)
 			ret.push_back(susynclib().GetValidMapName(i));
 	} catch (Exceptions::unitsync& e) {
@@ -401,7 +401,7 @@ UnitsyncMap Unitsync::GetMap(const std::string& mapname)
 	return m;
 }
 
-GameOptions Unitsync::GetModOptions(const std::string& name)
+GameOptions Unitsync::GetGameOptions(const std::string& name)
 {
 	assert(!name.empty());
 	GameOptions ret;
@@ -419,34 +419,35 @@ GameOptions Unitsync::GetModOptions(const std::string& name)
 	return ret;
 }
 
-StringVector Unitsync::GetModDeps(const std::string& modname) const
+StringVector Unitsync::GetGameDeps(const std::string& gamename) const
 {
-	assert(!modname.empty());
+	assert(!gamename.empty());
 	StringVector ret;
 	TRY_LOCK(ret)
 	try {
-		ret = susynclib().GetModDeps(Util::IndexInSequence(m_unsorted_mod_array, modname));
+		ret = susynclib().GetModDeps(Util::IndexInSequence(m_unsorted_mod_array, gamename));
 	} catch (Exceptions::unitsync& u) {
 	}
 	return ret;
 }
 
-StringVector Unitsync::GetSides(const std::string& modname)
+StringVector Unitsync::GetSides(const std::string& gamename)
 {
-	assert(!modname.empty());
+	assert(!gamename.empty());
 	StringVector ret;
 	TRY_LOCK(ret);
-	const std::string cachefile = GetFileCachePath(modname, true) + ".sides";
+	const std::string cachefile = GetFileCachePath(gamename, true) + ".sides";
 	if (m_sides_cache.TryGet(cachefile, ret)) { //first return from mru cache
 		return ret;
 	}
 
-	if (!GetCacheFile(cachefile, ret) && (ModExists(modname))) { // cache file failed, try from lsl
+	if (!GetCacheFile(cachefile, ret) && (GameExists(gamename))) { // cache file failed, try from lsl
 		try {
-			ret = susynclib().GetSides(modname);
+			ret = susynclib().GetSides(gamename);
 			SetCacheFile(cachefile, ret); //store into cachefile
 		} catch (Exceptions::unitsync& u) {
-			LSL_THROWF(unitsync, "Error in GetSides: %s", modname.c_str());
+			LslWarning("Error in GetSides: %s %s", gamename.c_str(), u.what());
+			return ret;
 		}
 	}
 	m_sides_cache.Add(cachefile, ret); //store into mru
@@ -454,11 +455,11 @@ StringVector Unitsync::GetSides(const std::string& modname)
 }
 
 
-UnitsyncImage Unitsync::GetSidePicture(const std::string& modname, const std::string& SideName)
+UnitsyncImage Unitsync::GetSidePicture(const std::string& gamename, const std::string& SideName)
 {
-	assert(!modname.empty());
+	assert(!gamename.empty());
 
-	const std::string cachepath = GetFileCachePath(modname, true, false) + "-side-" + SideName + ".png";
+	const std::string cachepath = GetFileCachePath(gamename, true, false) + "-side-" + SideName + ".png";
 	UnitsyncImage img;
 	TRY_LOCK(img);
 
@@ -471,9 +472,14 @@ UnitsyncImage Unitsync::GetSidePicture(const std::string& modname, const std::st
 		ImgName += "/";
 		ImgName += boost::to_lower_copy(SideName);
 		try {
-			img = GetImage(modname, ImgName + ".png", false);
+			img = GetImage(gamename, ImgName + ".png", false);
 		} catch (Exceptions::unitsync& u) {
-			img = GetImage(modname, ImgName + ".bmp", true);
+		}
+		if (!img.isValid()) {
+			try {
+				img = GetImage(gamename, ImgName + ".bmp", true);
+			} catch (Exceptions::unitsync& u) {
+			}
 		}
 
 		if (img.isValid()) {
@@ -483,30 +489,30 @@ UnitsyncImage Unitsync::GetSidePicture(const std::string& modname, const std::st
 	return img;
 }
 
-UnitsyncImage Unitsync::GetImage(const std::string& modname, const std::string& image_path, bool useWhiteAsTransparent) const
+UnitsyncImage Unitsync::GetImage(const std::string& gamename, const std::string& image_path, bool useWhiteAsTransparent) const
 {
-	assert(!modname.empty());
-	susynclib().SetCurrentMod(modname);
+	assert(!gamename.empty());
+	susynclib().SetCurrentMod(gamename);
 	int ini = susynclib().OpenFileVFS(image_path);
 	if (!ini)
-		LSL_THROWF(unitsync, "%s: cannot find image %s\n", modname.c_str(), image_path.c_str());
+		LSL_THROWF(unitsync, "%s: cannot find image %s\n", gamename.c_str(), image_path.c_str());
 	int FileSize = susynclib().FileSizeVFS(ini);
 	if (FileSize == 0) {
 		susynclib().CloseFileVFS(ini);
-		LSL_THROWF(unitsync, "%s: image has size 0 %s\n", modname.c_str(), image_path.c_str());
+		LSL_THROWF(unitsync, "%s: image has size 0 %s\n", gamename.c_str(), image_path.c_str());
 	}
 	Util::uninitialized_array<char> FileContent(FileSize);
 	susynclib().ReadFileVFS(ini, FileContent, FileSize);
 	return UnitsyncImage::FromVfsFileData(FileContent, FileSize, image_path, useWhiteAsTransparent);
 }
 
-StringVector Unitsync::GetAIList(const std::string& modname) const
+StringVector Unitsync::GetAIList(const std::string& gamename) const
 {
 	StringVector ret;
 	TRY_LOCK(ret);
-	if (modname.empty())
+	if (gamename.empty())
 		return ret;
-	int total = susynclib().GetSkirmishAICount(modname);
+	int total = susynclib().GetSkirmishAICount(gamename);
 	for (int i = 0; i < total; i++) {
 		StringVector infos = susynclib().GetAIInfo(i);
 		const int namepos = Util::IndexInSequence(infos, "shortName");
@@ -521,7 +527,7 @@ StringVector Unitsync::GetAIList(const std::string& modname) const
 	return ret;
 }
 
-void Unitsync::UnSetCurrentMod()
+void Unitsync::UnSetCurrentArchive()
 {
 #if ASYNC_LOAD
 	LOCK_UNITSYNC;
@@ -543,27 +549,27 @@ StringVector Unitsync::GetAIInfos(int index) const
 	return ret;
 }
 
-GameOptions Unitsync::GetAIOptions(const std::string& modname, int index)
+GameOptions Unitsync::GetAIOptions(const std::string& gamename, int index)
 {
-	assert(!modname.empty());
+	assert(!gamename.empty());
 	GameOptions ret;
 	TRY_LOCK(ret);
-	int count = susynclib().GetAIOptionCount(modname, index);
+	int count = susynclib().GetAIOptionCount(gamename, index);
 	for (int i = 0; i < count; ++i) {
 		GetOptionEntry(i, ret);
 	}
 	return ret;
 }
 
-StringVector Unitsync::GetUnitsList(const std::string& modname)
+StringVector Unitsync::GetUnitsList(const std::string& gamename)
 {
-	assert(!modname.empty());
-	const std::string cachefile = GetFileCachePath(modname, true) + ".units";
+	assert(!gamename.empty());
+	const std::string cachefile = GetFileCachePath(gamename, true) + ".units";
 	StringVector cache;
 	TRY_LOCK(cache)
 
 	if (!GetCacheFile(cachefile, cache)) { //cache read failed
-		susynclib().SetCurrentMod(modname);
+		susynclib().SetCurrentMod(gamename);
 		while (susynclib().ProcessUnitsNoChecksum() > 0) {
 		}
 		const int unitcount = susynclib().GetUnitCount();
@@ -612,8 +618,10 @@ UnitsyncImage Unitsync::GetMinimap(const std::string& mapname, int width, int he
 			img = UnitsyncImage(1, 1);
 		}
 	}
+
 	if (tiny)
 		m_tiny_minimap_cache.Add(mapname, img);
+
 	return img;
 }
 
@@ -682,23 +690,23 @@ MapInfo Unitsync::_GetMapInfoEx(const std::string& mapname)
 	info.height = 1;
 	if (m_mapinfo_cache.TryGet(mapname, info))
 		return info;
-	const std::string cachefile = GetFileCachePath(mapname, false, false) + ".infoex";
+	const std::string cachefile = GetFileCachePath(mapname, false, false) + ".mapinfo";
 	StringVector cache;
 	if (GetCacheFile(cachefile, cache) && cache.size() >= 11) { //cache file failed
 		info.author = cache[0];
-		info.tidalStrength = Util::FromString<long>(cache[1]);
-		info.gravity = Util::FromString<long>(cache[2]);
-		info.maxMetal = Util::FromString<double>(cache[3]);
-		info.extractorRadius = Util::FromString<double>(cache[4]);
-		info.minWind = Util::FromString<long>(cache[5]);
-		info.maxWind = Util::FromString<long>(cache[6]);
-		info.width = Util::FromString<long>(cache[7]);
-		info.height = Util::FromString<long>(cache[8]);
+		info.tidalStrength = Util::FromFloatString(cache[1]);
+		info.gravity = Util::FromIntString(cache[2]);
+		info.maxMetal = Util::FromFloatString(cache[3]);
+		info.extractorRadius = Util::FromFloatString(cache[4]);
+		info.minWind = Util::FromIntString(cache[5]);
+		info.maxWind = Util::FromIntString(cache[6]);
+		info.width = Util::FromIntString(cache[7]);
+		info.height = Util::FromIntString(cache[8]);
 		const StringVector posinfo = Util::StringTokenize(cache[9], " ");
 		for (const std::string pos : posinfo) {
 			StartPos position;
-			position.x = Util::FromString<long>(Util::BeforeFirst(pos, "-"));
-			position.y = Util::FromString<long>(Util::AfterFirst(pos, "-"));
+			position.x = Util::FromIntString(Util::BeforeFirst(pos, "-"));
+			position.y = Util::FromIntString(Util::AfterFirst(pos, "-"));
 			info.positions.push_back(position);
 		}
 		const unsigned int LineCount = cache.size();
@@ -711,18 +719,21 @@ MapInfo Unitsync::_GetMapInfoEx(const std::string& mapname)
 		info = susynclib().GetMapInfoEx(index, 1);
 
 		cache.push_back(info.author);
-		cache.push_back(Util::ToString(info.tidalStrength));
-		cache.push_back(Util::ToString(info.gravity));
-		cache.push_back(Util::ToString(info.maxMetal));
-		cache.push_back(Util::ToString(info.extractorRadius));
-		cache.push_back(Util::ToString(info.minWind));
-		cache.push_back(Util::ToString(info.maxWind));
-		cache.push_back(Util::ToString(info.width));
-		cache.push_back(Util::ToString(info.height));
+		cache.push_back(Util::ToFloatString(info.tidalStrength));
+		cache.push_back(Util::ToIntString(info.gravity));
+		cache.push_back(Util::ToFloatString(info.maxMetal));
+		cache.push_back(Util::ToFloatString(info.extractorRadius));
+		cache.push_back(Util::ToFloatString(info.minWind));
+		cache.push_back(Util::ToFloatString(info.maxWind));
+		cache.push_back(Util::ToIntString(info.width));
+		cache.push_back(Util::ToIntString(info.height));
 
 		std::string postring;
 		for (unsigned int i = 0; i < info.positions.size(); i++) {
-			postring += Util::ToString(info.positions[i].x) + "-" + Util::ToString(info.positions[i].y) + " ";
+			if (!postring.empty()) {
+				postring += " ";
+			}
+			postring += Util::ToIntString(info.positions[i].x) + "-" + Util::ToIntString(info.positions[i].y);
 		}
 		cache.push_back(postring);
 
@@ -746,8 +757,11 @@ bool Unitsync::ReloadUnitSyncLib()
 	const std::string path = LSL::Util::config().GetCurrentUsedUnitSync();
 	if (path.empty())
 		return false;
-	//LoadUnitSyncLibAsync(path); //FIXME: repair/use this!
+#if ASYNC_LOAD
+	LoadUnitSyncLibAsync(path);
+#else
 	LoadUnitSyncLib(path);
+#endif
 	return true;
 }
 
@@ -796,7 +810,7 @@ bool Unitsync::GetCacheFile(const std::string& path, StringVector& ret) const
 	ret.clear();
 	char line[1024];
 	while (fgets(line, 1024, file) != NULL) {
-		const int len = strlen(line);
+		const int len = strnlen(line, 1024);
 		ret.push_back(std::string(line, len - 1));
 	}
 	fclose(file);
@@ -1146,10 +1160,10 @@ void Unitsync::GetMapExAsync(const std::string& mapname)
 	m_cache_thread->DoWork(work, 200 /* higher prio then GetMinimapAsync */);
 }
 
-std::string Unitsync::GetTextfileAsString(const std::string& modname, const std::string& file_path)
+std::string Unitsync::GetTextfileAsString(const std::string& gamename, const std::string& file_path)
 {
-	assert(!modname.empty());
-	susynclib().SetCurrentMod(modname);
+	assert(!gamename.empty());
+	susynclib().SetCurrentMod(gamename);
 
 	int ini = susynclib().OpenFileVFS(file_path);
 	if (!ini)
