@@ -1,3 +1,5 @@
+/* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+
 #ifndef LIBSPRINGLOBBY_HEADERGUARD_SPRINGUNITSYNC_H
 #define LIBSPRINGLOBBY_HEADERGUARD_SPRINGUNITSYNC_H
 
@@ -5,6 +7,7 @@
 #include "data.h"
 #include "mru_cache.h"
 #include <lslutils/type_forwards.h>
+#include "image.h"
 
 #include <boost/thread/mutex.hpp>
 #include <boost/signals2/signal.hpp>
@@ -40,24 +43,24 @@ public:
 	Unitsync();
 	~Unitsync();
 
-	StringVector GetModList() const;
-	bool ModExists(const std::string& modname, const std::string& hash = "") const;
-	UnitsyncMod GetMod(const std::string& modname);
-	UnitsyncMod GetMod(int index);
+	StringVector GetGameList() const;
+	bool GameExists(const std::string& gamename, const std::string& hash = "") const;
+	UnitsyncGame GetGame(const std::string& gamename);
+	UnitsyncGame GetGame(int index);
 
-	GameOptions GetModOptions(const std::string& name);
-	StringVector GetModDeps(const std::string& name) const;
+	GameOptions GetGameOptions(const std::string& name);
+	StringVector GetGameDeps(const std::string& name) const;
 
 	StringVector GetMapList() const;
-	StringVector GetModValidMapList(const std::string& modname) const;
+	StringVector GetGameValidMapList(const std::string& gamename) const;
 	bool MapExists(const std::string& mapname, const std::string& hash = "") const;
 
 	UnitsyncMap GetMap(const std::string& mapname);
 	UnitsyncMap GetMap(int index);
 	GameOptions GetMapOptions(const std::string& name);
 
-	StringVector GetSides(const std::string& modname);
-	UnitsyncImage GetSidePicture(const std::string& modname, const std::string& SideName);
+	StringVector GetSides(const std::string& gamename);
+	UnitsyncImage GetSidePicture(const std::string& gamename, const std::string& SideName);
 
 	bool LoadUnitSyncLib(const std::string& unitsyncloc);
 	void FreeUnitSyncLib();
@@ -65,14 +68,14 @@ public:
 	bool IsLoaded() const;
 
 	std::string GetSpringVersion() const;
-	void UnSetCurrentMod();
+	void UnSetCurrentArchive();
 
-	StringVector GetAIList(const std::string& modname) const;
+	StringVector GetAIList(const std::string& gamename) const;
 	StringVector GetAIInfos(int index) const;
-	GameOptions GetAIOptions(const std::string& modname, int index);
+	GameOptions GetAIOptions(const std::string& gamename, int index);
 
 
-	StringVector GetUnitsList(const std::string& modname);
+	StringVector GetUnitsList(const std::string& gamename);
 
 	/// get minimap rescaled to given width x height
 	UnitsyncImage GetMinimap(const std::string& mapname, int width, int height);
@@ -130,20 +133,20 @@ private:
 	UnitsyncImage GetHeightmap(const std::string& mapname);
 
 	bool FileExists(const std::string& name) const;
-	std::string GetTextfileAsString(const std::string& modname, const std::string& file_path);
+	std::string GetTextfileAsString(const std::string& gamename, const std::string& file_path);
 
 	StringVector GetMapDeps(const std::string& name);
 
-	UnitsyncImage GetImage(const std::string& modname, const std::string& image_path, bool useWhiteAsTransparent = true) const;
+	UnitsyncImage GetImage(const std::string& gamename, const std::string& image_path, bool useWhiteAsTransparent = true) const;
 
-	LocalArchivesVector m_maps_list;	   /// mapname -> hash
-	LocalArchivesVector m_mods_list;	   /// modname -> hash
-	LocalArchivesVector m_mods_archive_name;   /// modname -> archive name
-	LocalArchivesVector m_maps_archive_name;   /// mapname -> archive name
-	StringVector m_map_array;		   // this vector is CUSTOM SORTED ALPHABETICALLY, DON'T USE TO ACCESS UNITSYNC DIRECTLY
-	StringVector m_mod_array;		   // this vector is CUSTOM SORTED ALPHABETICALLY, DON'T USE TO ACCESS UNITSYNC DIRECTLY
-	StringVector m_unsorted_map_array;	 // this is because unitsync doesn't have a search map index by name ..
-	StringVector m_unsorted_mod_array;	 // this isn't necessary but makes things more symmetrical :P
+	LocalArchivesVector m_maps_list;	 /// mapname -> hash
+	LocalArchivesVector m_mods_list;	 /// gamename -> hash
+	LocalArchivesVector m_mods_archive_name; /// gamename -> archive name
+	LocalArchivesVector m_maps_archive_name; /// mapname -> archive name
+	StringVector m_map_array;		 // this vector is CUSTOM SORTED ALPHABETICALLY, DON'T USE TO ACCESS UNITSYNC DIRECTLY
+	StringVector m_mod_array;		 // this vector is CUSTOM SORTED ALPHABETICALLY, DON'T USE TO ACCESS UNITSYNC DIRECTLY
+	StringVector m_unsorted_map_array;       // this is because unitsync doesn't have a search map index by name ..
+	StringVector m_unsorted_mod_array;       // this isn't necessary but makes things more symmetrical :P
 
 	/// caches sett().GetCachePath(), because that method calls back into
 	/// susynclib(), there's a good chance main thread blocks on some
@@ -169,7 +172,7 @@ private:
 
 	//! this function returns only the cache path without the file extension,
 	//! the extension itself would be added in the function as needed
-	std::string GetFileCachePath(const std::string& archivename, bool IsMod, bool usehash = true);
+	std::string GetFileCachePath(const std::string& archivename, bool IsGame, bool usehash = true);
 
 	bool _LoadUnitSyncLib(const std::string& unitsyncloc);
 	void _FreeUnitSyncLib();
@@ -241,31 +244,4 @@ private:
 
 } // namespace LSL
 
-/**
- * \file unitsync.h
- * \section LICENSE
-Copyright 2012 by The libSpringLobby team. All rights reserved.
-
-Redistribution and use in source and binary forms, with or without modification, are
-permitted provided that the following conditions are met:
-
-   1. Redistributions of source code must retain the above copyright notice, this list of
-      conditions and the following disclaimer.
-
-   2. Redistributions in binary form must reproduce the above copyright notice, this list
-      of conditions and the following disclaimer in the documentation and/or other materials
-      provided with the distribution.
-
-THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
-INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
-AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
-COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
-INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
-ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-**/
-
 #endif // LIBSPRINGLOBBY_HEADERGUARD_SPRINGUNITSYNC_H
