@@ -1,3 +1,5 @@
+/* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+
 #include "config.h"
 
 #include <lslutils/conversion.h>
@@ -5,21 +7,23 @@
 #include "misc.h"
 #include "globalsmanager.h"
 
-namespace LSL {
-namespace Util {
+namespace LSL
+{
+namespace Util
+{
 
 // FIXME chose better defaults
-Config::Config():
-	Cache("cache"),
-	CurrentUsedUnitSync("unitsync"),
-	CurrentUsedSpringBinary("spring")
+Config::Config()
+    : Cache("cache")
+    , CurrentUsedUnitSync("unitsync")
+    , CurrentUsedSpringBinary("spring")
 {
 }
 
 Config& config()
 {
-	static LSL::Util::LineInfo<Config> m( AT );
-	static LSL::Util::GlobalObjectHolder<Config, LSL::Util::LineInfo<Config> > m_sett( m );
+	static LSL::Util::LineInfo<Config> m(AT);
+	static LSL::Util::GlobalObjectHolder<Config, LSL::Util::LineInfo<Config> > m_sett(m);
 	return m_sett;
 }
 
@@ -53,4 +57,4 @@ void Config::ConfigurePaths(const std::string& Cache, const std::string& Current
 }
 
 } // namespace Util
-}// namespace LSL {
+} // namespace LSL {
