@@ -30,6 +30,8 @@
 #include "utils/conversion.h"
 #include "autohostmanager.h"
 #include "autohost.h"
+#include "utils/globalevents.h"
+#include "servermanager.h"
 
 #include <lslutils/globalsmanager.h>
 #include <exception>
@@ -71,7 +73,7 @@ void ServerEvents::OnLoginInfoComplete()
 		sett().SetHighlightedWords(highlights);
 	}
 	//m_serv.RequestChannels();
-	GlobalEvent::Send(GlobalEvent::OnLogin);
+	GlobalEventManager::Instance()->Send(GlobalEventManager::OnLogin);
 	std::vector<ChannelJoinInfo> autojoin = sett().GetChannelsJoin();
 	for (std::vector<ChannelJoinInfo>::const_iterator itor = autojoin.begin(); itor != autojoin.end(); ++itor) {
 		if (itor->name.IsEmpty())
@@ -130,12 +132,12 @@ void ServerEvents::OnNewUser(const std::string& nick, const std::string& country
 		return;
 	}
 	User& user = m_serv._AddUser(nick);
-	if (useractions().DoActionOnUser(UserActions::ActNotifLogin, TowxString(nick))) {
-		actNotifBox(SL_MAIN_ICON, TowxString(nick) + _(" is online"));
-	}
 	user.SetCountry(country);
 	user.SetCpu(cpu);
 	user.SetID(id);
+	if (!m_serv.IsOnline()) { //login info isn't complete yet
+		return;
+	}
 	ui().OnUserOnline(user);
 }
 
@@ -154,17 +156,23 @@ void ServerEvents::OnUserStatus(const std::string& nick, UserStatus status)
 				actNotifBox(SL_MAIN_ICON, TowxString(nick) + _(" is now ") + diffString);
 		}
 
-		ui().OnUserStatusChanged(user);
+		if (m_serv.IsOnline()) { //login info isn't complete yet
+			ui().OnUserStatusChanged(user);
+		}
+
 		if (user.GetBattle() != 0) {
 			IBattle& battle = *user.GetBattle();
 			try {
 				if (battle.GetFounder().GetNick() == user.GetNick()) {
 					if (status.in_game != battle.GetInGame()) {
 						battle.SetInGame(status.in_game);
-						if (status.in_game)
-							battle.StartSpring();
-						else
-							BattleEvents::GetBattleEventSender(BattleEvents::BattleInfoUpdate).SendEvent(std::make_pair(user.GetBattle(), ""));
+						if (m_serv.IsOnline()) {
+							if (status.in_game) {
+								battle.StartSpring();
+							} else {
+								BattleEvents::GetBattleEventSender(BattleEvents::BattleInfoUpdate).SendEvent(std::make_pair(user.GetBattle(), ""));
+							}
+						}
 					}
 				}
 			} catch (...) {
@@ -228,12 +236,16 @@ void ServerEvents::OnBattleOpened(int id, BattleType type, NatType nat, const st
 		battle.SetRankNeeded(rank);
 		battle.SetHostMap(map, maphash);
 		battle.SetDescription(title);
-		battle.SetHostMod(mod, "");
+		battle.SetHostGame(mod, "");
 		battle.SetEngineName(engineName);
 		battle.SetEngineVersion(engineVersion);
 
-		if (useractions().DoActionOnUser(UserActions::ActNotifBattle, TowxString(user.GetNick())))
+		if (useractions().DoActionOnUser(UserActions::ActNotifBattle, TowxString(user.GetNick()))) {
 			actNotifBox(SL_MAIN_ICON, TowxString(user.GetNick()) + _(" opened battle ") + TowxString(title));
+		}
+		if (!m_serv.IsOnline()) { //login info isn't complete yet
+			return;
+		}
 
 		ui().OnBattleOpened(battle);
 		if (user.Status().in_game) {
@@ -251,13 +263,13 @@ void ServerEvents::OnJoinedBattle(int battleid, const std::string& hash)
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 
-		battle.SetHostMod(battle.GetHostModName(), hash);
+		battle.SetHostGame(battle.GetHostGameName(), hash);
 		UserBattleStatus& bs = m_serv.GetMe().BattleStatus();
 		bs.spectator = false;
 
 		if (!battle.IsFounderMe() || battle.IsProxy()) {
 			battle.CustomBattleOptions().loadOptions(LSL::Enum::MapOption, battle.GetHostMapName());
-			battle.CustomBattleOptions().loadOptions(LSL::Enum::ModOption, battle.GetHostModName());
+			battle.CustomBattleOptions().loadOptions(LSL::Enum::ModOption, battle.GetHostGameName());
 		}
 
 		ui().OnJoinedBattle(battle);
@@ -274,13 +286,13 @@ void ServerEvents::OnHostedBattle(int battleid)
 
 		if (battle.GetBattleType() == BT_Played) {
 			battle.CustomBattleOptions().loadOptions(LSL::Enum::MapOption, battle.GetHostMapName());
-			battle.CustomBattleOptions().loadOptions(LSL::Enum::ModOption, battle.GetHostModName());
+			battle.CustomBattleOptions().loadOptions(LSL::Enum::ModOption, battle.GetHostGameName());
 		} else {
 			battle.GetBattleFromScript(true);
 		}
 
 
-		const std::string presetname = STD_STRING(sett().GetModDefaultPresetName(TowxString(battle.GetHostModName())));
+		const std::string presetname = STD_STRING(sett().GetModDefaultPresetName(TowxString(battle.GetHostGameName())));
 		if (!presetname.empty()) {
 			battle.LoadOptionsPreset(presetname);
 		}
@@ -431,7 +443,7 @@ void ServerEvents::OnSetBattleInfo(int battleid, const std::string& param, const
 				return;
 			}
 			if (param.find("game/restrict") == 0) {
-				OnBattleDisableUnit(battleid, vec[2], LSL::Util::FromString<int>(value));
+				OnBattleDisableUnit(battleid, vec[2], LSL::Util::FromIntString(value));
 				return;
 			}
 			if (param.find("game/") == 0) { //game/team0/startposx=1692.
@@ -446,10 +458,10 @@ void ServerEvents::OnSetBattleInfo(int battleid, const std::string& param, const
 							UserBattleStatus& status = usr.BattleStatus();
 							if (status.team == team) {
 								if (xpos) {
-									status.pos.x = LSL::Util::FromString<int>(value);
+									status.pos.x = LSL::Util::FromIntString(value);
 								}
 								if (ypos) {
-									status.pos.y = LSL::Util::FromString<int>(value);
+									status.pos.y = LSL::Util::FromIntString(value);
 								}
 								battle.OnUserBattleStatusUpdated(usr, status);
 							}
@@ -479,7 +491,7 @@ void ServerEvents::OnSetBattleInfo(int battleid, const std::string& param, const
 		case 2: { //depth 2
 			if (param == "game/hosttype") {
 				if (battle.m_autohost_manager->RecognizeAutohost(value)) {
-					OnSaidBattle(battleid, battle.GetMe().GetNick(), stdprintf("detected %s autohost", value.c_str())); //FIXME: add event for that + add a label?!
+					wxLogInfo("detected %s autohost", value.c_str()); //FIXME: add event for that + add a label?!
 				}
 				return;
 			}
@@ -869,7 +881,8 @@ void ServerEvents::OnRedirect(const std::string& address, unsigned int port, con
 {
 	const wxString name = TowxString(address) + _T(":") + TowxString(port);
 	sett().SetServer(name, TowxString(address), port);
-	ui().DoConnect(name, TowxString(CurrentNick), TowxString(CurrentPassword));
+	//TODO: Rework this. Server calls it`s own method through another object!
+	ServerManager::Instance()->DoConnectToServer(name, TowxString(CurrentNick), TowxString(CurrentPassword));
 }
 
 
