@@ -23,9 +23,8 @@
 #include <wx/tokenzr.h>
 #include <wx/colourdata.h>
 #include <set>
-#include <lslutils/misc.h>
+#include <cstdlib>
 #include <lslutils/globalsmanager.h>
-#include <lslunitsync/unitsync.h>
 
 #include "utils/conversion.h"
 #include "utils/platform.h"
@@ -79,7 +78,7 @@ void Settings::Setup(wxTranslationHelper* translationhelper)
 		cfg().Write(_T( "/General/CacheVersion" ), CACHE_VERSION);
 	}
 
-	SafeMkdir(userConfigDir);
+	SlPaths::mkDir(STD_STRING(userConfigDir));
 
 	if (!cfg().ReadBool(_T("/General/firstrun"))) {
 		ConvertSettings(translationhelper, settversion);
@@ -645,15 +644,15 @@ void Settings::DeletePreset(const wxString& name)
 }
 
 
-wxString Settings::GetModDefaultPresetName(const wxString& modname)
+wxString Settings::GetModDefaultPresetName(const wxString& gamename)
 {
-	return cfg().Read(_T( "/Hosting/ModDefaultPreset/" ) + modname);
+	return cfg().Read(_T( "/Hosting/ModDefaultPreset/" ) + gamename);
 }
 
 
-void Settings::SetModDefaultPresetName(const wxString& modname, const wxString& presetname)
+void Settings::SetModDefaultPresetName(const wxString& gamename, const wxString& presetname)
 {
-	cfg().Write(_T( "/Hosting/ModDefaultPreset/" ) + modname, presetname);
+	cfg().Write(_T( "/Hosting/ModDefaultPreset/" ) + gamename, presetname);
 }
 
 
@@ -1028,16 +1027,16 @@ void Settings::SetBattleLastAutoAnnounceDescription(bool value)
 	cfg().Write(_T( "/Hosting/AutoAnnounceDescription" ), value);
 }
 
-void Settings::SetBattleLastSideSel(const wxString& modname, int sidenum)
+void Settings::SetBattleLastSideSel(const wxString& gamename, int sidenum)
 {
-	cfg().Write(_T("/Battle/Sides/" + modname), sidenum);
+	cfg().Write(_T("/Battle/Sides/" + gamename), sidenum);
 }
 
-int Settings::GetBattleLastSideSel(const wxString& modname)
+int Settings::GetBattleLastSideSel(const wxString& gamename)
 {
-	if (modname.IsEmpty())
+	if (gamename.IsEmpty())
 		return 0;
-	return cfg().Read(_T("/Battle/Sides/" + modname), 0l);
+	return cfg().Read(_T("/Battle/Sides/" + gamename), 0l);
 }
 
 void Settings::SetMapLastStartPosType(const wxString& mapname, const wxString& startpostype)
@@ -1118,6 +1117,11 @@ void Settings::SetColumnWidth(const wxString& list_name, const int column_ind, c
 	cfg().Write(_T( "GUI/ColumnWidths/" ) + list_name + _T( "/" ) + TowxString(column_ind), column_width);
 }
 
+void Settings::SetColumnVisibility(const wxString& list_name, const int column_ind, const bool columnIsHidden)
+{
+	cfg().Write(_T( "GUI/ColumnVisibilities/" ) + list_name + _T( "/" ) + TowxString(column_ind), columnIsHidden);
+}
+
 int Settings::GetColumnWidth(const wxString& list_name, const int column)
 {
 	const int orgwidth = cfg().Read(_T( "/GUI/ColumnWidths/" ) + list_name + _T( "/" ) + TowxString(column), columnWidthUnset);
@@ -1127,6 +1131,15 @@ int Settings::GetColumnWidth(const wxString& list_name, const int column)
 	return width;
 }
 
+bool Settings::GetColumnVisibility(const wxString& list_name, const int column)
+{
+	bool isHidden;
+
+	cfg().Read(_T( "/GUI/ColumnVisibilities/" ) + list_name + _T( "/" ) + TowxString(column), &isHidden, false);
+
+	return isHidden;
+}
+
 void Settings::SaveCustomColors(const wxColourData& _cdata, const wxString& paletteName)
 {
 	//note 16 colors is wx limit
@@ -1493,9 +1506,3 @@ unsigned int Settings::GetNotificationPopupDisplayTime()
 {
 	return cfg().Read(_T("/GUI/NotificationPopupDisplayTime"), 5l);
 }
-
-
-wxString Settings::GetDefaultNick()
-{
-	return TowxString(LSL::usync().GetSpringConfigString("name", "Player"));
-}
