@@ -246,7 +246,10 @@ public:
 	void SetSortOrder(const wxString& list_name, const SortOrder& order);
 
 	void SetColumnWidth(const wxString& list_name, const int column_ind, const int column_width);
+	void SetColumnVisibility(const wxString&, const int, const bool);
+
 	int GetColumnWidth(const wxString& list_name, const int column);
+	bool GetColumnVisibility(const wxString& list_name, const int column);
 	//! used to signal unset column width in Get...
 	static const int columnWidthUnset = -3;
 	static const int columnWidthMinimum = 5;
@@ -342,7 +345,6 @@ public:
 	int GetLastHostPlayerNum();
 	int GetLastHostNATSetting();
 	wxString GetLastHostMap();
-	wxString GetDefaultNick();
 	int GetLastRankLimit();
 	bool GetTestHostPort();
 	bool GetLastAutolockStatus();
@@ -365,8 +367,8 @@ public:
 	wxArrayString GetPresetList();
 	void DeletePreset(const wxString& name);
 
-	wxString GetModDefaultPresetName(const wxString& modname);
-	void SetModDefaultPresetName(const wxString& modname, const wxString& presetname);
+	wxString GetModDefaultPresetName(const wxString& gamename);
+	void SetModDefaultPresetName(const wxString& gamename, const wxString& presetname);
 
 	/**@}*/
 
@@ -424,8 +426,8 @@ public:
 	bool GetBattleLastAutoAnnounceDescription();
 	void SetBattleLastAutoAnnounceDescription(bool value);
 
-	void SetBattleLastSideSel(const wxString& modname, int sidenum);
-	int GetBattleLastSideSel(const wxString& modname);
+	void SetBattleLastSideSel(const wxString& gamename, int sidenum);
+	int GetBattleLastSideSel(const wxString& gamename);
 
 	struct SettStartBox
 	{
