@@ -3,9 +3,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/networking/socket.cpp
 
