@@ -7,9 +7,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/networking/socket.h
 
@@ -47,7 +45,7 @@ class wxSocketEvent;
 class Socket : public wxEvtHandler
 {
 public:
-	Socket(iNetClass& netclass);
+	explicit Socket(iNetClass& netclass);
 	~Socket();
 
 	// Socket interface
