@@ -6,9 +6,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/spring/spring.h
 
@@ -32,7 +30,7 @@ public:
 
 	bool IsRunning() const;
 	bool Run(IBattle& battle);
-	wxString WriteScriptTxt(IBattle& battle) const;
+	std::string WriteScriptTxt(IBattle& battle) const;
 	/* start engine */
 	bool LaunchEngine(wxArrayString& params);
 
