@@ -39,6 +39,7 @@
 #include "gui/controls.h"
 #include "utils/platform.h"
 #include "utils/version.h"
+#include "utils/globalevents.h"
 #include "channel.h"
 #include "gui/customdialogs.h"
 #include "downloader/prdownloader.h"
@@ -53,6 +54,8 @@
 #include "log.h"
 #include "utils/conversion.h"
 #include "gui/ui.h"
+#include "servermanager.h"
+#include "gui/iconscollection.h"
 
 #include <wx/debugrpt.h>
 #include <wx/intl.h>
@@ -135,7 +138,7 @@ bool SpringLobbyApp::OnInit()
 	m_translationhelper = new wxTranslationHelper(GetAppName().Lower(), path);
 
 	const wxString configdir = TowxString(SlPaths::GetConfigfileDir());
-	SafeMkdir(configdir);
+	SlPaths::mkDir(STD_STRING((configdir)));
 
 	if (cfg().ReadBool(_T("/ResetLayout"))) {
 		//we do this early on and reset the config var a little later so we can save a def. perps once mw is created
@@ -177,11 +180,10 @@ bool SpringLobbyApp::OnInit()
 //! @brief Finalizes the application
 int SpringLobbyApp::OnExit()
 {
-	if (quit_called)
+	if (quit_called) {
 		return 0;
-
+	}
 	quit_called = true;
-	slLogDebugFunc("");
 
 	if (m_translationhelper) {
 		wxDELETE(m_translationhelper);
@@ -189,6 +191,9 @@ int SpringLobbyApp::OnExit()
 
 	sett().SaveSettings(); // to make sure that cache path gets saved before destroying unitsync
 
+	IconsCollection::Release();
+	ServerManager::Release();
+	GlobalEventManager::Release();
 	SetEvtHandlerEnabled(false);
 	UiEvents::GetNotificationEventSender().Enable(false);
 	LSL::Util::DestroyGlobals();
@@ -270,5 +275,5 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
 
 void SpringLobbyApp::OnQuit(wxCommandEvent& /*data*/)
 {
-	GlobalEvent::Send(GlobalEvent::OnQuit);
+	GlobalEventManager::Instance()->Send(GlobalEventManager::OnQuit);
 }
