@@ -3,9 +3,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/networking/tasserver.h
 
@@ -52,7 +50,7 @@ public:
 
 	void Login() override;
 	void Logout() override;
-	bool IsOnline() const override;
+	bool IsOnline() const override; //returns true when user is successfully logged in
 
 	void Ping() override;
 
@@ -139,18 +137,16 @@ private:
 
 	void HandlePong(int replyid);
 
-	void OnError(const std::string& err);
 
 	bool IsPasswordHash(const std::string& pass) const;
 	std::string GetPasswordHash(const std::string& pass) const;
 
-	int TestOpenPort(unsigned int port) const;
-
 	void SetRelayIngamePassword(const User& user);
 
-	void OnConnected();
-	void OnDataReceived();
-	void OnDisconnected();
+	void OnConnected() override;
+	void OnDisconnected() override;
+	void OnDataReceived() override;
+	void OnError(const std::string& err) override;
 
 	void UDPPing(); /// used for nat travelsal
 	/// generic udp "ping" function
