@@ -4,12 +4,13 @@
 #include <boost/test/unit_test.hpp>
 
 #include <stdio.h>
-#include "utils/lslconversion.h"
+#include <wx/colour.h>
 #include <lslutils/misc.h>
 #include <lslutils/conversion.h>
+
 #include "user.h"
+#include "utils/lslconversion.h"
 #include "utils/conversion.h"
-#include <wx/colour.h>
 
 
 void test_wxColourTolsl(const unsigned char red, const unsigned char green, const unsigned char blue, const unsigned char alpha)
@@ -120,12 +121,21 @@ BOOST_AUTO_TEST_CASE(colorconv)
 	const std::string blackstr("0 0 0");
 	const LSL::lslColor blackcol(0, 0, 0);
 
+	const std::string greystr("0.501961 0.501961 0.501961");
+	const LSL::lslColor greycol(128, 128, 128);
+
+	BOOST_CHECK(greycol.Red() == 128);
+
+
 	BOOST_CHECK(whitecol == LSL::lslColor::FromFloatString(whitestr));
 	BOOST_CHECK_MESSAGE(whitestr == LSL::lslColor::ToFloatString(whitecol), LSL::lslColor::ToFloatString(whitecol));
 
 	BOOST_CHECK(blackcol == LSL::lslColor::FromFloatString(blackstr));
 	BOOST_CHECK_MESSAGE(blackstr == LSL::lslColor::ToFloatString(blackcol), LSL::lslColor::ToFloatString(blackcol));
 
+	BOOST_CHECK(greycol == LSL::lslColor::FromFloatString(greystr));
+	BOOST_CHECK_MESSAGE(greystr == LSL::lslColor::ToFloatString(greycol), LSL::lslColor::ToFloatString(greycol));
+
 
 	for (int c = 0; c < 3; c++) {
 		float r = 0.f, g = 0.f, b = 0.f;
@@ -174,16 +184,73 @@ BOOST_AUTO_TEST_CASE(hashes)
 	const unsigned int overflow = 2232970410; //this
 	const int negative = -2147483648;
 
-	BOOST_CHECK("-2061996886" == LSL::Util::MakeHashSigned(LSL::Util::ToString(overflow)));
-	BOOST_CHECK(stdprintf("%d", negative) == LSL::Util::MakeHashSigned(LSL::Util::ToString(negative)));
+	BOOST_CHECK("-2061996886" == LSL::Util::MakeHashSigned(LSL::Util::ToIntString(overflow)));
+	BOOST_CHECK("-2147483648" == LSL::Util::MakeHashSigned(LSL::Util::ToIntString(negative)));
 
-	BOOST_CHECK("2232970410" == LSL::Util::MakeHashUnsigned(LSL::Util::ToString(overflow)));
-	BOOST_CHECK(stdprintf("%u", negative) == LSL::Util::MakeHashUnsigned(LSL::Util::ToString(negative)));
+	BOOST_CHECK("2232970410" == LSL::Util::MakeHashUnsigned(LSL::Util::ToIntString(overflow)));
+	BOOST_CHECK("2147483648" == LSL::Util::MakeHashUnsigned(LSL::Util::ToIntString(negative)));
 
-	BOOST_CHECK("2232970410" == LSL::Util::MakeHashUnsigned(stdprintf("%d", overflow)));
-	BOOST_CHECK(stdprintf("%u", negative) == LSL::Util::MakeHashUnsigned(stdprintf("%d", negative)));
+	BOOST_CHECK("2232970410" == LSL::Util::MakeHashUnsigned("-2061996886"));
+	BOOST_CHECK("2147483648" == LSL::Util::MakeHashUnsigned("-2147483648"));
 
-	BOOST_CHECK("2232970410" == LSL::Util::MakeHashUnsigned(stdprintf("%u", overflow)));
-	BOOST_CHECK("2147483648" == LSL::Util::MakeHashUnsigned(stdprintf("%u", negative)));
+	BOOST_CHECK(LSL::Util::MakeHashUnsigned("3807049253") == LSL::Util::MakeHashUnsigned("-487918043"));
+	BOOST_CHECK(LSL::Util::MakeHashUnsigned("-2567621") == LSL::Util::MakeHashUnsigned("4292399675"));
+
+	BOOST_CHECK(LSL::Util::MakeHashSigned("3807049253") == LSL::Util::MakeHashSigned("-487918043"));
+	BOOST_CHECK(LSL::Util::MakeHashSigned("-2567621") == LSL::Util::MakeHashSigned("4292399675"));
 }
 
+BOOST_AUTO_TEST_CASE(convertfloat)
+{
+	const float a = 1.0f;
+	const float b = -1.5f;
+	const float c = 1.999f;
+
+	BOOST_CHECK(a == LSL::Util::FromFloatString("1.0"));
+	BOOST_CHECK(b == LSL::Util::FromFloatString("-1.5"));
+	BOOST_CHECK(c == LSL::Util::FromFloatString("1.999"));
+
+	BOOST_CHECK(a == LSL::Util::FromFloatString(LSL::Util::ToFloatString(a)));
+	BOOST_CHECK(b == LSL::Util::FromFloatString(LSL::Util::ToFloatString(b)));
+	BOOST_CHECK(c == LSL::Util::FromFloatString(LSL::Util::ToFloatString(c)));
+}
+
+BOOST_AUTO_TEST_CASE(tokenize)
+{
+	std::vector<std::string> v;
+	v = LSL::Util::StringTokenize("", " ");
+	BOOST_CHECK(v.empty());
+
+	v = LSL::Util::StringTokenize("0 1 2", " ");
+	BOOST_CHECK(v.size() == 3);
+	BOOST_CHECK(v[0] == "0");
+	BOOST_CHECK(v[1] == "1");
+	BOOST_CHECK(v[2] == "2");
+
+	v = LSL::Util::StringTokenize(" 0 1 2 ", " ");
+	BOOST_CHECK(v.size() == 3);
+	BOOST_CHECK(v[0] == "0");
+	BOOST_CHECK(v[1] == "1");
+	BOOST_CHECK(v[2] == "2");
+
+	v = LSL::Util::StringTokenize(" 0:1 2 ", " :");
+	BOOST_CHECK(v.size() == 3);
+	BOOST_CHECK(v[0] == "0");
+	BOOST_CHECK(v[1] == "1");
+	BOOST_CHECK(v[2] == "2");
+
+	v = LSL::Util::StringTokenize(" ", " :");
+	BOOST_CHECK(v.size() == 0);
+
+	v = LSL::Util::StringTokenize(" 0", " :");
+	BOOST_CHECK(v.size() == 1);
+	BOOST_CHECK(v[0] == "0");
+
+	v = LSL::Util::StringTokenize(" 0 ", " :");
+	BOOST_CHECK(v.size() == 1);
+	BOOST_CHECK(v[0] == "0");
+
+	v = LSL::Util::StringTokenize("0 ", " :");
+	BOOST_CHECK(v.size() == 1);
+	BOOST_CHECK(v[0] == "0");
+}
