@@ -26,7 +26,7 @@ BOOST_AUTO_TEST_CASE(slpaths)
 
 	BOOST_CHECK(SlPaths::mkDir(subdirs));
 	BOOST_CHECK(SlPaths::mkDir(subdirs2));
-	BOOST_CHECK(wxFileName::DirExists(TowxString(subdirs)));
+	BOOST_CHECK_MESSAGE(wxFileName::DirExists(TowxString(subdirs)), "dir doesn't exist: " + subdirs) ;
 	BOOST_CHECK(SlPaths::RmDir(testdir));
 	BOOST_CHECK(SlPaths::SantinizeFilename(":<>test:end") == std::string("___test_end"));
 }
