@@ -3,9 +3,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/user/user.cpp
 
@@ -27,6 +25,7 @@ lsl/user/user.cpp
 
 User::User(IServer& serv)
     : CommonUser("", "", 0)
+    , panel(nullptr)
     , m_serv(&serv)
     , m_battle(0)
     , m_flagicon_idx(icons().GetFlagIcon(""))
@@ -38,6 +37,7 @@ User::User(IServer& serv)
 
 User::User(const std::string& nick, IServer& serv)
     : CommonUser(nick, "", 0)
+    , panel(nullptr)
     , m_serv(&serv)
     , m_battle(0)
     , m_flagicon_idx(icons().GetFlagIcon(""))
@@ -49,6 +49,7 @@ User::User(const std::string& nick, IServer& serv)
 
 User::User(const std::string& nick, const std::string& country, const int& cpu, IServer& serv)
     : CommonUser(nick, country, cpu)
+    , panel(nullptr)
     , m_serv(&serv)
     , m_battle(0)
     , m_flagicon_idx(icons().GetFlagIcon(country))
@@ -60,6 +61,7 @@ User::User(const std::string& nick, const std::string& country, const int& cpu,
 
 User::User(const std::string& nick)
     : CommonUser(nick, "", 0)
+    , panel(nullptr)
     , m_serv(0)
     , m_battle(0)
     , m_flagicon_idx(icons().GetFlagIcon(""))
@@ -71,6 +73,7 @@ User::User(const std::string& nick)
 
 User::User(const std::string& nick, const std::string& country, const int& cpu)
     : CommonUser(nick, country, cpu)
+    , panel(nullptr)
     , m_serv(0)
     , m_battle(0)
     , m_flagicon_idx(icons().GetFlagIcon(country))
@@ -82,6 +85,7 @@ User::User(const std::string& nick, const std::string& country, const int& cpu)
 
 User::User()
     : CommonUser("", "", 0)
+    , panel(nullptr)
     , m_serv(0)
     , m_battle(0)
     , m_flagicon_idx(icons().GetFlagIcon(""))
@@ -93,8 +97,11 @@ User::User()
 
 User::~User()
 {
-	if (uidata.panel)
-		uidata.panel->SetUser(0);
+	if (panel != nullptr) {
+		ChatPanel* tmp = panel;
+		panel = nullptr;
+		tmp->SetUser(0);
+	}
 }
 
 std::string UserStatus::GetDiffString(const UserStatus& old) const
@@ -211,7 +218,7 @@ bool User::ExecuteSayCommand(const std::string& cmd) const
 	return false;
 }
 
-UserStatus::RankContainer User::GetRank()
+UserStatus::RankContainer User::GetRank() const
 {
 	return GetStatus().rank;
 }
@@ -262,6 +269,17 @@ void CommonUser::SetStatus(const UserStatus& status)
 	m_status = status;
 }
 
+LSL::lslColor User::GetColor() const {
+	return BattleStatus().colour;
+}
+
+bool User::IsHuman() const {
+	return (BattleStatus().IsBot() == false);
+}
+
+bool User::IsBot() const {
+	return BattleStatus().IsBot();
+}
 //User& User::operator= ( const User& other )
 //{
 //    if( this != &other ) {
