@@ -7,9 +7,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/user/user.h
 
@@ -184,15 +182,10 @@ struct UserBattleStatus
 class ChatPanel;
 class IBattle;
 
-struct UiUserData
+namespace LSL
 {
-	UiUserData()
-	    : panel(0)
-	{
-	}
-	ChatPanel* panel;
-};
-
+class lslColor;
+}
 //! parent class leaving out server related functionality
 class CommonUser
 {
@@ -313,12 +306,12 @@ private:
 class User : public CommonUser
 {
 public:
-	mutable UiUserData uidata;
+	ChatPanel* panel; //FIXME: privatize
 
-	User(IServer& serv);
+	explicit User(IServer& serv);
+	explicit User(const std::string& nick);
 	User(const std::string& nick, IServer& serv);
 	User(const std::string& nick, const std::string& country, const int& cpu, IServer& serv);
-	User(const std::string& nick);
 	User(const std::string& nick, const std::string& country, const int& cpu);
 	User();
 
@@ -347,9 +340,12 @@ public:
 	static std::string GetRankName(UserStatus::RankContainer rank);
 
 	float GetBalanceRank();
-	UserStatus::RankContainer GetRank();
+	UserStatus::RankContainer GetRank() const;
 	std::string GetClan();
 
+	bool IsHuman() const;
+	bool IsBot() const;
+
 	int GetFlagIconIndex() const
 	{
 		return m_flagicon_idx;
@@ -374,6 +370,8 @@ public:
 		m_sideicon_idx = idx;
 	}
 
+	LSL::lslColor GetColor() const;
+
 private:
 	// User variables
 
