@@ -8,19 +8,21 @@
 #include <wx/string.h>
 
 
-WX_DECLARE_STRING_HASH_MAP( wxString, HashMap_String_String );
+WX_DECLARE_STRING_HASH_MAP(wxString, HashMap_String_String);
 
 
-class TextCompletionDatabase {
+class TextCompletionDatabase
+{
 public:
 	TextCompletionDatabase();
 	virtual ~TextCompletionDatabase();
 
 	unsigned int Size();
 
-	void Insert_Mapping( const wxString& abbreviation, const wxString& mapping );
-	void Delete_Mapping( const wxString& abbreviation );
-	HashMap_String_String GetMapping( wxString text );
+	void Insert_Mapping(const wxString& abbreviation, const wxString& mapping);
+	void Delete_Mapping(const wxString& abbreviation);
+	HashMap_String_String GetMapping(wxString text);
+
 private:
 	HashMap_String_String hm;
 };
